local lang = {
  ["abort"] = "Abortar",
  ["actions"] = "Ações",
  ["activities"] = "atividades",
  ["activity"] = "Atividade",
  ["advanced"] = "Avançado",
  ["aggregation"] = "Agregação",
  ["all"] = "Todos",
  ["allowed"] = "Permitido",
  ["any"] = "qualquer",
  ["application"] = "Aplicação",
  ["applications"] = "Aplicações",
  ["apply"] = "Aplique",
  ["arp"] = "ARP",
  ["as"] = "COMO",
  ["as_number"] = "Número AS",
  ["asn"] = "ASN",
  ["backup"] = "Cópia de segurança",
  ["begin"] = "Início",
  ["breakdown"] = "Demolir",
  ["bridge"] = "Ponte",
  ["broadcast_domain"] = "Domínio de transmissão",
  ["broadcast_traffic"] = "Tráfego de Transmissão",
  ["bytes"] = "Bytes",
  ["cancel"] = "Cancelar",
  ["categories"] = "Categorias",
  ["category"] = "Categoria",
  ["change_number_of_rows"] = "Alterar o número de linhas por página",
  ["chart"] = "Gráfico",
  ["client"] = "Cliente",
  ["clone"] = "Clone",
  ["close"] = "Perto",
  ["countries"] = "Países",
  ["date_from"] = "Data de início / hora:",
  ["date_to"] = "Data / hora final:",
  ["day"] = "Dia",
  ["define"] = "Define",
  ["delete"] = "Excluir",
  ["destination"] = "Destino",
  ["device_protocols_description"] = "Nesta página, é possível configurar a lista de aplicativos aceitáveis ​​por tipo de dispositivo e direção (dispositivo como cliente ou servidor em relação ao aplicativo). Ao ativar os alertas de aplicativos de dispositivos na página de configuração Alertas, em Preferências, os alertas são gerados quando um aplicativo anômalo é detectado.",
  ["difference"] = "Diferença",
  ["disabled"] = "Desativado",
  ["dns"] = "DNS",
  ["download"] = "Baixar",
  ["download_x"] = "%{what} baixar",
  ["downloaders"] = "Volume de Download",
  ["drilldown"] = "Drilldown",
  ["duration"] = "Duração",
  ["egress"] = "Saída",
  ["empty"] = "Esvaziar",
  ["end"] = "Fim",
  ["enterpriseOnly"] = "Este recurso está disponível somente na edição Enterprise do Ntopng",
  ["error"] = "Erro",
  ["error_no_search_results"] = "Nenhum resultado encontrado. Por favor, modifique os seus critérios de pesquisa.",
  ["error_not_granted"] = "Pedido não concedido",
  ["error_rrd_cannot_complete_dump"] = "Não é possível concluir o despejo de serie de tempo dos hosts locais. Disco lento ou muitos hosts locais?",
  ["error_rrd_low_resolution"] = "Você está pedindo para buscar dados com uma resolução menor que a disponível no RRD, o que levará a dados inválidos. <br> Se você ainda deseja dados com essa granularidade, ajuste <a href=\"%{prefs}\"> Preferências Aplicação / Redes Séries Temporais </a>",
  ["flow"] = "Fluxo",
  ["flow_search_criteria"] = "Critérios de pesquisa de fluxo",
  ["flow_search_from_aggregated"] = "(Agregado)",
  ["flow_search_results"] = "Resultados da pesquisa de fluxo",
  ["flows"] = "Fluxos",
  ["forbidden"] = "Proibido",
  ["free"] = "Livre",
  ["from"] = "de",
  ["gateway"] = "Gateway",
  ["host"] = "Host %{host}",
  ["hosts"] = "Hosts",
  ["hour"] = "hora",
  ["http"] = "HTTP",
  ["icmp"] = "ICMP",
  ["iface_download"] = "%{iface} baixar",
  ["iface_upload"] = "%{iface} Envio",
  ["incomingflows"] = "Fluxos de entrada ativos",
  ["info"] = "Info",
  ["ingress"] = "Entrada",
  ["interface"] = "Interface",
  ["interface_ifname"] = "Interface %{ifname}",
  ["interfaces"] = "Interfaces",
  ["ip_address"] = "Endereço de IP",
  ["ipv4"] = "IPv4",
  ["ipv6"] = "IPv6",
  ["key"] = "chave",
  ["language"] = "Língua",
  ["layer_2"] = "Endereços Mac",
  ["legenda"] = "Legenda",
  ["local_traffic"] = "Local Traffic",
  ["mac_address"] = "Endereço MAC",
  ["max_rate"] = "Taxa máxima",
  ["model"] = "Modelo",
  ["month"] = "Mês",
  ["mtu"] = "MTU",
  ["name"] = "nome",
  ["netmask"] = "Netmask",
  ["networks"] = "Redes",
  ["next"] = "Próximo",
  ["no"] = "Não",
  ["noTraffic"] = "Nenhum tráfego foi relatado para a seleção de data / hora especificada",
  ["no_data_available"] = "Nenhum dado disponível",
  ["no_results_found"] = "Nenhum resultado encontrado",
  ["no_talkers_for_the_host"] = "Não há locutores para o host atual",
  ["note_flow_search_allowed_networks"] = "Usuário atual só tem permissão para navegar nas seguintes redes: %{nets}.",
  ["note_flow_search_allowed_networks_applications"] = "Hosts que não pertencem a nenhuma das redes permitidas serão ocultados dos locutores do aplicativo.",
  ["note_flow_search_allowed_networks_counter"] = "Os contadores nos resultados da pesquisa de fluxo são totais, mas somente os fluxos com cliente e servidor nas redes permitidas serão mostrados.",
  ["note_flow_search_allowed_networks_ipv6"] = "As redes IPv6 permitidas não-zero farão com que todos os fluxos IPv6 sejam mostrados.",
  ["note_flow_search_allowed_networks_talkers"] = "Hosts que não pertencem a nenhuma das redes permitidas serão ocultados dos principais locutores.",
  ["notes"] = "NOTAS:",
  ["operating_systems"] = "Sistemas operacionais",
  ["os"] = "OS",
  ["other"] = "De outros",
  ["outgoingflows"] = "Outros fluxos de saída ativos",
  ["overview"] = "visão global",
  ["packets"] = "Pacotes",
  ["peers"] = "Pares",
  ["percentage"] = "Percentagem",
  ["pkts"] = "Pacotes",
  ["port"] = "Porta",
  ["ports"] = "Portas",
  ["previous"] = "Anterior",
  ["protocol"] = "Protocolo",
  ["protocol_categories"] = "Categorias de protocolo",
  ["protocols"] = "Protocolos",
  ["purged_error_message"] = "É muito provável que tenha expirado e %{product} tenha sido removido da memória. Você pode definir as configurações de tempo limite de eliminação ociosas da <a href=\"%{url}\"> <i class = \"fa-flask\"> </ i> Preferências </a>. ",
  ["quotas"] = "Quotas",
  ["reason"] = "Razão",
  ["received"] = "Recebido",
  ["refresh"] = "Atualizar",
  ["remote_hosts"] = "Hosts remotos",
  ["remote_networks"] = "Redes remotas",
  ["remove"] = "Remover",
  ["reset"] = "Restabelecer",
  ["restore"] = "Restaurar",
  ["retry"] = "Tente novamente",
  ["running"] = "Corrida",
  ["save"] = "Salve ",
  ["save_configuration"] = "Salvar configuração",
  ["save_settings"] = "Salvar configurações",
  ["search_host"] = "Procurar",
  ["seen_since"] = "Visto desde",
  ["sent"] = "Enviei",
  ["server"] = "Servidora",
  ["showing_x_to_y_rows"] = "Mostrando%{x} a %{y} de %{tot} linhas",
  ["similarity"] = "Semelhança",
  ["speed"] = "Rapidez",
  ["start"] = "Começar",
  ["status"] = "Status",
  ["stop"] = "Pare",
  ["summary"] = "Resumo",
  ["system"] = "Sistema",
  ["talkers"] = "Locutores",
  ["tcp_flags"] = "Sinalizadores TCP",
  ["tcp_stats"] = "Estatísticas TCP ",
  ["throughput"] = "Taxa de transferência",
  ["time"] = "Tempo",
  ["timeframe"] = "Prazo",
  ["tls_certificate"] = "Certificado TLS",
  ["today"] = "Hoje",
  ["total"] = "Total",
  ["total_incoming_misbehaving_flows"] = "Fluxos Anômalos Totais como Servidor",
  ["total_incoming_unreachable_flows"] = "Total inacessível fluxos como servidor ",
  ["total_outgoing_misbehaving_flows"] = "Fluxos Anômalos Totais como Cliente",
  ["total_outgoing_unreachable_flows"] = "Fluxos Inacessíveis Totais Como Cliente",
  ["traffic"] = "Tráfego",
  ["traffic_policy"] = "Política de trânsito",
  ["undo"] = "Desfazer",
  ["unknowers"] = "Volume de Tráfego Desconhecido",
  ["unknown"] = "Desconhecido",
  ["unlimited"] = "&infin;",
  ["uploaders"] = "envio Volume",
  ["version"] = "Sua versão é %{vers}.",
  ["via"] = "Através da",
  ["vlan"] = "VLAN",
  ["warning"] = "Aviso",
  ["week"] = "Semana",
  ["welcome"] = "Bem vinda",
  ["welcome_to"] = "Bem-vindo ao %{product}",
  ["yes"] = "sim",
  ["about"] = {
    ["about"] = "Sobre",
    ["about_ntopng"] = "Sobre o ntopng",
    ["about_x"] = "sobre %{product}",
    ["built_on"] = "Construído em",
    ["copyright"] = "direito autoral",
    ["cpu_load"] = "Carga da CPU",
    ["datadir_warning"] = "Aviso de migração do diretório de dados",
    ["influxdb_migration_msg"] = "Você tem muitos hosts locais. Por favor, considere <a href='%{url}'> mudar de RRD para InfluxDB </a> para armazenamento de timeseries para melhorar o desempenho. ",
    ["last_log"] = "Último rastreamento de log",
    ["licence"] = "Licença",
    ["licence_expires_in"] = "Licença expira em %{time} ",
    ["licence_generation"] = "Clique no URL acima para gerar sua licença de versão profissional ou compre uma licença em <a href=\"%{purchase_url}\"> e-shop </a>. Se você não tem fins lucrativos, pesquisa ou instituição educacional, leia <a href=\"%{universities_url}\"> esta </a>.",
    ["maintenance"] = "Manutenção: até %{_ until} [%{days_left} dias restantes]",
    ["maintenance_expired"] = "%{product}a manutenção expirou",
    ["maxmind"] = "Este produto inclui dados GeoDB criados por <a class='ntopng-external-link' href=\"%{maxmind_url}\">MaxMind <i class=\"fas fa-external-link-alt\"></i></a> / <a class='ntopng-external-link' href='https://db-ip.com'>DB-IP <i class=\"fas fa-external-link-alt\"></i></a>.",
    ["ntop_blog"] = "ntop Blog",
    ["platform"] = "Plataforma",
    ["ram_memory"] = "RAM",
    ["readme_and_manual"] = "Guia do usuário",
    ["report_issue"] = "Reproduzir um problema",
    ["runtime_status"] = "Status de tempo de execução",
    ["save_licence"] = "Salvar licença",
    ["specify_licence"] = "Especifique aqui sua licença ntopng",
    ["startup_line"] = "Linha de inicialização",
    ["system"] = "Sistema",
    ["system_id"] = "ID do sistema",
    ["telegram"] = "Ajuda e Notícias",
    ["upgrade_to_professional"] = "Atualize para a versão Professional",
    ["uptime"] = "Tempo de atividade",
    ["version"] = "Versão",
    ["you_have_too_many_flows"] = "Você tem muitos hosts / fluxos para sua configuração de %{product} e isso levará a quedas de pacotes e alta carga de CPU. Por favor, reinicie %{product} aumentando -x e -X ",
  },
  ["activities_page"] = {
    ["host_activity"] = "Atividade do Host",
  },
  ["alert_messages"] = {
    ["host_alert_countries_contacts"] = "Muitos países contatados por% {entity} [% {value} & gt; % {threshold} países]",
    ["a_new_device_has_connected"] = "O novo dispositivo <a href=\"%{url}\">%{device} </a> se conectou à rede.",
    ["device_has_connected"] = "O dispositivo <a href=\"%{url}\">%{device}</a> se conectou à rede.",
    ["device_has_disconnected"] = "O dispositivo <a href=\"%{url}\">%{device}</a> foi desconectado da rede.",
    ["host_entity"] = "host %{entity_value}",
    ["host_pool_has_connected"] = "O pool de hosts <a href=\"%{url}\">%{pool}</a> se conectou à rede.",
    ["host_pool_has_disconnected"] = "O pool de hosts <a href=\"%{url}\">%{pool}</a> foi desconectado da rede.",
    ["host_remote_to_remote"] = "Host remoto <a href=\"%{url}\">%{ip}</a> %{mac} entrou em contato com um controle remoto hospedeiro. Fluxos de remoto para remoto disponíveis na <a href=\"%{flow_alerts_url}\"> página de alertas de fluxo </a>.",
    ["influxdb_partial_write"] = "Isso pode ser corrigido configurando \"max-values-per-tag = 0\" na configuração do servidor InfluxDB.",
    ["influxdb_write_error"] = "Houve um erro ao enviar os dados da timeseries para \"%{influxdb}\":%{err}",
    ["interface_entity"] = "interface %{entity_value}",
    ["mac_ip_association_change"] = "IP %{ip} changed association from <a href=\"%{old_mac_url}\">%{old_mac}</a> to <a href=\"%{new_mac_url}\">%{new_mac}</a>",
    ["network_entity"] = "rede %{entity_value}",
    ["nfq_flushed"] = "Interface <a href=\"%{url}\">%{name} </a> fila de pacotes liberada. Fila%{pct} %% cheia com pacotes%{tot} e %{dropped} gotas.",
    ["ntopng_anomalous_termination"] = "Iniciado após finalização anormal (<a href=\"%{url}\"> relatório de erros </a>)",
    ["ntopng_start"] = "Começado",
    ["ntopng_stop"] = "Parado",
    ["open_files_limit_too_small"] = "Ntopng detectou que o número máximo de arquivos que o MySQL pode abrir é potencialmente pequeno demais. Isso pode resultar em perda de dados de fluxo devido a erros como [Recursos esgotados ao abrir o arquivo './ntopng/flowsv6#P#p22.MYD' (Errcode: 24 - Muitos arquivos abertos)] [23]. Certifique-se de aumentar o open_files_limit ou, se quiser apenas ignorar esse aviso, desative a verificação nas preferências.",
    ["proto_bytes_quotas"] = "%{proto} bytes",
    ["proto_time_quotas"] = "%{proto} Tempo",
    ["subject_quota_exceeded"] = "O pool de hosts <a href=\"%{url}\">%{pool}</a> excedeu %{subject} quota [%{value} &gt; %{quota}]",
    ["x_alerts"] = "%{num} alertas",
  },
  ["alerts_dashboard"] = {
    ["host_alert_countries_contacts"] = "Alerta de contatos de países",
    ["active_flows_anomaly"] = "Anomalia de Fluxos Ativos",
    ["alert_counts"] = "Contagens",
    ["alert_duration"] = "Duração",
    ["alert_severity"] = "Gravidade",
    ["alert_type"] = "Tipo",
    ["alerts_dashboard"] = "Painel de alertas",
    ["all_hosts"] = "Todos Hosts",
    ["blacklisted_flow"] = "Fluxo na Lista Negra",
    ["blocked_flow"] = "Fluxo Bloqueado",
    ["custom_period"] = "Período Personalizado",
    ["device_connection"] = "Conexão do dispositivo",
    ["device_disconnection"] = "Desconexão do dispositivo",
    ["dns_anomaly"] = "Anomalia de DNS",
    ["engaged_for_longest"] = "Alertas passados engajados por mais tempo",
    ["error"] = "Erro",
    ["five_mins"] = "Últimos 5 minutos",
    ["flow_alert_origins"] = "Origens de alerta de fluxo",
    ["flow_alert_targets"] = "Alvos de Alerta de Fluxo",
    ["flow_misbehaviour"] = "Misbehavior do fluxo",
    ["flows_flood"] = "Flows Flood",
    ["host_pool_connection"] = "Conexão de pool de host",
    ["host_pool_disconnection"] = "Desconexão do Conjunto de Hosts",
    ["icmp_anomaly"] = "Anomalia do ICMP",
    ["inactivity"] = "Inatividade",
    ["influxdb_export_failure"] = "Falha de exportação do influxo",
    ["info"] = "Info",
    ["interface_alerted"] = "Interface Alertada",
    ["involving_msg"] = "Alertas de Fluxo Envolvendo",
    ["last_day"] = "Último dia",
    ["last_hour"] = "Última hora",
    ["last_minute"] = "Último minuto",
    ["list_download_failed"] = "Falha no download da lista",
    ["local_only"] = "Somente hosts locais",
    ["local_origin_remote_target"] = "Origem Local - Alvo Remoto",
    ["mac_ip_association_change"] = "Mudança IP / MAC",
    ["misconfigured_app"] = "App mal configurado",
    ["new_device"] = "Novo dispositivo",
    ["nfq_flushed"] = "Fila de pacotes descarregada",
    ["no_alert"] = "Sem alerta",
    ["no_alerts"] = "Sem alertas",
    ["none"] = "Nenhum",
    ["not_engaged"] = "Não envolvido",
    ["one_day"] = "Último dia",
    ["one_hour"] = "Última hora",
    ["one_min"] = "Último minuto",
    ["process"] = "Processo",
    ["quota_exceeded"] = "Cota excedida",
    ["remote_only"] = "Somente hosts remotos",
    ["remote_origin_local_target"] = "Origem remota - alvo local",
    ["remote_to_remote"] = "Remoto para Remoto",
    ["search_criteria"] = "Configurações do painel",
    ["snmp_device_is_unresponsive"] = "Dispositivo SNMP <a href = \"%{url}\">%{device}</a>não responde",
    ["snmp_port_changed_operational_status"] = "Interface <a href=\"%{port_url}\">%{port}</a> no dispositivo SNMP <a href=\"%{url}\">%{device}</a> mudou seu status para %{new_op}",
    ["snmp_port_errors"] = "Erros de interface",
    ["snmp_port_errors_increased"] = "Contadores de descarte / erro aumentados na interface <a href=\"%{port_url}\">%{port}</a> no dispositivo SNMP <a href=\"%{url}\">%{device}</a>",
    ["snmp_port_status_change"] = "Mudança de Status da Interface",
    ["starting_on"] = "Começando",
    ["submit"] = "Atualizar painel",
    ["suspicious_activity"] = "Atividade suspeita",
    ["suspicious_device_protocol"] = "Protocolo de Dispositivo Suspeito",
    ["tcp_syn_flood"] = "TCP SYN Flood",
    ["threashold_cross"] = "limite de crus",
    ["too_many_drops"] = "Gotas de Pacotes",
    ["total_alerts"] = "Total de alertas",
    ["trailing_msg"] = "Janela de oportunidade",
    ["unresponsive_device"] = "Dispositivo sem resposta",
    ["user_activity"] = "Atividade do usuário",
    ["warning"] = "Aviso",
    ["web_mining"] = "Mineração na Web",
  },
  ["alerts_thresholds_config"] = {
    ["countries_contacts_title"] = "Alerta de contatos de países",
    ["countries_contacts_description"] = "Acionar um alerta quando o número de países diferentes contatados exceder o limite",
    ["active_local_hosts"] = "Hosts locais",
    ["active_local_hosts_threshold_descr"] = "Número de hosts locais ativos",
    ["activity_time"] = "Tempo de atividade",
    ["alert_active_description"] = "Delta do tempo de atividade (seconds).",
    ["alert_bytes_description"] = "Delta de 2 bytes de camada (sent + received)",
    ["alert_dns_description"] = "Delta de 2 bytes de camada (sent + received) para o tráfego detectado pelo DNS",
    ["alert_flows_description"] = "Delta de fluxo (as client + as server)",
    ["alert_idle_description"] = "Tempo ocioso desde o último pacote visto (seconds)",
    ["alert_network_egress_description"] = "Delta de Bytes de Saída",
    ["alert_network_ingress_description"] = "Ingress Bytes delta",
    ["alert_network_inner_description"] = "Delta interno dos bytes",
    ["alert_p2p_description"] = "Delta de 2 bytes de camada (sent + received) para tráfego detectado peer-to-peer",
    ["alert_packets_description"] = "Pacotes delta (sent + received)",
    ["alert_throughput_description"] = "Taxa de transferência média (sent + received) [Mbps]",
    ["common_thresholds_local_sources"] = "%{source}s Limiares Comuns",
    ["daily"] = "Diariamente",
    ["dns_traffic"] = "Tráfego DNS",
    ["egress_traffic"] = "Tráfego de saída",
    ["every_5_minutes"] = "A cada 5 minutos",
    ["every_minute"] = "Todo minuto",
    ["hourly"] = "De hora em hora",
    ["idle_time"] = "Tempo ocioso",
    ["ingress_traffic"] = "Tráfego de ingresso",
    ["inner_traffic"] = "Tráfego Interno",
    ["note_attacker_victime_threshold"] = "Um limite de invasor / vítima é considerado excedido se o host correspondente tiver excedido o limite configurado por pelo menos três segundos ao executar a verificação periódica.",
    ["note_checks_on_active_hosts"] = "As verificações são realizadas apenas para hosts ativos. Definir uma condição 'menor que' implica em maior que zero.",
    ["note_consecutive_checks"] = "Cheques consecutivos não são necessariamente realizados em períodos consecutivos. Por exemplo, se um host ficar ocioso, seus limites não serão verificados até se tornarem ativos novamente.",
    ["note_control_threshold_checks_periods"] = "Os limites listados nessas guias são verificados periodicamente. Use guias para controlar períodos de verificação de limite.",
    ["note_deltas_of_idle_host_become_active"] = "Os deltas de um host inativo que se torna ativo novamente serão calculados como a diferença da mesma quantidade durante a última verificação e a verificação mais recente executada quando o host estava ativo antes de ficar inativo.",
    ["note_thresholds_expressed_as_delta"] = "Alguns limites são expressos como delta. Um delta é a diferença da mesma quantidade entre dois cheques consecutivos.",
    ["notes"] = "NOTAS",
    ["p2p_traffic"] = "Tráfego P2P",
    ["threshold_type"] = "Tipo de limite",
    ["thresholds_single_source"] = "%{source} %{alt_name} Limiares",
    ["throughput"] = "Taxa de transferência",
  },
  ["arp_page"] = {
    ["arp_type"] = "Tipo ARP",
  },
  ["as_details"] = {
    ["as"] = "Sistema autônomo",
    ["as_parameter_missing_message"] = "Parâmetro do sistema autônomo está ausente (internal error?)",
    ["as_timeseries_enable_message"] = "AS timeseries podem ser ativadas a partir do <A HREF=\"%{url}\">%{icon_flask} Preferências </A>. São necessários alguns minutos para ver os primeiros pontos de dados.",
    ["no_available_data_for_as"] = "Não há dados disponíveis para o AS %{asn}.",
  },
  ["as_stats"] = {
    ["autonomous_systems"] = "Sistemas autônomos",
  },
  ["categories_page"] = {
    ["search_application"] = "Aplicativo de pesquisa",
    ["target"] = "Alvo",
  },
  ["category_lists"] = {
    ["category_lists"] = "Listas de categorias",
    ["connection_time_out"] = "O tempo limite de conexão do servidor após %{duration} segundos [HTTP Code: %{err_code}]",
    ["edit_list"] = "Editar lista de categorias",
    ["enabled"] = "Ativado",
    ["error_occurred"] = "Ocorreu um erro durante a lista de downloads '%{name}': %{err}",
    ["last_update"] = "Última atualização",
    ["list_will_be_updated"] = "A lista '%{name}' será atualizado em 30 segundos.",
    ["ready_for_update"] = "Pronto para atualização",
    ["server_returned_error"] = "O servidor retornou um erro [HTTP Code: %{err_code}]",
    ["update_frequency"] = "Update Frequency",
    ["update_now"] = "Atualizar agora",
  },
  ["conf_backup"] = {
    ["conf_backup"] = "Configuração de Backup",
    ["conf_restore"] = "Restaurar Configuração",
  },
  ["contacts_page"] = {
    ["client_address"] = "Endereço do Cliente",
    ["client_contacts_initiator"] = "Contatos do cliente (Initiator)",
    ["contacts"] = "Contatos",
    ["no_client_contacts_so_far"] = "Nenhum contato de cliente até agora",
    ["no_contacts_message"] = "Nenhum contato para este host",
    ["no_server_contacts_so_far"] = "Nenhum contato do servidor até agora",
    ["server_address"] = "Endereço do servidor",
    ["server_contacts_receiver"] = "Contatos do servidor (Receiver)",
  },
  ["country_details"] = {
    ["country"] = "País",
    ["country_parameter_missing_message"] = "Parâmetro do país está ausente (internal error?)",
    ["no_available_stats_for_country"] = "Não há estatísticas disponíveis para o país %{country}",
  },
  ["country_stats"] = {
    ["hosts_by_country"] = "Hosts por país",
  },
  ["custom_categories"] = {
    ["add"] = "Adicionar",
    ["add_to_categories"] = "Adicionar a Categorias",
    ["custom_host_category"] = "Categoria de host personalizada",
    ["custom_hosts"] = "Hosts personalizados",
    ["domain_names_substrings"] = "Os nomes de domínio são interpretados como substring a serem correspondidos. <br> E.g. \"%{s1}\" corresponderá \"%{s2}\" e \"%{s3}\"",
    ["each_host_separate_line"] = "Cada host deve ser colocado em uma linha separada",
    ["edit_category_hosts"] = "Editar hosts personalizados",
    ["edit_hosts"] = "Editar hosts",
    ["host_domain_or_cidr"] = "Os hosts podem ser nomes de domínio ou endereços IPv4 / endereços de rede CIDR",
    ["select_url_category"] = "Por favor, selecione a categoria para atribuir o domínio a:",
    ["similar_host_found"] = "um host semelhante ao \"%{host}\" já está contido na %{category} categoria",
    ["the_following_is_a_list_of_hosts"] = "Segue-se uma lista de anfitriões personalizados para a %{category} categoria",
    ["the_following_url_will_be_added"] = "O seguinte domínio será adicionado:",
  },
  ["dashboard"] = {
    ["actual_traffic"] = "Tráfego real",
    ["lastday_app_traffic"] = "Visualização do último dia do tráfego de aplicativos principais",
    ["lastday_traffic"] = "Interfaces de Rede: Última Visão do Dia",
    ["realtime_app_traffic"] = "Tráfego de aplicativos principais em tempo real",
    ["realtime_traffic"] = "Interfaces de Rede: Tráfego em Tempo Real",
    ["slow_dashboard_message"] = "Demasiada latência no %{product} resposta. Considere definir uma <a href='%{url}'> taxa de atualização de estatísticas em tempo real </ a> maior.",
    ["top_local_talkers"] = "Principais locutores locais",
    ["top_remote_destinations"] = "Principais destinos remotos",
    ["traffic_dashboard"] = "Painel de tráfego",
  },
  ["db_explorer"] = {
    ["abort"] = "Abortar",
    ["all"] = "todos",
    ["app_between_talkers_pairs"] = "aplicações entre pares de falantes",
    ["app_flows_between"] = "%{app} fluxos de aplicativos entre %{peer1} e %{peer2}",
    ["app_talkers"] = "%{app} locutores",
    ["app_talkers_with"] = "%{app} palestrantes com %{peer}",
    ["application_flows"] = "Fluxos de Aplicação",
    ["applications_between"] = "Aplicações entre %{peer1} e %{peer2}",
    ["average_throughput"] = "Média de pontos",
    ["client_server_breakdown"] = "Análise de tráfego do cliente vs servidor",
    ["client_server_host"] = "Host do cliente / servidor",
    ["dns_query"] = "Consulta DNS",
    ["download_flows"] = "Fluxos de download",
    ["download_flows_limit"] = "Máximo de 1000 registros.",
    ["empty_query_response"] = "Resposta de consulta vazia (database down or query killed/timed out?)",
    ["extract_pcap"] = "Extrair pcap",
    ["filter_bpf"] = "Filtro (BPF)",
    ["first_last_seen"] = "Primeiro / último visto",
    ["flow_peers"] = "Pares de Fluxo",
    ["get_proto_talkers"] = "Obter locutores usando este aplicativo",
    ["historical_data_explorer"] = "Explorador de Dados Históricos",
    ["host_name"] = "Nome de anfitrião",
    ["host_talkers"] = "%{host} locutores",
    ["hosts_talking_proto_with"] = "Hosts falando%{proto} com {host}",
    ["http_host"] = "Host HTTP",
    ["http_method"] = "Método HTTP",
    ["interface_name"] = "Nome da instância",
    ["last_hour_flows"] = "Fluxos vistos na última hora",
    ["ms_client"] = "%{client} Senhora (client)",
    ["ms_server"] = "%{server} Senhora (server)",
    ["network_latency_breakdown"] = "Repartição de latência de rede",
    ["observation_period"] = "Período de Observação",
    ["ok_request_sent"] = "OK, pedido enviado",
    ["packet_rate"] = "Taxa média de pacotes",
    ["pcap_requests_and_status"] = "Solicitações e Status do Pcap",
    ["pcaps"] = "Pcaps",
    ["protocol_flows_between"] = "%{proto} fluxos de aplicativos entre %{peer1} e %{peer2}",
    ["protocol_id"] = "ID do aplicativo",
    ["query_in_progress"] = "Consulta de banco de dados em andamento, aguardando para receber resultados...",
    ["request_failed"] = "Pedido falhou",
    ["response_code"] = "Código de resposta",
    ["search_flows"] = "Fluxos de pesquisa",
    ["selected_saved"] = "Selecione salvo",
    ["server_name"] = "Nome do servidor",
    ["summary"] = "Resumo",
    ["talkers_with_this_host"] = "Locutores com este host",
    ["task_id"] = "ID da tarefa",
    ["this_flow_has_been_reset"] = "Esse fluxo foi redefinido e provavelmente o aplicativo do servidor está inativo",
    ["this_flow_is_active"] = "Esse fluxo está ativo",
    ["this_flow_is_completed"] = "Esse fluxo é concluído e expirará em breve",
    ["top_flows_ipv4"] = "Principais fluxos IPv4 [%{date_from} - %{date_to}]",
    ["top_flows_ipv6"] = "Principais fluxos IPv6 [%{date_from} - %{date_to}]",
    ["top_proto_ipv4_flows"] = "Topo %{proto} Fluxos IPv4",
    ["top_proto_ipv6_flows"] = "Topo %{proto} Fluxos IPv6",
    ["total_flows"] = "Fluxos Totais",
    ["total_packets"] = "Total de pacotes",
    ["total_traffic"] = "Total de bytes",
    ["traffic_rate"] = "Taxa Média de Tráfego",
    ["traffic_received"] = "Bytes Recebidos",
    ["traffic_sent"] = "Bytes enviados",
    ["traffic_sent_to_cli"] = "Bytes enviados para clientes",
    ["traffic_sent_to_srv"] = "Bytes enviados para servidores",
    ["traffic_volume"] = "Volume de trafego",
    ["unable_to_find_flow"] = "Não foi possível encontrar o fluxo especificado",
    ["unsave"] = "Remover",
    ["vlan_id"] = "ID da VLAN",
  },
  ["delete_data"] = {
    ["delete_active_interface_confirmation"] = "Tem certeza de que deseja excluir todos os dados persistentes associados a %{ifname}? A exclusão de dados será realizada após %{product} reiniciar. Reiniciar %{product} para tornar eficaz a eliminação.",
    ["delete_active_interface_data_failed"] = "Não é possível excluir dados da interface ativa.",
    ["delete_active_interface_data_ok"] = "Dados para %{ifname} foi marcado com sucesso para exclusão. Reiniciar %{product} para tornar eficaz a eliminação.",
    ["delete_confirmation"] = "Tem certeza de que deseja excluir todos os dados persistentes de %{host}?",
    ["delete_failed"] = "Não é possível excluir dados para %{host}.",
    ["delete_inactive_interfaces_confirmation"] = "As seguintes interfaces estão inativas: %{interfaces_list} as seguintes interfaces estão inativas?",
    ["delete_inactive_interfaces_data_failed"] = "Não é possível excluir dados de interfaces inativas.",
    ["delete_inactive_interfaces_data_ok"] = "Dados para interfaces inativas excluídas com sucesso.",
    ["delete_ok"] = "Dados para %{host} foi eliminado com sucesso.",
    ["msg_err_invalid_host"] = "O formato do host especificado não é reconhecido.",
    ["msg_err_no_fs_data"] = "Nenhum dado persistente encontrado para o host especificado.",
    ["msg_err_unable_to_delete_dir"] = "Não é possível excluir o diretório de dados.",
    ["msg_err_unable_to_delete_ts_data"] = "Não é possível excluir dados de séries temporais.",
    ["msg_err_unknown"] = "Ocorreu um erro desconhecido.",
    ["note_persistent_data"] = "Todos os dados persistentes são excluídos. Os dados incluem contadores de tráfego, timeseries, fluxos, alertas e caches Redis.",
  },
  ["details"] = {
    ["additional_mac_address"] = "Endereço MAC adicional",
    ["address_resolution_protocol"] = "Protocolo de Resolução de Endereço",
    ["ago"] = "atrás",
    ["alerts"] = "Alertas",
    ["arp_replies"] = "Respostas ARP",
    ["arp_requests"] = "Solicitações ARP",
    ["as_client"] = "cliente As",
    ["as_server"] = "Server As",
    ["device_port"] = "Porta do dispositivo",
    ["device_type"] = "Tipo de dispositivo",
    ["first_last_seen"] = "Primeiro / último visto",
    ["first_observed_on"] = "Primeiro observado em",
    ["flow_snmp_localization"] = "Localização de fluxo SNMP",
    ["flows_dropped_by_bridge"] = "Fluxos bloqueados devido a políticas de tráfego",
    ["flows_non_packet_iface"] = "Fluxos Ativo Recentemente / Total / Total Anomalous",
    ["flows_packet_iface"] = "Fluxos: Ativo / Total / Baixo Goodput / Anômalo / Não Alcance",
    ["flows_packet_pcap_dump_iface"] = "Fluxos / Total Ativo / Total Anômalo",
    ["further_host_names_information"] = "Nomes de Host Adicionais",
    ["goodput"] = "Goodput",
    ["host_pool"] = "Pool de host",
    ["host_purged"] = "Este host não está mais ativo e deveria ter sido removido da memória",
    ["host_snmp_localization"] = "Localização SNMP",
    ["input_device_port"] = "Porta de entrada do dispositivo",
    ["keep_alive"] = "Mantenha vivo",
    ["label_blacklisted_host"] = "Na lista negra",
    ["label_local_host"] = "Local",
    ["label_private_ip"] = "Privado",
    ["label_remote"] = "Controlo remoto",
    ["label_system_ip"] = "IP do sistema",
    ["lost"] = "Perdido",
    ["note"] = "NOTA",
    ["note_hosts_located_snmp_device"] = "Hosts estão localizados em dispositivos SNMP usando o <A HREF=%{url}>Bridge MIB</A>.",
    ["out_of_order"] = "Fora de serviço",
    ["output_device_port"] = "Porta de saída do dispositivo",
    ["rcvd"] = "Rcvd",
    ["retransmissions"] = "Retransmissões",
    ["router_access_point_mac_address"] = "(Router/AccessPoint) Endereço MAC",
    ["sent_vs_received_traffic_breakdown"] = "Distribuição de tráfego enviada vs. recebida",
    ["show_hosts"] = "mostra Hosts",
    ["source"] = "Fonte",
    ["source_id"] = "ID da fonte",
    ["tcp_packets_sent_analysis"] = "Análise Enviada dos Pacotes TCP",
    ["total_traffic"] = "Tráfego total",
    ["traffic_sent_received"] = "Tráfego enviado / recebido",
    ["vlan_id"] = "ID de VLAN",
    ["whois_lookup"] = "Whois Lookup",
  },
  ["device_protocols"] = {
    ["alert"] = "Alerta de gatilho",
    ["alerts_disabled_msg"] = "Os aplicativos de dispositivos configurados são usados apenas para gerar alertas de aplicativos do dispositivo quando um dispositivo está fazendo tráfego de determinados aplicativos que ele não deveria usar. Certifique-se de ativar esses alertas do <A HREF=\"%{url}\"><i classe=\"fas fa-flask\"></i> Preferências</A>.",
    ["device_protocol_policy"] = "Política de Aplicativo do Dispositivo",
    ["device_protocols"] = "Aplicativos de dispositivos",
    ["devtype_as_proto_client"] = "%{devtype} as <i>%{proto}</i> cliente",
    ["devtype_as_proto_server"] = "%{devtype} as <i>%{proto}</i> servidor",
    ["filter_device_protocols"] = "%{filter} Aplicativos de dispositivos",
    ["ok"] = "Aceitável",
  },
  ["device_types"] = {
    ["iot"] = "IoT",
    ["laptop"] = "Computador portátil",
    ["multimedia"] = "Multimídia",
    ["nas"] = "NAS",
    ["networking"] = "Roteador / switch",
    ["phone"] = "telefone",
    ["printer"] = "Impressora",
    ["tablet"] = "Comprimido",
    ["tv"] = "TV",
    ["unknown"] = "Desconhecido",
    ["video"] = "Video",
    ["wifi"] = "Rede sem fio",
    ["workstation"] = "Computador",
  },
  ["dhcp"] = {
    ["delete_range"] = "Excluir intervalo DHCP",
    ["delete_range_confirm"] = "Você realmente deseja excluir o intervalo DHCP configurado %{range} ?",
    ["dhcp_configuration_note"] = "Esta página lista os intervalos DHCP configurados para esta interface. Estes devem corresponder à configuração real do servidor DHCP em uso",
    ["invalid_ip_address"] = "Endereço IP inválido",
    ["no_dhcp_ranges"] = "Nenhum intervalo DHCP configurado.",
  },
  ["discover"] = {
    ["device"] = "Dispositivo",
    ["discovered_devices"] = "Descoberto %{manuf} %{sys} %{dev} Dispositivos",
    ["err_unable_to_arp_discovery"] = "Não é possível iniciar a descoberta de rede ARP",
    ["error_no_discovery_cached"] = "Nenhum dado de descoberta foi armazenado em cache.",
    ["error_unable_to_decode_json"] = "Não é possível decodificar dados de descoberta do cache JSON.",
    ["ghost_icon_descr"] = "o %{ghost_icon} ícone destaca anfitriões fantasma (i.e. they do not belong to the interface IP address network)",
    ["network_discovery"] = "Descoberta de rede",
    ["network_discovery_datetime"] = "Última descoberta de rede",
    ["network_discovery_not_enabled"] = "Descoberta de rede em andamento",
  },
  ["dns_page"] = {
    ["dns_breakdown"] = "Divisão de DNS",
    ["dns_query_sent_distribution"] = "Distribuição Enviada de Consulta DNS",
    ["error_replies"] = "Respostas de erro",
    ["note"] = "NOTA",
    ["note_dns_ratio"] = "Idealmente, a relação solicitação / resposta do DNS deve ser 1 (one reply per request). Quando muito abaixo disso, há questões que devem ser investigadas, pois significa que o número de respostas recebidas é muito menor do que o esperado e isso pode indicar que estamos usando resolvedores de DNS sem resposta ou que eles estão mal configurados. (e.g. they have been move to another IP).",
    ["positive_replies"] = "Respostas positivas ",
    ["queries"] = "Consultas",
    ["ratio"] = "Ratio",
    ["rcvd"] = "Rcvd",
    ["replies"] = "Respostas",
    ["reply_breakdown"] = "Repartição de resposta",
    ["request_vs_reply"] = "Solicitar vs resposta",
  },
  ["entity_thresholds"] = {
    ["flow_attacker_description"] = "Número máximo de fluxos enviados / s nos quais um host é considerado um flooder",
    ["flow_attacker_title"] = "Atacante Flood Flood",
    ["flow_victim_description"] = "Número máximo de fluxos recebidos / s nos quais um host é considerado sob ataque de inundação",
    ["flow_victim_title"] = "Vítima Flood Fluxo",
    ["syn_attacker_description"] = "Número máximo de pacotes TCP SYN enviados / s nos quais um host é considerado um flooder SYN",
    ["syn_attacker_title"] = "Atacante de inundação SYN",
    ["syn_victim_description"] = "Número máximo de pacotes TCP SYN recebidos / s nos quais um host é considerado no ataque de inundação SYN",
    ["syn_victim_title"] = "Vítima de inundação SYN",
  },
  ["export_data"] = {
    ["export_json_data"] = "Exportar dados JSON",
    ["note_active_hosts"] = "Somente hosts ativos são retornados.",
    ["note_maximum_number"] = "O número máximo de hosts para download é de 32.768.",
  },
  ["flow_alerts_explorer"] = {
    ["by_target_port"] = "Por porta de destino",
    ["flow_alert_origin"] = "Origem do alerta",
    ["flow_alert_target"] = "Alvo de Alerta",
    ["label"] = "Explorador de Alertas de Fluxo",
    ["origins"] = "Origens",
    ["search"] = "Alertas de fluxo de pesquisa",
    ["summary_cli2srv"] = "Origem total para direcionar o tráfego",
    ["summary_n_origins"] = "Origens totais",
    ["summary_n_targets"] = "Metas Totais",
    ["summary_srv2cli"] = "Tráfego total de alvo para origem",
    ["summary_total"] = "Alertas de Fluxo Total",
    ["targets"] = "Alvos",
    ["type_alerts_by_type"] = "Alertas de fluxo por tipo",
    ["type_explorer"] = "Digite Explorer",
    ["visual_explorer"] = "Visual Explorer",
  },
  ["flow_details"] = {
    ["acceptable_label"] = "Aceitável",
    ["actual_peak_throughput"] = "Taxa de transferência real / máxima",
    ["additional_flow_elements"] = "Elementos de Fluxo Adicionais",
    ["alert_type"] = "Status de Fluxo",
    ["application_latency"] = "Latência do aplicativo",
    ["average_cpu_load"] = "Carga Média da CPU",
    ["bittorrent_hash"] = "BitTorrent hash",
    ["blacklisted_flow"] = "Cliente, servidor ou domínio está na lista negra",
    ["c_ip_addresses"] = "Endereços IP C",
    ["call_canceled"] = "Chamada cancelada",
    ["call_completed"] = "Chamada Concluída",
    ["call_error"] = "Erro de Chamada",
    ["call_id"] = "ID de chamada",
    ["call_initiator"] = "Iniciador de chamadas",
    ["call_quality_indicators"] = "Chame Indicadores de Qualidade",
    ["call_started"] = "Chamada iniciada",
    ["call_state"] = "Estado da chamada",
    ["called_party"] = "Festa Chamada",
    ["cancel_bye_failure_reason_cause"] = "Motivo da Razão do Cancelamento / Bye / Falha",
    ["certificates_not_match"] = "Certificados não correspondem",
    ["client_process_information"] = "Informação do processo do cliente",
    ["client_requested"] = "Cliente solicitado",
    ["computed_as_tcp_window_size_rtt"] = "Computado como tamanho da janela TCP / RTT",
    ["could_not_add_host_to_category"] = "Não foi possível adicionar o host \"%{host}\" ao \"%{category}\" category.",
    ["desirable_label"] = "Desejável",
    ["dns_invalid_query"] = "Consulta DNS inválida",
    ["dns_query"] = "Consulta DNS",
    ["drop_flow_traffic_btn"] = "Tráfego de Fluxo de Gota",
    ["dropped_packets"] = "Pacotes Soltos",
    ["dtmf_tones_sent"] = "Tons DTMF enviados durante a chamada",
    ["dump_flow_traffic"] = "Tráfego de fluxo de descarga",
    ["elephant_exceeded"] = "Superando %{vol}",
    ["elephant_flow_descr"] = "Os fluxos de elefantes são aqueles que transferem mais do que uma certa quantidade configurada de dados. Administradores podem configurar fluxos de elefantes nas preferências.",
    ["elephant_flow_l2r"] = "Fluxo de Elefante (Local to Remote)",
    ["elephant_flow_r2l"] = "Fluxo de Elefante (Remote to Local)",
    ["first_last_flow_sequence"] = "Primeira / última sequência de fluxo",
    ["flow_active_msg"] = "O fluxo está ativo.",
    ["flow_blocked_by_bridge"] = "Fluxo bloqueado devido a políticas configuradas",
    ["flow_cannot_be_found_message"] = "Este fluxo não pode ser encontrado.",
    ["flow_completed_msg"] = "O fluxo está fechado.",
    ["flow_connecting_msg"] = "O fluxo está conectando.",
    ["flow_details"] = "Detalhes do Fluxo",
    ["flow_emitted"] = "Fluxo emitido quando a interface de rede foi alertada",
    ["flow_marker"] = "Marcador de fluxo",
    ["flow_peer_roles_inaccurate_msg"] = "O fluxo está ativo, no entanto, o início do fluxo não foi visto e os papéis dos pares (client/server) pode ser impreciso",
    ["flow_peers_client_server"] = "Pares de Fluxo [ Client / Server ]",
    ["flow_quota"] = "Cota de Fluxo",
    ["flow_reset_by_resetter_msg"] = "Fluxo redefinido pelo %{resetter}.",
    ["flow_reset_msg"] = "Esse fluxo foi redefinido",
    ["flow_shapers"] = "Shapers de fluxo",
    ["flow_traffic_is_dropped"] = "Tráfego de fluxo é descartado",
    ["forward"] = "frente",
    ["gsm_cell_identifier"] = "Identificador de célula GSM",
    ["gsm_cell_lac"] = "Célula GSM LAC (Location Area Code)",
    ["host_successfully_added_to_category"] = "Host \"%{host}\" adicionado com sucesso ao <a href=\"%{url}\">%{category}</a> categoria. Apenas novos fluxos serão afetados pela regra.",
    ["http_method"] = "Método HTTP",
    ["icmp_info"] = "Informações do ICMP",
    ["imsi"] = "IMSI (International mobile Subscriber Identity)",
    ["io_wait_time_percentage"] = "Porcentagem de tempo de espera de I/O ",
    ["jitter"] = "Jitter",
    ["longlived_exceeded"] = "Superando %{amount}",
    ["longlived_flow"] = "Fluxo Longo Prazo",
    ["longlived_flow_descr"] = "Fluxos de Longo Prazo são aqueles que duram mais que um determinado período de tempo configurado. Administradores podem configurar fluxos de elefantes nas preferências.",
    ["looks_like_idle_flow_message"] = "Isso parece um <font color=red>fluxo inativo</font> com transmissões periódicas apenas para mantê-lo vivo.",
    ["lost_packets"] = "Pacotes Perdidos",
    ["low_goodput"] = "Low Goodput",
    ["max_estimated_tcp_throughput"] = "Max (Estimated) Taxa de Transferência TCP",
    ["max_packet_interarrival_time"] = "Tempo de chegada do pacote máximo",
    ["memory_actual_peak"] = "Memória real / pico",
    ["normal"] = "Normal",
    ["not_recommended_label"] = "Não recomendado",
    ["now_purged"] = "Esse fluxo não está mais ativo e deveria ter sido removido da memória.",
    ["nsapi"] = "NSAPI",
    ["ongoing_call"] = "Chamada em Andamento",
    ["packet_inter_arrival_time"] = "Hora de chegada entre pacotes <br>[ Min / Avg / Max ]",
    ["payload_type"] = "Tipo de carga",
    ["process_information_report_warning"] = "O relatório de informações do processo é limitado, a menos que você use ntopng com <A HREF='%{url}'>nProbe</A> e o plugin sprobe",
    ["process_pid_name"] = "Processo PID / Nome",
    ["profile_name"] = "Nome do perfil",
    ["pseudo_mos"] = "(Pseudo) MOS",
    ["r_factor"] = "R-Factor",
    ["reach_connection_label"] = "Conexão de alcance",
    ["remote_to_remote"] = "Cliente Remoto e Servidor Remoto",
    ["response_code"] = "Código de resposta",
    ["reverse"] = "reverso",
    ["round_trip_time"] = "Tempo de ida e volta",
    ["rtp_codecs"] = "Codecs RTP",
    ["rtp_flow"] = "Fluxo RTP",
    ["rtp_protocol_information"] = "Informação do Protocolo RTP",
    ["rtp_stream_peers"] = "Pares do córrego RTP",
    ["rtp_transit_in_out"] = "RTP Transit IN / OUT",
    ["rtt_breakdown"] = "Repartição do tempo de ida e volta",
    ["rtt_distance"] = "Distância estimada do cliente / servidor",
    ["sac_service_area_code"] = "SAC (Service Area Code)",
    ["server_certificate"] = "Certificado de servidor",
    ["server_name"] = "Nome do servidor",
    ["server_process_information"] = "Informações do processo do servidor",
    ["sip_call_id"] = "SIP Call-ID",
    ["sip_protocol_information"] = "Informações do protocolo SIP",
    ["slow_application_header"] = "Cabeçalho de aplicativo lento",
    ["slow_data_exchange"] = "Troca de dados lenta",
    ["slow_tcp_connection"] = "Conexão TCP lenta",
    ["son_of_father_process"] = "filho de <a href ='%{url}'>%{proc_father_name} [pid: %{proc_father_pid}]</a>",
    ["ssh_signature"] = "Assinatura SSH",
    ["suspicious_client_device_protocol"] = "Aplicação cliente \"%{proto}\" não é permitido pelo configurado <a href=\"%{url}\">%{devtype} política de aplicação</a>",
    ["suspicious_server_device_protocol"] = "Aplicação do servidor \"%{proto}\" não é permitido pelo configurado <a href=\"%{url}\">%{devtype} política de aplicação</a>",
    ["suspicious_tcp_probing"] = "Pesquisa TCP Suspeita",
    ["suspicious_tcp_syn_probing"] = "Sondagem TCP SYN suspeita",
    ["sync_source_id"] = "Sincronizar ID da fonte",
    ["tcp_connection_issues"] = "Problemas de conexão TCP (Retransmission, OOO, Lost)",
    ["tcp_connection_refused"] = "Conexão TCP recusada",
    ["tcp_packet_analysis"] = "Análise de pacotes TCP",
    ["throughput_trend"] = "Tendência de Throughput",
    ["tls_certificate"] = "Certificado TLS",
    ["tls_certificate_mismatch"] = "Incompatibilidade de certificado TLS",
    ["unknown_status"] = "Status desconhecido (%{status})",
    ["url"] = "URL",
    ["user_name"] = "Nome de usuário",
    ["vm_page_faults"] = "Falhas de página da VM",
    ["web_mining_detected"] = "O site é conhecido por criptomoedas de mineração em dispositivos clientes",
  },
  ["flow_devices"] = {
    ["active_sflow"] = "Dispositivos ativos do sFlow",
    ["all_device_ports"] = "Todos %{device} Portos",
    ["all_flow_devices"] = "Todos os dispositivos de fluxo",
    ["all_sflow_devices"] = "Todos os dispositivos sFlow",
    ["duplex"] = "Duplex",
    ["flow_device_x"] = "Dispositivo de fluxo %{device}",
    ["full_duplex"] = "Completo-Duplex",
    ["half_duplex"] = "Meio duplex",
    ["in_errors"] = "Em erros",
    ["note_condition_1"] = "Dispositivo %{device} deve suportar SNMP e deve ser configurado no <a href=\"%{url}\">SNMP</a> página de dispositivos",
    ["note_condition_2"] = "Os timeseries de SNMP e dispositivos de fluxo devem ser ativados a partir do <A HREF=\"%{url}\"><i class=\"fas fa-flask\"></i> Preferências</A> (Expert View)",
    ["note_zmq_fields1"] = "Os dispositivos de fluxo são determinados usando campos do ZMQ %%EXPORTER_IPV4_ADDRESS and %%NPROBE_IPV4_ADDRESS. Quando ambos os campos estão disponíveis, o primeiro tem precedência sobre o último",
    ["note_zmq_fields2"] = "As interfaces de dispositivos de fluxo são determinadas usando campos do ZMQ %%INPUT_SNMP and %%OUTPUT_SNMP",
    ["note_zmq_fields3"] = "Os dispositivos sFlow são determinados usando o dispositivo de campo sFlowIP recebido via ZMQ (topic 'counter')",
    ["note_zmq_fields4"] = "As interfaces dos dispositivos sFlow são determinadas usando o campo ifIndex recebido via ZMQ (topic 'counter')",
    ["out_errors"] = "Erros de saída",
    ["flow_exporter_devices"] = "Dispositivos de Exportação de Fluxo",
    ["exporter_ip"] = "Exportador de Fluxo IP",
    ["promisc"] = "Promisc",
    ["sflow_device_x"] = "Dispositivo sFlow %{device}",
    ["sflow_snmp_ratio"] = "Contadores / Relação SNMP",
    ["sflow_snmp_ratio_descr"] = "A razão Contadores / SNMP é calculada dividindo o tráfego total da interface obtido usando amostras de contador sFlow, pelo tráfego total da mesma interface lida via SNMP.",
    ["snmp_description"] = "Descrição SNMP",
    ["snmp_devmodel"] = "Modelo de dispositivo SNMP",
    ["snmp_devname"] = "Nome do dispositivo SNMP",
    ["snmp_location"] = "Localização SNMP",
    ["snmp_ratio"] = "Taxa de fluxo / SNMP",
    ["snmp_ratio_descr"] = "A taxa de fluxo / SNMP é calculada dividindo o tráfego total da interface obtido usando fluxos, pelo tráfego total da mesma interface lida via SNMP. Como na análise baseada em fluxo, os cabeçalhos não IP e da camada 2 não são contabilizados, <br>typical valores de proporção estão na faixa de 0.8..0.9 (i.e. 0.9 means that 90%% of the received traffic as observed via SNMP has been reported in flows).<br>A taxa é calculada por hora somente se as seguintes condições forem atendidas",
    ["this_page_contains_couters"] = "Esta página contém contadores de interface, uma vez que foram coletados via sFlow. Se o SNMP estiver configurado, você também poderá ver o <A HREF=\"%{url}\">SNMP view</A> deste dispositivo",
    ["timeseries_descr"] = "Timeseries de dispositivos de fluxo podem ser ativados <a href=\"%{url}\"><i class=\"fas fa-flask\"></i> Preferências </a>. São necessários alguns minutos para ver os primeiros pontos de dados",
  },
  ["flow_fields_description"] = {
    ["appl_latency_ms"] = "Latência do aplicativo (msec), a.k.a. tempo de resposta do servidor",
    ["application_id"] = "ID do aplicativo coletado (Cisco or IXIA)",
    ["application_name"] = "Palo Alto App-Id",
    ["biflow_direction"] = "1 =iniciador, 2 =reversionInitiator",
    ["bittorrent_hash"] = "BITTORRENT hash",
    ["client_nw_latency_ms"] = "Rede RTT / 2 cliente <-> nprobe (msec)",
    ["cumulative_icmp_type"] = "OR cumulativo de pacotes do tipo ICMP",
    ["dhcp_client_ip"] = "Endereço IPv4 do cliente atribuído por DHCP",
    ["dhcp_client_mac"] = "MAC do cliente DHCP",
    ["dhcp_client_name"] = "Nome do cliente DHCP",
    ["dhcp_message_type"] = "Tipo de mensagem DHCP",
    ["dhcp_remote_id"] = "ID remoto do agente DHCP",
    ["dhcp_subscriber_id"] = "ID do assinante DHCP",
    ["diameter_clr_cancel_type"] = "DIÂMETRO Tipo de Cancelamento",
    ["diameter_clr_flags"] = "DIAMETER CLR Flags",
    ["diameter_exp_res_result_code"] = "DIÂMETRO Resposta Experimental Result Code",
    ["diameter_exp_res_vendor_id"] = "DIAMETER ID do fornecedor do resultado experimental de resposta",
    ["diameter_hop_by_hop_id"] = "DIÂMETRO Hop by Hop Identifier",
    ["diameter_req_msg_type"] = "DIAMETER Solicitar tipo de mensagem",
    ["diameter_req_origin_host"] = "Pedido de Host DIAMETER Origin",
    ["diameter_req_user_name"] = "DIAMETER Solicitar nome de usuário",
    ["diameter_rsp_msg_type"] = "DIAMETER Tipo de mensagem de resposta",
    ["diameter_rsp_origin_host"] = "DIAMETER Resposta do host de origem",
    ["diameter_rsp_result_code"] = "DIAMETER Código do Resultado da Resposta",
    ["direction"] = "Direção do fluxo [0=src->dst, 1=dst->src]",
    ["dns_num_answers"] = "DNS # de respostas retornadas",
    ["dns_query"] = "Consulta DNS",
    ["dns_query_id"] = "ID da transação da consulta de DNS",
    ["dns_query_type"] = "Tipo de consulta DNS (e.g. 1=A, 2=NS..)",
    ["dns_response"] = "Resposta de DNS(s)",
    ["dns_ret_code"] = "Código de retorno DNS (e.g. 0=no error)",
    ["dns_ttl_answer"] = "TTL do primeiro registro A (if any)",
    ["dot1q_dst_vlan"] = "VLAN de destino (outer VLAN in QinQ)",
    ["dot1q_src_vlan"] = "VLAN de origem (outer VLAN in QinQ)",
    ["downstream_session_id"] = "Identificador de sessão a jusante (e.g. L2TP) ou 0 se desconhecido",
    ["downstream_tunnel_id"] = "Identificador de túnel a jusante (e.g. GTP TEID, VXLAN VNI) ou 0 se desconhecido",
    ["dst_as"] = "Destino BGP AS",
    ["dst_as_map"] = "Nome da organização para DST_AS",
    ["dst_as_path_1"] = "Posição do caminho Dest AS 1",
    ["dst_as_path_10"] = "Posição do caminho Dest AS 10",
    ["dst_as_path_2"] = "Posição do caminho Dest AS 2",
    ["dst_as_path_3"] = "Posição do caminho Dest AS 3",
    ["dst_as_path_4"] = "Posição do caminho Dest AS 4",
    ["dst_as_path_5"] = "Posição do caminho Dest AS 5",
    ["dst_as_path_6"] = "Posição do caminho Dest AS 6",
    ["dst_as_path_7"] = "Posição do caminho Dest AS 7",
    ["dst_as_path_8"] = "Posição do caminho Dest AS 8",
    ["dst_as_path_9"] = "Posição do caminho Dest AS 9",
    ["dst_father_proc_name"] = "Nome do processo pai Dst",
    ["dst_father_proc_pid"] = "Dst pai processo PID",
    ["dst_fragments"] = "Pacotes numéricos fragmentados dst-> src",
    ["dst_ip_city"] = "Cidade onde o dst IP está localizado",
    ["dst_ip_country"] = "País onde o dst IP está localizado",
    ["dst_ip_lat"] = "Latitude onde o dst IP está localizado",
    ["dst_ip_long"] = "Longitude onde o dst IP está localizado",
    ["dst_proc_actual_memory"] = "Dst processa a memória real (bytes)",
    ["dst_proc_average_cpu_load"] = "Carga média do processo Dst (%% * 100)",
    ["dst_proc_name"] = "Nome do processo Dst",
    ["dst_proc_num_page_faults"] = "Dst process numfaces de página",
    ["dst_proc_pctg_iowait"] = "Tempo de processamento do processo Src %% (%% * 100)",
    ["dst_proc_peak_memory"] = "Memória de pico do processo Dst (bytes)",
    ["dst_proc_pid"] = "Processo DST PID",
    ["dst_proc_uid"] = "UID do processo Dst",
    ["dst_proc_user_name"] = "Nome do usuário do processo Dst",
    ["dst_to_src_avg_throughput"] = "Dst para src média thpt (bps)",
    ["dst_to_src_max_throughput"] = "Dst para src max thpt (bps)",
    ["dst_to_src_min_throughput"] = "Dst para src min thpt (bps)",
    ["dst_tos"] = "TOS/DSCP (dst->src)",
    ["dst_vlan"] = "VLAN de destino (inner VLAN in QinQ)",
    ["duration_in"] = "Duração do fluxo de cliente para servidor (msec)",
    ["duration_out"] = "Duração do fluxo de cliente para servidor (msec)",
    ["engine_id"] = "Id do mecanismo de comutação de fluxo",
    ["engine_type"] = "Motor de comutação de fluxo",
    ["firewall_event"] = "Evento de Firewall 0=ignore, 1=fluxo criado, 2=fluxo excluído, 3=fluxo negado, 4=alerta de fluxo, 5=atualização de fluxo",
    ["first_switched"] = "SysUptime (ms) do primeiro fluxo pkt",
    ["flow_active_timeout"] = "Tempo limite de atividade das entradas do cache de fluxo",
    ["flow_duration_microseconds"] = "Duração do fluxo (usec)",
    ["flow_duration_milliseconds"] = "Duração do fluxo (msec)",
    ["flow_end_microseconds"] = "uSec (epoch) do primeiro pacote de fluxo",
    ["flow_end_milliseconds"] = "Msec (epoch) do último pacote de fluxo",
    ["flow_end_sec"] = "Segundos (epoch) do último pacote de fluxo",
    ["flow_id"] = "Identificador de Fluxo Serial",
    ["flow_inactive_timeout"] = "Tempo limite de inatividade das entradas do cache de fluxo",
    ["flow_proto_port"] = "Porta L7 que identifica o aplicativo de fluxo ou 0 se desconhecido",
    ["flow_server_name"] = "Nome do servidor de fluxo (if known)",
    ["flow_start_microseconds"] = "uSec (epoch) do primeiro pacote de fluxo",
    ["flow_start_milliseconds"] = "Msec (epoch) do primeiro pacote de fluxo",
    ["flow_start_sec"] = "Segundos (epoch) do primeiro pacote de fluxo",
    ["flow_user_name"] = "Nome de usuário do fluxo do túnel (if known)",
    ["frame_length"] = "Comprimento da moldura original L2",
    ["ftp_command"] = "Comando do cliente FTP",
    ["ftp_command_ret_code"] = "Código de retorno do comando do cliente FTP",
    ["ftp_login"] = "Login do cliente de FTP",
    ["ftp_password"] = "Senha do cliente FTP",
    ["gtpv0_apn_name"] = "GTPv0 APN Name",
    ["gtpv0_end_user_ip"] = "Endereço IP do usuário final GTPv0",
    ["gtpv0_end_user_msisdn"] = "GTPv0 End User MSISDN",
    ["gtpv0_rai_cell_lac"] = "Código de área da localização da célula GTPv0",
    ["gtpv0_rai_cell_rac"] = "Código de área de roteamento de células GTPv0",
    ["gtpv0_rai_mcc"] = "Código do país móvel GTPv0",
    ["gtpv0_rai_mnc"] = "Código de rede móvel GTPv0",
    ["gtpv0_req_msg_type"] = "Tipo de mensagem de solicitação GTPv0",
    ["gtpv0_response_cause"] = "Causa GTPv0 de Operação",
    ["gtpv0_rsp_msg_type"] = "Tipo de mensagem de resposta GTPv0",
    ["gtpv0_tid"] = "Identificador de túnel GTPv0",
    ["gtpv1_apn_name"] = "GTPv1 APN Name",
    ["gtpv1_c2s_teid_ctrl"] = "GTPv1 Client-> Controle TunnelId do Servidor",
    ["gtpv1_c2s_teid_data"] = "GTPv1 Client->Server TunnelId Data",
    ["gtpv1_end_user_imei"] = "IMEI do usuário final do GTPv1",
    ["gtpv1_end_user_imsi"] = "IMSI do usuário final do GTPv1",
    ["gtpv1_end_user_ip"] = "Endereço IP do usuário final GTPv1",
    ["gtpv1_end_user_msisdn"] = "GTPv1 Usuário final MSISDN",
    ["gtpv1_rai_lac"] = "GTPv1 Código da área de localização da RAI",
    ["gtpv1_rai_mcc"] = "GTPv1 Código de país móvel da RAI",
    ["gtpv1_rai_mnc"] = "GTPv1 Código da Rede Móvel RAI",
    ["gtpv1_rai_rac"] = "GTPv1 Código da área de roteamento RAI",
    ["gtpv1_rat_type"] = "GTPv1 RAT Type",
    ["gtpv1_req_msg_type"] = "Tipo de mensagem de solicitação GTPv1",
    ["gtpv1_response_cause"] = "Causa GTPv1 de Operação",
    ["gtpv1_rsp_msg_type"] = "Tipo de mensagem de resposta GTPv1",
    ["gtpv1_s2c_teid_ctrl"] = "GTPv1 Server-> Controle TunnelId do Cliente",
    ["gtpv1_s2c_teid_data"] = "GTPv1 Server-> Dados TunnelId do Cliente ",
    ["gtpv1_uli_cell_ci"] = "CI de célula GTPv1 ULI",
    ["gtpv1_uli_cell_lac"] = "Código de área da localização da célula GTPv1 ULI",
    ["gtpv1_uli_mcc"] = "Código de país móvel GTPv1 ULI",
    ["gtpv1_uli_mnc"] = "Código de rede móvel GTPv1 ULI",
    ["gtpv1_uli_sac"] = "GTPv1 ULI SAC",
    ["gtpv2_apn_name"] = "GTPv2 Nome APN",
    ["gtpv2_c2s_s1u_gtpu_ip"] = "GTPv2 Client->Svr S1U GTPU IP",
    ["gtpv2_c2s_s1u_gtpu_teid"] = "GTPv2 Client->Svr S1U GTPU TEID",
    ["gtpv2_c2s_s5_s8_gtpc_ip"] = "GTPv2 Client->Svr S5/S8 GTPC IP",
    ["gtpv2_c2s_s5_s8_gtpu_ip"] = "GTPv2 Client->Srv S5/S8 PGW GTPU IP",
    ["gtpv2_c2s_s5_s8_gtpu_teid"] = "GTPv2 Client->Srv S5/S8 PGW GTPU TEID",
    ["gtpv2_c2s_s5_s8_sgw_gtpu_ip"] = "GTPv2 Client->Srv S5/S8 SGW GTPU IP",
    ["gtpv2_c2s_s5_s8_sgw_gtpu_teid"] = "GTPv2 Client->Srv S5/S8 SGW GTPU TEID",
    ["gtpv2_end_user_imei"] = "IMEI do usuário final do GTPv2",
    ["gtpv2_end_user_imsi"] = "IMSI do usuário final do GTPv2",
    ["gtpv2_end_user_msisdn"] = "GTPv2 End User MSISDN",
    ["gtpv2_pdn_ip"] = "Endereço IP do PDN GTPV2",
    ["gtpv2_rat_type"] = "Tipo de RATO GTPv2",
    ["gtpv2_req_msg_type"] = "Tipo de mensagem de solicitação GTPv2",
    ["gtpv2_response_cause"] = "Causa GTPv2 de Operação",
    ["gtpv2_rsp_msg_type"] = "Tipo de mensagem de resposta GTPv2",
    ["gtpv2_s2c_s1u_gtpu_ip"] = "GTPv2 Srv->Client S1U GTPU IP",
    ["gtpv2_s2c_s1u_gtpu_teid"] = "GTPv2 Srv->Client S1U GTPU TEID",
    ["gtpv2_s2c_s5_s8_gtpc_ip"] = "GTPv2 Svr->Client S5/S8 GTPC IP",
    ["gtpv2_s2c_s5_s8_gtpu_ip"] = "GTPv2 Srv->Client S5/S8 PGW GTPU IP",
    ["gtpv2_s2c_s5_s8_gtpu_teid"] = "GTPv2 Srv->Client S5/S8 PGW GTPU TEID",
    ["gtpv2_s2c_s5_s8_sgw_gtpu_ip"] = "GTPv2 Srv->Client S5/S8 SGW GTPU IP",
    ["gtpv2_s2c_s5_s8_sgw_gtpu_teid"] = "GTPv2 Srv->Client S5/S8 SGW GTPU TEID",
    ["gtpv2_s5_s8_gtpc_teid"] = "GTPv2 S5/S8 SGW GTPC TEIDs",
    ["gtpv2_uli_cell_id"] = "Identificador de célula GTPv2",
    ["gtpv2_uli_cell_tac"] = "Código de área de rastreamento GTPv2",
    ["gtpv2_uli_mcc"] = "Código do país móvel GTPv2",
    ["gtpv2_uli_mnc"] = "Código de rede móvel GTPv2",
    ["http_host"] = "Nome do Host HTTP (IXIA Host Name)",
    ["http_method"] = "MÉTODO HTTP",
    ["http_mime"] = "Tipo Mime HTTP",
    ["http_referer"] = "Referenciador HTTP",
    ["http_ret_code"] = "Código de retorno HTTP (e.g. 200, 304...)",
    ["http_site"] = "Servidor HTTP sem nome do host",
    ["http_ua"] = "Agente de Usuário HTTP",
    ["http_url"] = "HTTP URL (IXIA URI)",
    ["http_via"] = "HTTP Via",
    ["http_x_forwarded_for"] = "HTTP X-Forwarded-For",
    ["icmp_ipv4_code"] = "Código ICMP",
    ["icmp_ipv4_type"] = "Tipo ICMP",
    ["icmp_type"] = "Tipo ICMP * 256 + código ICMP",
    ["imap_login"] = "Remetente de correio",
    ["in_bytes"] = "Bytes de fluxo de entrada (src->dst)",
    ["in_dst_mac"] = "Endereço MAC de destino",
    ["in_pkts"] = "Pacotes de fluxo de entrada (src->dst)",
    ["in_src_mac"] = "Endereço MAC de origem",
    ["in_src_osi_sap"] = "Fonte OSI SAP (OSI Traffic Only)",
    ["ingress_vrfid"] = "Ingress VRF ID",
    ["input_snmp"] = "Interface de entrada SNMP idx",
    ["ip_protocol_version"] = "[4=IPv4][6=IPv6]",
    ["ipfix_sampling_algorithm"] = "Algoritmo de amostragem",
    ["ipv4_dst_addr"] = "Endereço de destino IPv4",
    ["ipv4_dst_mask"] = "Máscara de sub-rede de destino IPv4 (/<bits>)",
    ["ipv4_next_hop"] = "Endereço do próximo salto do IPv4",
    ["ipv4_src_addr"] = "Endereço de origem IPv4",
    ["ipv4_src_mask"] = "Máscara de sub-rede de origem IPv4 (/<bits>)",
    ["ipv6_dst_addr"] = "Endereço de destino IPv6",
    ["ipv6_dst_mask"] = "Máscara de destino IPv6",
    ["ipv6_next_hop"] = "Endereço do próximo salto do IPv6",
    ["ipv6_src_addr"] = "Endereço de origem IPv6",
    ["ipv6_src_mask"] = "Máscara de origem IPv6",
    ["l4_dst_port"] = "Porta de destino da camada 4",
    ["l4_dst_port_map"] = "Nome simbólico da porta de destino da camada 4",
    ["l4_src_port"] = "Porta de origem IPv4",
    ["l4_src_port_map"] = "Nome simbólico da porta de origem da camada 4",
    ["l4_srv_port"] = "Porta do servidor da camada 4",
    ["l4_srv_port_map"] = "Nome simbólico da porta do servidor da camada 4",
    ["l7_proto"] = "Aplicação da camada 7 (numeric)",
    ["l7_proto_name"] = "Nome da aplicação da camada 7",
    ["last_switched"] = "SysUptime (msec) do último fluxo pkt",
    ["longest_flow_pkt"] = "Maior pacote (bytes) do fluxo",
    ["max_ttl"] = "Maior fluxo TTL",
    ["min_ttl"] = "Menor fluxo TTL",
    ["mpls_label_1"] = "MPLS rótulo na posição 1",
    ["mpls_label_10"] = "MPLS rótulo na posição 10",
    ["mpls_label_2"] = "Rótulo MPLS na posição 2",
    ["mpls_label_3"] = "Rótulo MPLS na posição 3",
    ["mpls_label_4"] = "Rótulo MPLS na posição 4",
    ["mpls_label_5"] = "Rótulo MPLS na posição 5",
    ["mpls_label_6"] = "Rótulo MPLS na posição 6",
    ["mpls_label_7"] = "Rótulo MPLS na posição 7",
    ["mpls_label_8"] = "Rótulo MPLS na posição 8",
    ["mpls_label_9"] = "Rótulo MPLS na posição 9",
    ["mysql_appl_latency_usec"] = "MySQL pedido->reposta latencia (usec)",
    ["mysql_db"] = "Banco de dados MySQL em uso",
    ["mysql_query"] = "Consulta MySQL",
    ["mysql_response"] = "Resposta do servidor MySQL",
    ["mysql_server_version"] = "Versão do servidor MySQL",
    ["mysql_username"] = "Nome de usuario MySQL",
    ["netbios_query_name"] = "Consulta nome NETBIOS",
    ["netbios_query_os"] = "Consulta OS NETBIOS",
    ["netbios_query_type"] = "Consulta erro de digitação NETBIOS",
    ["netbios_response"] = "Consulta resposta NETBIOS",
    ["nprobe_ipv4_address"] = "Endereços IPv4 do host nProbe foram executados",
    ["num_pkts_1024_to_1514_bytes"] = "# pacotes cujo tamanho IP > 1024 e <= 1514",
    ["num_pkts_128_to_256_bytes"] = "# pacotes cujo tamanho IP > 128 e <= 256",
    ["num_pkts_256_to_512_bytes"] = "# pacotes cujo tamanho IP > 256 and < 512",
    ["num_pkts_512_to_1024_bytes"] = "# pacotes cujo tamanho IP > 512 and < 1024",
    ["num_pkts_over_1514_bytes"] = "# pacotes cujo tamanho IP > 1514",
    ["num_pkts_ttl_128_160"] = "# pacotes com TTL > 128 and <= 160",
    ["num_pkts_ttl_160_192"] = "# pacotes com TTL > 160 and <= 192",
    ["num_pkts_ttl_192_224"] = "# pacotes com TTL > 192 and <= 224",
    ["num_pkts_ttl_224_255"] = "# pacotes com TTL > 224 and <= 255",
    ["num_pkts_ttl_2_5"] = "# pacotes com TTL > 1 and TTL <= 5",
    ["num_pkts_ttl_32_64"] = "# pacotes com TTL > 32 and <= 64",
    ["num_pkts_ttl_5_32"] = "# pacotes com TTL > 5 and TTL <= 32",
    ["num_pkts_ttl_64_96"] = "# pacotes com TTL > 64 and <= 96",
    ["num_pkts_ttl_96_128"] = "# pacotes com TTL > 96 and <= 128",
    ["num_pkts_ttl_eq_1"] = "# pacotes com TTL = 1",
    ["num_pkts_up_to_128_bytes"] = "# pacotes cujo tamanho IP <= 128",
    ["observation_point_id"] = "ID do ponto de observação",
    ["observation_point_type"] = "Tipo de ponto de observação",
    ["ooorder_in_pkts"] = "Número de pacotes de fluxo TCP fora de ordem (dst->src)",
    ["ooorder_out_pkts"] = "Número de pacotes de fluxo TCP fora de ordem (src->dst)",
    ["oracle_query"] = "Consulta Oracle",
    ["oracle_query_duration"] = "Duração de consulta Oracle (msec)",
    ["oracle_rsp_code"] = "Código de Resposta do Oracle",
    ["oracle_rsp_string"] = "String de Resposta do Oracle",
    ["oracle_username"] = "Nome de usuário Oracle",
    ["out_bytes"] = "Bytes de fluxo de saída (dst->src) [Aliado para %%DST_TO_SRC_BYTES]",
    ["out_dst_mac"] = "Endereço MAC de destino, potencialmente modificado por uma função middlebox após o ponto de observação",
    ["out_dst_osi_sap"] = "OSI destinado a SAP (OSI Traffic Only)",
    ["out_pkts"] = "Pacotes de fluxo de saída (dst->src) [Aliado para %%DST_TO_SRC_PKTS]",
    ["out_src_mac"] = "Endereço MAC de origem, potencialmente modificado por uma função middlebox após o ponto de observação",
    ["output_snmp"] = "Interface de saída SNMP idx",
    ["packet_section_offset"] = "Deslocamento de seção de pacote",
    ["packets_observed"] = "Número total de pacotes vistos",
    ["packets_selected"] = "Número de pacotes selecionados para amostragemng",
    ["payload_hash"] = "carga útil do fluxo inicial",
    ["plugin_name"] = "Nome do plugin usado por este fluxo (caso tenha)",
    ["pop_user"] = "Usuario de login POP3",
    ["post_napt_dst_transport_port"] = "Porta de transporte de destino pós-NAPT",
    ["post_napt_src_transport_port"] = "Porta de transporte de destino pós-NAPT",
    ["post_nat_dst_ipv4_addr"] = "Poste o endereço IPv4 do destino NAT",
    ["post_nat_src_ipv4_addr"] = "Poste o endereço IPv4 da fonte NAT",
    ["exporter_ipv4_address"] = "Exportador de Fluxo Endereço IPv4",
    ["exporter_ipv6_address"] = "Exportador de Fluxo Endereço IPv6",
    ["protocol"] = "Byte de protocolo IP",
    ["protocol_map"] = "Nome do protocolo IP",
    ["radius_acct_in_octets"] = "Octetos de Entrada de Contabilidade RADIUS",
    ["radius_acct_in_pkts"] = "Pacotes de Entrada de Contabilidade RADIUS",
    ["radius_acct_out_octets"] = "Octetos de Saída de Contabilidade do RADIUS",
    ["radius_acct_out_pkts"] = "Pacotes de Saída de Contabilidade RADIUS",
    ["radius_acct_session_id"] = "Nome da sessão de contabilidade do RADIUS",
    ["radius_acct_status_type"] = "Tipo de Status da Contabilidade RADIUS",
    ["radius_called_station_id"] = "ID da estação chamada RADIUS",
    ["radius_calling_station_id"] = "ID de estação de chamada do RADIUS",
    ["radius_framed_ip_addr"] = "RADIUS IP emoldurado",
    ["radius_nas_identifier"] = "RADIUS NAS Identificador",
    ["radius_nas_ip_addr"] = "Endereço IP do NAS RADIUS",
    ["radius_req_msg_type"] = "Tipo de mensagem de solicitação RADIUS",
    ["radius_rsp_msg_type"] = "Tipo de mensagem de resposta RADIUS",
    ["radius_user_imei"] = "Usuário do RADIUS MSISDN (Extension)",
    ["radius_user_imsi"] = "Usuário do RADIUS IMSI (Extension)",
    ["radius_user_name"] = "Nome de usuário do RADIUS (Access Only)",
    ["retransmitted_in_bytes"] = "Número de bytes de fluxo TCP retransmitidos (src->dst)",
    ["retransmitted_in_pkts"] = "Número de pacotes de fluxo TCP retransmitidos (src->dst)",
    ["retransmitted_out_bytes"] = "Número de bytes de fluxo TCP retransmitidos (dst->src)",
    ["retransmitted_out_pkts"] = "Número de pacotes de fluxo TCP retransmitidos (dst->src)",
    ["rtp_dtmf_tones"] = "Tons DTMF enviados (if any) durante a chamada",
    ["rtp_first_seq"] = "Primeiro Fluxo RTP Seq Number",
    ["rtp_first_ts"] = "Primeiro registro de data e hora do fluxo RTP",
    ["rtp_in_jitter"] = "RTP jitter (ms * 1000)",
    ["rtp_in_max_delta"] = "Max delta (ms*100) entre pacotes consecutivos (src->dst)",
    ["rtp_in_mos"] = "RTP pseudo-MOS (value * 100) (src->dst)",
    ["rtp_in_payload_type"] = "Tipo de carga útil RTP",
    ["rtp_in_pkt_drop"] = "Pacote descartado pelo Jitter Buffer (src->dst)",
    ["rtp_in_pkt_lost"] = "Pacote descartado pelo Jitter Buffer (src->dst)",
    ["rtp_in_r_factor"] = "RTP pseudo-R_FACTOR (value * 100) (src->dst)",
    ["rtp_in_transit"] = "RTP Transit (value * 100) (src->dst)",
    ["rtp_last_seq"] = "Último fluxo RTP Seq Number",
    ["rtp_last_ts"] = "Último registro de data e hora do fluxo RTP",
    ["rtp_mos"] = "RTP pseudo-MOS (value * 100) (average both directions)",
    ["rtp_out_jitter"] = "RTP jitter (ms * 1000)",
    ["rtp_out_max_delta"] = "Max delta (ms*100) entre pacotes consecutivos (dst->src)",
    ["rtp_out_mos"] = "RTP pseudo-MOS (value * 100) (dst->src)",
    ["rtp_out_payload_type"] = "Tipo de carga útil RTP",
    ["rtp_out_pkt_drop"] = "Pacote descartado pelo Jitter Buffer (dst->src)",
    ["rtp_out_pkt_lost"] = "Perda de pacotes no fluxo (dst->src)",
    ["rtp_out_r_factor"] = "RTP pseudo-R_FACTOR (value * 100) (dst->src)",
    ["rtp_out_transit"] = "RTP Transit (value * 100) (dst->src)",
    ["rtp_r_factor"] = "RTP pseudo-R_FACTOR (value * 100) (average both directions)",
    ["rtp_rtt"] = "Tempo de ida e volta da RTP (ms)",
    ["rtp_sip_call_id"] = "SIP call-id correspondente a este fluxo RTP",
    ["rtp_ssrc"] = "ID da origem de sincronização RTP",
    ["s1ap_cause_enb_to_mme"] = "ID da origem de sincronização RTP",
    ["s1ap_detailed_cause_enb_to_mme"] = "Causa Detalhada S1AP da ENB para a MME",
    ["s1ap_enb_ue_s1ap_id"] = "S1AP ENB Identifier",
    ["s1ap_mme_ue_s1ap_id"] = "S1AP MME Identifier",
    ["s1ap_msg_emm_type_enb_to_mme"] = "Tipo de mensagem S1AP EMM de ENB para MME",
    ["s1ap_msg_emm_type_mme_to_enb"] = "Tipo de mensagem S1AP EMM do MME para ENB",
    ["s1ap_msg_esm_type_enb_to_mme"] = "Tipo de mensagem S1AP ESM de ENB para MME",
    ["s1ap_msg_esm_type_mme_to_enb"] = "Tipo de mensagem S1AP ESM do MME para ENB",
    ["sampled_packet_id"] = "ID de pacote amostrado",
    ["sampled_packet_size"] = "Tamanho do pacote amostrado",
    ["sampling_algorithm"] = "Tipo de amostragem (deterministic/random)",
    ["sampling_interval"] = "Taxa de amostragem",
    ["sampling_population"] = "População de amostragem",
    ["sampling_size"] = "Número de pacotes para amostra",
    ["selector_id"] = "ID do seletor",
    ["selector_name"] = "Nome do sampler",
    ["server_nw_latency_ms"] = "Rede RTT / 2 nprobe <-> server (msec)",
    ["shortest_flow_pkt"] = "Pacote mais curto (bytes) do fluxo",
    ["sip_bye_ok_time"] = "Tempo SIP (epoch) de BYE OK",
    ["sip_bye_time"] = "Tempo SIP (epoch) de BYE",
    ["sip_c_ip"] = "Endereços IP SIP C",
    ["sip_call_id"] = "ID de chamada SIP",
    ["sip_call_state"] = "Estado de Chamada SIP",
    ["sip_called_party"] = "Partido Chamado SIP",
    ["sip_calling_party"] = "Iniciador de chamada SIP",
    ["sip_cancel_ok_time"] = "Tempo SIP (epoch) de CANCELAR OK",
    ["sip_cancel_time"] = "Tempo SIP (epoch) de CANCELAR",
    ["sip_invite_failure_time"] = "Tempo SIP (epoch) de INVITE FALHA",
    ["sip_invite_ok_time"] = "Tempo SIP (epoch) de CONVITE OK",
    ["sip_invite_time"] = "Tempo SIP (epoch) de CONVIDAR",
    ["sip_reason_cause"] = "Razão de Cancelamento / Bye / Falha SIP causa",
    ["sip_response_code"] = "Código de resposta a falha do SIP",
    ["sip_ringing_time"] = "Tempo SIP (epoch) de RINGING",
    ["sip_rtp_codecs"] = "Codecs SIP RTP",
    ["sip_rtp_ipv4_dst_addr"] = "SIP RTP fluxo de destino IP",
    ["sip_rtp_ipv4_src_addr"] = "SIP RTP IP de origem do fluxo",
    ["sip_rtp_l4_dst_port"] = "SIP RTP stream dest port",
    ["sip_rtp_l4_src_port"] = "SIP RTP porta de origem de fluxo",
    ["sip_trying_time"] = "Tempo SIP (epoch) de tentar",
    ["smtp_mail_from"] = "Remetente de correio",
    ["smtp_rcpt_to"] = "Destinatário do correio",
    ["src_as"] = "Fonte BGP AS",
    ["src_as_map"] = "Nome da organização para SRC_AS",
    ["src_as_path_1"] = "Posição do caminho AS ASC 1",
    ["src_as_path_10"] = "Posição do trajecto AS ASc 10",
    ["src_as_path_2"] = "Posição do caminho Src AS 2",
    ["src_as_path_3"] = "Posição de trajetória ASc Src 3",
    ["src_as_path_4"] = "Posição do caminho AS de ASC 4",
    ["src_as_path_5"] = "Posição do caminho AS de ASC 5",
    ["src_as_path_6"] = "Posição do trajecto AS ASc 6",
    ["src_as_path_7"] = "Posição do trajecto AS ASc 7",
    ["src_as_path_8"] = "Posição do trajecto AS ASc 8",
    ["src_as_path_9"] = "Posição do trajecto AS ASc 9",
    ["src_father_proc_name"] = "Nome do processo pai Src",
    ["src_father_proc_pid"] = "Processo pai Src PID",
    ["src_fragments"] = "Pacotes numéricos fragmentados src-> dst",
    ["src_ip_city"] = "Cidade onde o src IP está localizado",
    ["src_ip_country"] = "País onde o IP src está localizado",
    ["src_ip_lat"] = "Latitude onde o src IP está localizado",
    ["src_ip_long"] = "Longitude onde o src IP está localizado",
    ["src_proc_actual_memory"] = "Src processa a memória real (bytes)",
    ["src_proc_average_cpu_load"] = "Carga média do processo Src (%% * 100)",
    ["src_proc_name"] = "Nome do processo Src",
    ["src_proc_num_page_faults"] = "Processo de src num pagefaults",
    ["src_proc_pctg_iowait"] = "Tempo de processamento do processo Src %% (%% * 100)",
    ["src_proc_peak_memory"] = "Memória de pico do processo Src (bytes)",
    ["src_proc_pid"] = "Processo Src PID",
    ["src_proc_uid"] = "UID do processo Src",
    ["src_proc_user_name"] = "Nome de usuário do processo Src",
    ["src_to_dst_avg_throughput"] = "Src para dst média thpt (bps)",
    ["src_to_dst_max_throughput"] = "Src para dst max thpt (bps)",
    ["src_to_dst_min_throughput"] = "Src to dst min thpt (bps)",
    ["src_tos"] = "TOS/DSCP (src->dst)",
    ["src_vlan"] = "VLAN de origem (inner VLAN in QinQ)",
    ["ssdp_host"] = "Host do SSDP",
    ["ssdp_method"] = "Método SSDP",
    ["ssdp_server"] = "Servidor SSDP",
    ["ssdp_type"] = "Tipo SSDP",
    ["ssdp_usn"] = "SSDP USN",
    ["tcp_flags"] = "Cumulativo de todo o fluxo TCP flags",
    ["tcp_win_max_in"] = "Janela Max TCP (src->dst)",
    ["tcp_win_max_out"] = "Janela Max TCP (dst->src)",
    ["tcp_win_min_in"] = "Min TCP Window (src->dst)",
    ["tcp_win_min_out"] = "Min TCP Window (dst->src)",
    ["tcp_win_mss_in"] = "Tamanho máximo do segmento TCP (src->dst)",
    ["tcp_win_mss_out"] = "Tamanho máximo do segmento TCP (dst->src)",
    ["tcp_win_scale_in"] = "Escala de janela TCP (src->dst)",
    ["tcp_win_scale_out"] = "Escala de janela TCP (dst->src)",
    ["tls_server_name"] = "Nome do servidor TLS",
    ["total_bytes_exp"] = "Total de bytes exportados",
    ["total_flows_exp"] = "Número total de fluxos exportados",
    ["total_pkts_exp"] = "Pacotes de fluxo total exportados",
    ["untunneled_ipv4_dst_addr"] = "Endereço de destino IPv4 não canalizado",
    ["untunneled_ipv4_src_addr"] = "Endereço de origem IPv4 não canalizado",
    ["untunneled_ipv6_dst_addr"] = "Endereço de destino IPv6 não canalizado",
    ["untunneled_ipv6_src_addr"] = "Endereço de origem IPv6 não canalizado",
    ["untunneled_l4_dst_port"] = "Endereço de origem IPv6 não canalizado",
    ["untunneled_l4_src_port"] = "Porta de origem IPv4 não canalizada",
    ["untunneled_protocol"] = "Byte de protocolo IP não organizado",
    ["upstream_session_id"] = "Identificador de sessão a montante (e.g. L2TP) ou 0 se desconhecido",
    ["upstream_tunnel_id"] = "Identificador de túnel a montante (e.g. GTP TEID, VXLAN VNI) ou 0 se desconhecido",
    ["user_name"] = "Nome de usuário",
  },
  ["flows_page"] = {
    ["active_flows"] = "Ativo %{filter} Fluxos",
    ["actual_throughput"] = "Thpt real",
    ["alerted"] = "Anômalo",
    ["all_ases"] = "Todas ases",
    ["all_categories"] = "todas as categorias",
    ["all_devices"] = "Todos os exportadores de fluxo",
    ["all_flows"] = "Todos os fluxos",
    ["all_hosts"] = "Todos os Hosts",
    ["all_inIfIdx"] = "Todas as Interfaces de Entrada",
    ["all_ip_versions"] = "Todas versões",
    ["all_outIfIdx"] = "Todas as interfaces de saída",
    ["all_proto"] = "Todos Proto",
    ["all_vlan_ids"] = "Todas as VLANs",
    ["applications"] = "Aplicações",
    ["blocked"] = "Bloqueado",
    ["client_as"] = "Cliente AS",
    ["device_ip"] = "Exportador de Fluxo",
    ["direction"] = "Direção",
    ["flows"] = "%{filter} Fluxos",
    ["flows_as_client"] = "Fluxos como Cliente",
    ["flows_as_server"] = "Fluxos como Servidor",
    ["hosts"] = "Hosts",
    ["idle_flows_not_listed"] = "Fluxos ociosos não listados.",
    ["inIfIdx"] = "Interface de entrada",
    ["ip_version"] = "Versão IP",
    ["ipv4_only"] = "Somente IPv4",
    ["ipv6_only"] = "Somente IPv6",
    ["local_cli_remote_srv"] = "Cliente Local - Servidor Remoto",
    ["local_only"] = "Apenas local",
    ["local_srv_remote_cli"] = "Servidor Local - Cliente Remoto",
    ["multicast"] = "Multicast / Broadcast",
    ["network"] = " [ Network %{network} ]",
    ["non_multicast"] = "Não-Multicast / Não-Transmissão",
    ["normal"] = "Normal",
    ["one_way_multicast"] = "Multidifusão / transmissão unidirecional",
    ["one_way_non_multicast"] = "Não-Multicast de uma via / não difusão",
    ["outIfIdx"] = "Interface de saída",
    ["flow_exporters"] = "Exportadores de Fluxo",
    ["recently_active_flows"] = "Ativo recentemente %{filter} Fluxos",
    ["remote_only"] = "Somente remoto",
    ["server_as"] = "Servidor AS",
    ["sflow_devices"] = "Dispositivos sFlow",
    ["source_id"] = "ID da fonte",
    ["tcp_state"] = "Estado TCPv",
    ["tcp_state_closed"] = "Fechados",
    ["tcp_state_connecting"] = "Conectando",
    ["tcp_state_established"] = "Estabelecido",
    ["tcp_state_reset"] = "Restabelecer",
    ["tcp_state_unknown"] = "Desconhecido",
    ["total_bytes"] = "Total de Bytes",
    ["total_bytes_rcvd"] = "Total de bytes recebidos",
    ["total_bytes_sent"] = "Total de bytes enviados",
    ["total_bytes_unknown"] = "Total de Bytes de Aplicativos Desconhecidos",
    ["vlan"] = "VLAN",
  },
  ["geo_map"] = {
    ["browser_reported_home_map"] = "Localização do mapa do host relatado pelo navegador",
    ["geo_map"] = "Mapa geográfico",
    ["geolocation_error"] = "Erro de geolocalização",
    ["hosts_geomap"] = "Hosts GeoMap",
    ["latitude"] = "Latitude",
    ["longitude"] = "Longitude",
    ["note"] = "NOTE",
    ["note_active_flows"] = "Ter fluxos ativos entre pares com endereços IP públicos.",
    ["note_compiled_ntopng_with_geolocation"] = "Ter compilado o software com geolocalização e iniciado com ele.",
    ["note_google_maps_browser_api_key"] = "Uma chave da API do navegador do Google Maps pode ser necessária. Informação detalhada sobre geração de chaves <a href='%{url_google}'>can be found here</a>.<br>Uma vez gerada, a chave pode ser enviada através do <a href='%{url_prefs}'><i class=\"fas fa-flask\"></i> Preferences</a>.",
    ["note_html_browser_geolocation"] = "HTML <A HREF=%{url}>browser geolocation</A> é usado para colocar em hosts de mapa com base em locais desconhecidos.",
    ["note_requirements_visualize_maps"] = "Para visualizar os mapas, você deve",
    ["note_working_internet_connection"] = "Tenha uma conexão com a Internet funcionando.",
    ["unavailable_geolocation"] = "Geolocalização não suportada pelo seu navegador ou desativada.",
    ["using_default_location"] = "Usando localização padrão.",
  },
  ["graphs"] = {
    ["95_perc"] = "95th Perc",
    ["active_devices"] = "Dispositivos Ativos",
    ["active_flows"] = "Fluxos Ativos",
    ["active_host_contacts"] = "Contatos ativos do host",
    ["active_hosts"] = "Hosts Ativos",
    ["active_http_servers"] = "Servidores HTTP Ativos",
    ["actual_memory"] = "Memória real",
    ["arp_replies"] = "Respostas ARP",
    ["arp_requests"] = "Solicitações ARP",
    ["average"] = "Média",
    ["average_traffic"] = "Tráfego médio / seg",
    ["avg"] = "Avg",
    ["binary_operators_note"] = "Para obter mais informações sobre os indicadores EMA, SMA e RSI, confira <a href=\"%{url}\">documentação online</a>.",
    ["blocked_flows"] = "Fluxos bloqueados",
    ["custom"] = "Personalizadas",
    ["download_chart_data"] = "Baixe os dados do gráfico atuala",
    ["export_flows_as_txt"] = "Exportar fluxos como arquivo TXT",
    ["flows_vs_local_hosts"] = "Fluxos Ativos vs Hosts Locais",
    ["flows_vs_traffic"] = "Fluxos Ativos vs Tráfego",
    ["get_permanent_link"] = "Obter link permanente",
    ["graph_info"] = "Informações do gráfico",
    ["max"] = "Max",
    ["memory_vs_hosts_flows"] = "Memória de Processos vs Hosts / Fluxos",
    ["minute_interface_top_stats"] = "Estatísticas de tráfego superior de interface de minutos",
    ["note_ases_rcvd"] = "Tráfego recebeu o tráfego recebido pelo sistema autônomo.",
    ["note_ases_sent"] = "Tráfego enviado é o tráfego enviado pelo sistema autônomo.",
    ["note_ases_traffic"] = "O tráfego mostrado é enviado e recebido pelo sistema autônomo.",
    ["note_chart_zoom"] = "Clique e arraste no gráfico para aumentar o zoom, clique duas vezes para diminuir o zoom.",
    ["note_protocols_shown"] = "Aplicativos não vistos no período de tempo selecionado não são listados no menu suspenso.",
    ["num_ms_rtt"] = "Tempo de ida e volta ms",
    ["num_nfq_drops"] = "Pacotes Soltos",
    ["num_nfq_pct"] = "Preenchimento da fila %%",
    ["packet_drops"] = "Drops de pacotes",
    ["percentile"] = "95th <a href=\"%{url}\">Percentile</a>",
    ["permanent_link"] = "Link permanente",
    ["pkt_drops"] = "Pkt Drops",
    ["query_too_much_time"] = "A consulta está demorando muito para concluir",
    ["query_too_slow"] = "A consulta demorou muito tempo para concluir",
    ["query_was_aborted"] = "Consulta foi anulada",
    ["raw_flows"] = "Fluxos Brutos",
    ["raw_proto_flows"] = "Cru %{proto} Fluxos",
    ["reset_zoom"] = "Redefinir Zoom",
    ["right_axis_note"] = "(eixo direito)",
    ["rtt"] = "RTT",
    ["tcp_finack_packets"] = "Pacotes TCP FIN + ACK",
    ["tcp_packets_lost"] = "Pacotes TCP Perdidos",
    ["tcp_packets_ooo"] = "Pacotes TCP fora de ordem",
    ["tcp_packets_retr"] = "Pacotes Retransmitidos por TCP",
    ["tcp_retr_ooo_lost"] = "TCP retransmitido fora de ordem e perdido",
    ["tcp_rst_packets"] = "Pacotes TCP RST",
    ["tcp_syn_packets"] = "Pacotes TCP SYN",
    ["tcp_synack_packets"] = "Pacotes TCP SYN + ACK",
    ["the_select_timeframe_too_small_top_talkers"] = "O período de tempo selecionado é muito pequeno para determinar os principais palestrantes. Por favor, selecione pelo menos um quadro de 1 minuto.",
    ["top_clients"] = "Topo %{protocol} Clientes",
    ["top_interfaces"] = "Interfaces superiores",
    ["top_l7_contacts"] = "Topo %{protocol} L7 Contatos",
    ["top_ndpi_categories"] = "Categorias principais",
    ["top_ndpi_protocols"] = "Principais aplicativos",
    ["top_profiles"] = "Perfis principais",
    ["top_receivers"] = "Receptores Principais",
    ["top_senders"] = "Principais remetentes",
    ["top_servers"] = "Topo %{protocol} Servidores",
    ["total_misbehaving_flows"] = "Fluxos Anômalos Totais",
    ["total_unreachable_flows"] = "Fluxos Inacessíveis Totais",
    ["traffic_rxtx"] = "Tráfego RX/TX",
    ["trend"] = "Tendência",
    ["zmq_flow_coll_drops"] = "Drops de coleta de fluxo do ZMQ",
    ["zmq_received_flows"] = "Fluxos Recebidos do ZMQ",
    ["metrics_prefixes"] = {
      ["broadcast_bytes"] = "Bytes de transmissão",
      ["drops"] = "Drops",
      ["num_devices"] = "Dispositivos numéricos",
      ["num_flows"] = "Num Fluxos",
      ["num_hosts"] = "Hosts Númidos",
      ["num_http_hosts"] = "Hosts Num HTTP",
      ["num_ms_rtt"] = "RTT ms",
      ["packets"] = "Pacotes",
    },
    ["metrics_suffixes"] = {
      ["by_as"] = "%{metric} by AS",
      ["egress"] = "Saída",
      ["ingress"] = "Entrada",
      ["inner"] = "Interior",
      ["rcvd"] = "rcvd",
      ["sent"] = "Enviei",
    },
  },
  ["host_config"] = {
    ["drop_all_host_traffic"] = "Soltar todo o tráfego do host",
    ["hide_from_top"] = "Ocultar dos principais locutores",
    ["hide_host_from_top_descr"] = "Não conta o host %{host} no topo talkers computação",
    ["host_alias"] = "Host Alias",
    ["host_pool"] = "Pool de host",
    ["host_traffic_policy"] = "Política de Tráfego do Host",
    ["modify_host_pool_policy_btn"] = "Modificar a política do pool de hosts",
    ["trigger_alerts_for_host"] = "Acionar alertas para o host %{host}",
    ["trigger_host_alerts"] = "Alertas do Host de Trigger",
    ["unblock_host_traffic"] = "Desbloquear o tráfego do host",
  },
  ["host_details"] = {
    ["blocked_traffic"] = "Tráfego bloqueado",
    ["host"] = "Host",
    ["host_cannot_be_found_message"] = "Host %{host} não pode ser encontrado.",
    ["host_parameter_missing_message"] = "O parâmetro do host está ausente (erro interno ?)",
    ["host_traffic_blocked_quota"] = "Algum tráfego de host foi bloqueado por uma cota excedida",
    ["host_traffic_blocked_quota_and_shaper"] = "Algum tráfego de host foi bloqueado por uma cota excedida e por um modelador de bloqueio",
    ["host_traffic_blocked_shaper"] = "Algum tráfego de host foi bloqueado por um shaper de bloqueio",
    ["reset_host_stats"] = "Redefinir estatísticas do host",
    ["reset_host_stats_confirm"] = "Você realmente quer redefinir \"%{host}\" estatísticas de tempo de execução?",
    ["reset_host_stats_note"] = "NOTA: os gráficos históricos para este host podem ter uma lacuna após a redefinição.",
    ["reset_stats_in_progress"] = "As estatísticas do host serão redefinidas em 5 segundos",
    ["restore_from_cache_message"] = "Clique <a href=%{js_code}> here</a> para restaurá-lo do cache.",
    ["snmp"] = "SNMP",
    ["trace_debug_host_info"] = "Host:%{hostinfo}, Vlan: %{vlan}",
    ["trace_debug_host_ip"] = "Host:%{hostip}, Vlan: %{vlan}",
    ["trace_debug_restored_host_info"] = "Informações do host Restaurado",
    ["unknown_device_type"] = "Tipo de dispositivo desconhecido",
  },
  ["host_pools"] = {
    ["alias_or_manufacturer"] = "Alias / Fabricante",
    ["and_associated_members"] = "seus dados RRD e quaisquer membros associados",
    ["cannot_delete_cp"] = "Um pool não pode ser excluído se houver qualquer usuário do Captive Portal associado",
    ["change_member_pool"] = "Alterar pool de membros",
    ["change_pool"] = "Switch Pool",
    ["children_safe"] = "Cofre para crianças",
    ["confirm_delete_pool"] = "Você realmente deseja excluir o host pool",
    ["confirm_empty_pool"] = "Você realmente quer remover todos os membros do host pool",
    ["confirm_remove_member"] = "Você realmente quer remover o membro",
    ["confirm_reset_pool_quotas"] = "Você realmente quer redefinir o \"%{pool}\" pool couters?",
    ["confirm_reset_quotas"] = "Você realmente deseja redefinir todos os contadores de cotas?",
    ["create_new_quotas_here"] = "Você pode criar novas cotas <a href=\"%{url}\">here</a>.",
    ["create_pool_hint"] = "Você pode criar novos pools na guia Gerenciar pools.",
    ["create_pools"] = "Gerenciar pools",
    ["delete_pool"] = "Excluir pool",
    ["duplicate_member"] = "Endereço do membro duplicado",
    ["duplicate_pool"] = "Nome do pool duplicado",
    ["edit_host_pools"] = "Editar pools de host",
    ["empty_pool"] = "Pool vazia",
    ["enforce_quotas_per_pool_member"] = "Cotas por membro",
    ["enforce_shapers_per_pool_member"] = "Shapers por membro",
    ["from_pool"] = "do host pool",
    ["host_pools"] = "Host Pools",
    ["invalid_member"] = "Formato de endereço de membro inválido",
    ["manage_pools"] = "Gerenciar associação ao pool",
    ["manufacturer_filter"] = "Fabricante: %{manufacturer}",
    ["max_members_message"] = "Com esta versão do ntopng você só pode atribuir %{maxnum} membros por host pool. Atualize para a versão Enterprise para remover esse limite.",
    ["max_pools_message"] = "Com esta versão do ntopng você só pode criar %{maxnum} pools de host. Atualize para a versão Enterprise para remover esse limite.",
    ["member_address"] = "Endereço do membro",
    ["member_exists"] = "Membro \"%{member_name}\" não adicionado. Já está atribuído ao pool \"%{member_pool}\".",
    ["member_filter"] = "Membro: %{member}",
    ["members_limit_reached"] = "limite de membros atingido",
    ["network_normalized"] = "Rede \"%{network}\" tem um identificador de host diferente de zero. Usando \"%{network_normalized}\".",
    ["new_pool"] = "Nova Pool",
    ["no_pools_defined"] = "Nenhum conjunto de hosts definido.",
    ["per_member_quotas"] = "Quando a opção de cotas por membro é definida, cada host terá uma contagem de cotas separada. Quando não definido, todo o tráfego de hosts contará como um todo para o limite de cota",
    ["per_member_shapers"] = "Quando a opção shapers por membro é definida, cada host terá seus próprios shapers. Quando não configurado, todos os hosts pertencentes ao mesmo pool compartilharão os mesmos shapers",
    ["pool"] = "Nome do pool",
    ["pool_name"] = "Nome do pool",
    ["pool_name_pattern_error"] = "Por favor, insira apenas caracteres minúsculos, números ou sublinhados",
    ["remove_member"] = "Remover membro",
    ["reset_quotas"] = "Redefinir Quotas",
    ["search_member"] = "Pesquisar membro",
    ["select_new_pool"] = "Selecione um novo pool no menu suspenso abaixo para atribuir um membro \"%{member}\" para:",
    ["specify_member_address"] = "Por favor especifique um endereço IPv4 / IPv6 ou rede ou um endereço MAC",
    ["specify_pool_name"] = "Especifique um nome de pool",
    ["view"] = "Visão",
  },
  ["hosts_comparison"] = {
    ["hosts_parameter_missing_message"] = "Parâmetro de hosts está ausente (erro interno ?)",
  },
  ["hosts_stats"] = {
    ["all"] = "Tudo",
    ["all_hosts"] = "Todas Hosts",
    ["as_geolocation"] = "AS Geolocalização",
    ["as_info"] = "Informação AS",
    ["as_path"] = "Caminho AS",
    ["as_prefixes"] = "Prefixos AS",
    ["asn_title"] = "para AS %{asn}",
    ["bgp_updates"] = "Atualizações do BGP",
    ["blacklisted"] = "Na lista negra",
    ["blacklisted_hosts_only"] = "Somente hosts na lista negra",
    ["blocking_traffic_policy_popup_msg"] = "O tráfego do host é afetado por uma política de tráfego de bloqueio",
    ["broadcast_domain_hosts_only"] = "Somente hosts de domínio de broadcast",
    ["country_title"] = "para o país %{country}",
    ["filter_hosts"] = "Filtrar Hosts",
    ["filtered"] = "Filtrado",
    ["filtered_hosts_only"] = "Hosts com tráfego bloqueado",
    ["host_pool"] = "Pool de host %{pool_name}",
    ["hosts"] = "Hosts",
    ["hosts_page_title"] = "%{all} %{traffic_type} %{local_remote} %{protocol} %{network} %{ip_version} %{os} Hosts %{country_asn_or_mac} %{vlan}",
    ["idle_hosts_not_listed"] = "Hosts inativos não listados.",
    ["in_network"] = "em %{network}",
    ["ipver_title"] = "IPv%{version_num}",
    ["label_blacklisted_host"] = "Na lista negra",
    ["label_broadcast_domain_host"] = "Domínio Broadcast",
    ["label_local_host"] = "Local",
    ["label_remote_host"] = "Remoto",
    ["local"] = "Local",
    ["local_hosts_only"] = "Somente hosts locais",
    ["location"] = "Localização",
    ["mac_title"] = "com Mac %{mac}",
    ["more_info_about_as_popup_msg"] = "Mais informações sobre AS",
    ["pool_title"] = "para Pool %{poolname}",
    ["remote"] = "Remoto",
    ["remote_hosts_only"] = "Somente hosts remotos",
    ["source_id"] = "ID da fonte",
    ["traffic_type_all"] = "Todas Hosts",
    ["traffic_type_one_way"] = "Mão única",
    ["user"] = "Usuário %{pool_name}",
    ["user_title"] = "para Usuário %{poolname}",
    ["vlan_title"] = "VLAN %{vlan}",
  },
  ["http_page"] = {
    ["distribution"] = "Distribuição",
    ["http_queries"] = "Consultas HTTP enviadas",
    ["http_responses"] = "Respostas HTTP recebidas",
    ["method"] = "Método",
    ["other_method"] = "Outro método",
    ["requests"] = "solicitações de",
    ["requests_served"] = "Solicitações Atendidas",
    ["response_code"] = "Código de resposta",
    ["response_code_1xx"] = "1xx (Informativa)",
    ["response_code_2xx"] = "2xx (Sucesso)",
    ["response_code_3xx"] = "3xx (Redirecionamento)",
    ["response_code_4xx"] = "4xx (Erro do cliente)",
    ["response_code_5xx"] = "5xx (Erro do servidor)",
    ["responses"] = "Respostas",
    ["traffic_received"] = "Tráfego recebido",
    ["traffic_sent"] = "Tráfego enviado",
    ["virtual_hosts"] = "Hosts Virtuais",
  },
  ["http_servers_stats"] = {
    ["actual_requests"] = "Solicitações reais",
    ["bytes_received"] = "Bytes Recebidos",
    ["bytes_sent"] = "Bytes enviados",
    ["http_server_ip"] = "IP do servidor HTTP",
    ["http_servers"] = "HTTP do servidor",
    ["http_virtual_host"] = "Host Virtual HTTP",
    ["local_http_servers"] = "Servidores HTTP locais",
    ["total_requests"] = "Total de Pedidos",
  },
  ["icmp_page"] = {
    ["icmp_message"] = "Mensagem ICMP",
    ["icmp_port_unreachable_extra"] = "%{unreach_protocol} porta %{unreach_port} inacessível em %{unreach_host}",
    ["last_rcvd_peer"] = "Última Rcvd Peer",
    ["last_sent_peer"] = "Último par enviado",
    ["packets_received"] = "Pacotes Recebidos",
    ["packets_sent"] = "Pacotes enviados",
  },
  ["if_stats_config"] = {
    ["custom_name"] = "Nome personalizado",
    ["custom_name_popup_msg"] = "Especifique um alias para a interface",
    ["hide_from_top_networks"] = "Ocultar as principais redes",
    ["hide_from_top_networks_descr"] = "e.g. %{example}",
    ["interface_network_discovery"] = "Descoberta de Rede de Interface Periódica",
    ["interface_rrd_creation"] = "Criar séries de tempo de interface",
    ["interface_speed"] = "Velocidade da Interface (Mbit/s)",
    ["interface_speed_popup_msg"] = "Especifique a velocidade máxima da interface",
    ["is_mirrored_traffic"] = "Tráfego espelhado",
    ["scaling_factor"] = "Taxa de Amostragem de Pacotes de Entrada",
    ["scaling_factor_popup_msg"] = "Isso deve corresponder à sua taxa de amostragem da interface de captura",
    ["trigger_interface_alerts"] = "Alertas de desencadear interface",
  },
  ["if_stats_overview"] = {
    ["active"] = "Ativa",
    ["all_counters"] = "Todos os contadores",
    ["blocked_flows"] = "Fluxos bloqueados",
    ["bridged_traffic"] = "Tráfego em ponte",
    ["buffer_full"] = "Buffer Completo",
    ["collected_flows"] = "Fluxos Recolhidos",
    ["dropped_flows"] = "Fluxos Deixados",
    ["dropped_packets"] = "Pacotes Soltos",
    ["drops_only"] = "Apenas dropps",
    ["dumped_files"] = "Arquivos despejados",
    ["dumped_packets"] = "Pacotes despejados",
    ["egress_packets"] = "Pacotes de saída",
    ["exported_flows"] = "Fluxos exportados",
    ["family"] = "Família",
    ["flows_export_statistics"] = "Fluxos Exportar Estatísticas",
    ["ghost_bcast_domain_descr"] = "A %{ghost_icon} destaca domínios de difusão fantasma (ou seja, eles não pertencem a nenhuma das redes de endereços IP da interface).",
    ["has_traffic_directions"] = "com direções RX / TX",
    ["id"] = "Id",
    ["iface_switch_active_msg"] = "A interface selecionada <b>%{interface}</b> [ifid: %{ifid}] agora está ativo",
    ["iface_switch_empty_session_msg"] = "Sessão vazia",
    ["iface_switch_error_msg"] = "Erro ao alternar interfaces",
    ["in_path_interface"] = "Interface no caminho (Colisão no fio)",
    ["ingress_packets"] = "Pacotes de entrada",
    ["ingress_traffic"] = "Tráfego ingresso",
    ["interface_ip"] = "IP da interface",
    ["interface_name"] = "Nome da interface",
    ["interface_rx_updates"] = "Atualizações de Interface RX",
    ["nf"] = "Netfilter",
    ["nf_enobufs"] = "Nenhum espaço de buffer",
    ["nf_handle_packet_failed"] = "Pacotes de filas na fila lidando com falhas",
    ["nf_queue_dropped"] = "Pacotes Soltos (Fila Completa)",
    ["nf_queue_pct"] = "Nível de preenchimento da fila",
    ["nf_queue_total"] = "Pacotes enfileirados",
    ["nf_queue_user_dropped"] = "Pacotes Soltos (Não foi possível enviar para o espaço do usuário)",
    ["note"] = "NOTE",
    ["note_drop_ifstats_dynamic"] = "Drops estão disponíveis na interface principal",
    ["note_drops_sflow"] = "Os drops são mostradas apenas para o sFlow, pois o NetFlow não as reporta.<br><A HREF=https://www.ietf.org/rfc/rfc3176.txt>sFlow</A> drops contam o número de vezes que o agente sFlow detectou que um pacote marcado para ser amostrado foi descartado devido à falta de recursos. O contador de drops informa o número total de drops detectadas desde a última reinicialização do agente. Uma taxa de queda alta indica que o agente de gerenciamento não pode processar amostras tão rápido quanto elas estão sendo geradas pelo hardware. Aumentar a taxa de amostragem do sFlow reduzirá a taxa de queda. Nota: Um agente que não pode detectar quedas informará sempre zero.",
    ["note_packets"] = "Em redes ethernet, cada pacote tem um <A HREF=\"https://en.wikipedia.org/wiki/Ethernet_frame\">sobrecarga de 24 bytes</A> [preamble (7 bytes), início do quadro (1 byte), CRC (4 bytes), e <A HREF=\"http://en.wikipedia.org/wiki/Interframe_gap\">IFG</A> (12 bytes)].Essa sobrecarga precisa ser contabilizada no tráfego da interface, mas não é adicionada ao tráfego que está sendo trocado entre os endereços IP. Isso ocorre porque esses dados contribuem para o carregamento da interface, mas não podem ser contabilizados no tráfego que está sendo trocado pelos hosts e, portanto, esperam poucas discrepâncias entre os valores de tráfego do host e da interface..",
    ["note_probe_zmq_drops_export_queue_full"] = "O probe remoto processou com êxito esses fluxos, mas não conseguiu enfileirá-los para a exportação, pois a fila de exportação estava cheia.",
    ["note_probe_zmq_drops_flow_collection_drops"] = "Pacotes de fluxo ignorados (NetFlow v9) ou fluxos descartados (NetFlow v5/IPFIX)",
    ["paused"] = "Pausado",
    ["probe_ip"] = "Examinar IP",
    ["probe_timeout_idle"] = "Tempo limite ocioso",
    ["probe_timeout_lifetime"] = "Tempo Limite Vitalício",
    ["probe_zmq_drops_export_queue_full"] = "Fluxos Cheios de Queda da Fila",
    ["probe_zmq_drops_flow_collection_drops"] = "Drops de coleta de fluxo",
    ["probe_zmq_num_endpoints"] = "Pontos de extremidade do ZMQ do probe ativo",
    ["probe_zmq_num_flow_exports"] = "Fluxos exportados",
    ["public_probe_ip"] = "Ip público examinado",
    ["received_traffic"] = "Tráfego recebido",
    ["remote_probe"] = "Examinar remotamente",
    ["reset_counters"] = "Repor contadores",
    ["send_error"] = "Erro de envio",
    ["sflow_counter_updates"] = "Atualizações do contador sFlow",
    ["shaped_filtered_packets"] = "Pacotes em forma / filtrados",
    ["snmp"] = "SNMP",
    ["state"] = "Estado",
    ["traffic_breakdown"] = "Repartição do Tráfego",
    ["traffic_statistics"] = "Estatísticas de tráfego",
    ["zmq_message_drops"] = "Drops de mensagens do ZMQ",
    ["zmq_rx_statistics"] = "Estatísticas ZMQ RX",
  },
  ["index_page"] = {
    ["applications"] = "Aplicações",
    ["asns"] = "ASNs",
    ["dashboard"] = "Painel de controle",
    ["hosts"] = "Hosts",
    ["live_update"] = "Atualização ao vivo",
    ["minute"] = "Minuto",
    ["never"] = "Nunca",
    ["no_packet_warning"] = "Nenhum pacote foi recebido ainda na interface %{ifname}.<p>Por favor, espere %{countdown} segundos até que esta página seja recarregada.",
    ["refresh"] = "Atualizar",
    ["refresh_frequency"] = "Frequência de atualização",
    ["refresh_graph_popup_msg"] = "Atualizar gráfico",
    ["seconds"] = "Segundos",
    ["senders"] = "Remetentes",
    ["top_flow_talkers"] = "Top Talkers de Fluxo",
  },
  ["live_capture"] = {
    ["active_live_captures"] = "Capturas ao Vivo",
    ["note"] = "Capture o tráfego ao vivo para o host %{hostinfo}. O fluxo irá parar automaticamente após 1 minuto ou 100k pacotes.",
  },
  ["live_traffic"] = {
    ["error_generic"] = "Erro genérico",
    ["error_not_found"] = "Não encontrado",
    ["error_not_granted"] = "Pedido não concedido",
    ["modal_vlan_tagged_with_bpf_confirmation"] = "Este host é marcado com VLAN. O filtro BPF enviado, para corresponder adequadamente aos pacotes, deve conter VLAN 51. A VLAN pode ser especificada no filtro como <br> <pre>vlan %{vlan} e <i>...resto do filtro...</i></pre>",
    ["modal_vlan_tagged_with_bpf_continue"] = "Continuar",
    ["modal_vlan_tagged_with_bpf_title"] = "Host pcap Baixar",
  },
  ["local_flow_matrix"] = {
    ["error_no_local_hosts"] = "Nenhum host local pode ser encontrado",
    ["local_flow_matrix"] = "Matriz de Fluxo Local",
    ["local_hosts_active_flows_matrix"] = "Matriz de fluxos ativos de hosts locais",
  },
  ["local_hosts_stats"] = {
    ["criteria"] = "Critério",
    ["looking_glass"] = "Espelho",
  },
  ["locales"] = {
    ["de"] = "Alemão",
    ["en"] = "Inglês",
    ["it"] = "Italiano",
    ["jp"] = "Japonês",
  },
  ["login"] = {
    ["add_captive_portal_user"] = "Adicionar usuário do portal cativo",
    ["add_web_user"] = "Adicionar usuário da web",
    ["auth_success"] = "Autenticação bem sucedida",
    ["blacklisted_ip_notice"] = "Muitas tentativas de autenticação com falha. Por favor, tente novamente depois de um tempo.",
    ["change_password"] = "Mudar senha",
    ["confirm_password"] = "Confirme a Senha",
    ["device_label"] = "Rótulo do Dispositivo",
    ["donation"] = "Se você achar %{product} útil, por favor, ajudem-nos fazendo uma pequena <A href=\"%{donation_url}\">donation</A>. Seu financiamento ajudará a administrar e fomentar o desenvolvimento deste projeto. Obrigado.",
    ["enter_credentials"] = "Por favor insira suas credenciais para acessar esta rede.",
    ["informative_captive_join"] = "Acessar a internet",
    ["informative_captive_portal_tos"] = "Eu li e concordei com o <a target='_blank' href='%{url}'>termos de serviço</a>.",
    ["internet_redirecting"] = "Estamos redirecionando você para a Internet...",
    ["license"] = "%{product} é lançado sob <a href=\"%{license_url}\">%{license}</a>.",
    ["logging_out"] = "Sair...",
    ["login"] = "Entrar",
    ["logout"] = "Sair",
    ["logout_user_x"] = "Sair %{user}",
    ["must_change_password"] = "A senha do administrador padrão deve ser alterada. Por favor insira uma nova senha abaixo.",
    ["password"] = "Senha",
    ["password_mismatch"] = "As senhas não coincidem",
    ["password_not_valid"] = "Por favor, especifique uma senha diferente",
    ["password_pattern_error"] = "Por favor, insira pelo menos 5 caracteres válidos.",
    ["password_ph"] = "Senha (administrador padrão)",
    ["passwords_dont_match"] = "Senhas não combinam.",
    ["unsupported_browser"] = "Seu navegador não é suportado.<br>Por favor, considere o uso de um Firefox ou Chrome recente.",
    ["username"] = "Nome de usuário",
    ["username_ph"] = "Nome de usuário (administrador padrão)",
    ["web_users"] = "Usuários da Web",
    ["welcome_to"] = "Bem-vindo ao %{product}",
  },
  ["mac_details"] = {
    ["json_error_inactive"] = "Erro JSON: host inativo removido ou %{product} terminou?",
    ["mac"] = "Mac",
    ["mac_cannot_be_found_message"] = "Mac %{mac} não pode ser encontrado.",
    ["mac_parameter_missing_message"] = "Parâmetro Mac está faltando (erro interno ?)",
    ["reset_mac_stats"] = "Redefinir estatísticas do Mac",
    ["reset_mac_stats_note"] = "OBSERVAÇÃO: os gráficos históricos para esse endereço mac podem ter um intervalo após a redefinição.",
    ["reset_stats_in_progress"] = "As estatísticas do Mac serão repostas dentro de 5 segundos",
  },
  ["mac_stats"] = {
    ["all_devices"] = "Todos",
    ["all_layer_2_devices"] = "Todos os dispositivos",
    ["all_manufacturers"] = "Todos os fabricantes",
    ["arp_total"] = "ARP",
    ["dev_layer_2_devices"] = "%{device_type} Devices",
    ["dhcp_only"] = "Somente DHCP",
    ["filter_macs"] = "Filtrar Macs",
    ["idle_devices_not_listed"] = "Dispositivos ociosos não listados.",
    ["layer_2_dev_devices"] = "%{device_type} Devices",
    ["layer_2_devices_with_manufacturer"] = "%{manufacturer} %{title}",
    ["layer_2_source_devices"] = "%{device_type} Devices",
    ["manufacturer"] = "Fabricante",
    ["source_macs"] = "Apenas fonte",
  },
  ["manage_data"] = {
    ["all_hosts"] = "Todos",
    ["delete"] = "Excluir dados do host",
    ["delete_active_interface"] = "Excluir dados da interface",
    ["delete_inactive_interfaces"] = "Excluir dados de interfaces inativas",
    ["delete_tab"] = "Excluir",
    ["export"] = "Exportar dados do host",
    ["export_tab"] = "Exportar",
    ["hosts"] = "Hosts",
    ["ip_or_mac_address"] = "Endereço IP ou MAC ou / 24",
    ["local_hosts"] = "Local",
    ["mac_or_ip_required"] = "Por favor, insira um endereço IP ou MAC válido",
    ["manage_data"] = "Gerenciar dados",
    ["remote_hosts"] = "Controlo remoto",
    ["single"] = "Individual",
  },
  ["manage_users"] = {
    ["add_new_user"] = "Adicionar novo usuário",
    ["administrator"] = "Administrador",
    ["allowed_interface"] = "Interface permitida",
    ["allowed_networks"] = "Redes permitidas",
    ["allowed_networks_descr"] = "Lista separada por vírgulas de redes que esse usuário pode visualizar. Exemplo:",
    ["allowed_passwd_charset"] = "Caracteres permitidos são ISO 8859-1 (latin1) letras maiúsculas e minúsculas, números e símbolos especiais",
    ["any_interface"] = "Qualquer interface",
    ["authentication_lifetime"] = "Autenticação tempo de vida",
    ["change_user_password"] = "Alterar a senha do usuário",
    ["change_user_preferences"] = "Alterar as preferências do usuário",
    ["confirm_delete_user"] = "Tem certeza de que deseja excluir %{user}?",
    ["enable_captive_portal"] = "<a href=\"%{url}\">Ativando o portal cativo</a> permite que você defina usuários do portal cativos",
    ["expires_after"] = "Expira depois",
    ["group"] = "Grupo",
    ["host_pool_id"] = "ID do conjunto de Host",
    ["manage"] = "Administrar",
    ["manage_user_x"] = "Gerenciar usuário %{user}",
    ["manage_users"] = "Gerenciar usuários",
    ["new_password"] = "Nova senha",
    ["new_password_confirm"] = "Confirme a nova senha",
    ["no_host_pools"] = "Nenhum conjunto de hosts definido. Por favor crie um <a href='%{url}'>here</a>",
    ["non_privileged_user"] = "Usuário não privilegiado",
    ["old_password"] = "Senha Antiga",
    ["the_auth_can_be_perpetual"] = "A autenticação pode ser perpétua ou pode expirar após o tempo especificado",
    ["the_host_pool_associated"] = "O host pool que será associado ao usuário após a autenticação bem-sucedida",
    ["unlimited"] = "Ilimitado",
    ["user_role"] = "Papel do usuário",
    ["web_captive_users"] = "Usuários do Portal da Web / Captive",
  },
  ["metrics"] = {
    ["days"] = "Dias",
    ["hours"] = "Horas",
    ["mins"] = "Mins",
    ["secs"] = "Secs",
  },
  ["ndpi_page"] = {
    ["custom_applications"] = "Aplicações Personalizadas",
    ["live_flows_count"] = "Contagem de Fluxos em Tempo Real",
    ["note"] = "NOTA",
    ["note_historical_per_protocol_traffic"] = "Histórico %{what} dados de tráfego podem ser ativados via <a href='%{url}'>%{flask_icon} Preferências</a>.",
    ["note_live_flows_chart"] = "Este gráfico mostra apenas conexões TCP.",
    ["note_possible_probing_alert"] = "Um ícone como %{icon} indica uma possibilidade de sondagem (ou servidor de aplicativos) alerta como o host recebeu tráfego para um aplicativo específico sem enviar de volta nenhum dado. Você pode usar <A HREF='%{url}'>relatórios históricos</A> detalhar esse problema.",
    ["note_protocol_usage_time"] = "O tempo de uso do aplicativo é calculado em intervalos de slot discretos.",
    ["overview"] = "%{what} visão global",
    ["rcvd"] = "Rcvd",
    ["received_only"] = "Recebido apenas",
    ["sent"] = "Enviei",
    ["sent_only"] = "Enviado apenas",
    ["total_since_startup"] = "Total (Desde a inicialização)",
    ["unable_to_find_host"] = "Incapaz de encontrar %{host_ip} (dados expirados ?)",
  },
  ["nedge"] = {
    ["a_member_address_is"] = "Um endereço de membro é uma regra para atribuir dispositivos a um usuário. A seguinte ordem se aplica:",
    ["a_zero_quota_is_unlimited"] = "Uma cota zero significa tráfego ilimitado.",
    ["active_user"] = "Usuário ativo",
    ["add_gateway"] = "Adicionar gateway",
    ["add_member"] = "Adicionar membro",
    ["add_port_forwarding_rule"] = "Adicionar regra de encaminhamento de porta",
    ["add_routing_policy"] = "Adicionar política de roteamento",
    ["add_some_gateways_first"] = "Nenhum gateways definido. Por favor, defina alguns gateways <a href=\"%{url}\">here</a>.",
    ["add_static_lease"] = "Adicionar concessão estática",
    ["add_static_route"] = "Adicionar rota estática",
    ["add_system_user"] = "Adicionar usuário do sistema",
    ["add_user_member"] = "Adicionar usuário membro",
    ["applied_policy"] = "Política Aplicada",
    ["apply_and_reboot"] = "Aplicar e reiniciar",
    ["apply_and_restart_self"] = "Aplicar e reiniciar",
    ["apply_configuration"] = "Aplicar configuração",
    ["apply_configuration_and_reboot"] = "Você aplicará a nova configuração. As interfaces de rede serão reconfiguradas de acordo com as configurações especificadas e o sistema será reinicializado. Configurações erradas podem fazer com que o sistema perca a conectividade IP. Apenas continue se você estiver extremamente confiante de que as configurações estão corretas.",
    ["apply_configuration_and_restart_self"] = "Você aplicará a nova configuração. Isso causará %{product} para reiniciar e pode fazer com que esta GUI da Web pare de responder por alguns segundos.",
    ["apply_the_initial_device_configuration"] = "Aplicar a configuração inicial do dispositivo.",
    ["authentication_gui_and_captive_portal"] = "Os métodos de autenticação aplicam-se tanto ao %{product} gui e o <a href=\"%{url}\">Portal cativo</a> Acesso.",
    ["bandwidth_allocation"] = "Alocação de Largura de Banda",
    ["bind_to_any"] = "Qualquer interface",
    ["bind_to_lan"] = "Interface LAN",
    ["cannot_rename_gateway"] = "Não é possível renomear o gateway.",
    ["cannot_rename_policy"] = "Não é possível renomear a política.",
    ["cannot_rename_static_route"] = "Não é possível renomear a rota estática.",
    ["captive_portal_other_methods"] = "O Portal Cativo usa os métodos de autenticação definidos no <a href=\"%{url}\">Preferências de Autenticação</a> (e.g. Radius).",
    ["categories_policies"] = "Políticas de Categoria",
    ["configure_routing_policies"] = "Configurar políticas de roteamento",
    ["configured_members"] = "Membros configurados",
    ["confirm_delete_gateway"] = "Você realmente quer excluir o gateway \"%{gw}\"?",
    ["confirm_delete_policy"] = "Você realmente quer excluir a política \"%{policy}\"?",
    ["confirm_delete_port_forwarding_rule"] = "Você realmente deseja excluir a regra especificada?",
    ["confirm_delete_static_lease"] = "Você realmente deseja excluir \"%{hostname}\" locação estática?",
    ["confirm_delete_static_route"] = "Você realmente deseja excluir a rota estática \"%{sr}\"?",
    ["confirm_remove_member_from_user"] = "Você realmente quer remover o membro %{member} do usuário %{user}?",
    ["could_not_add_port_forwarding"] = "Não foi possível adicionar a regra de encaminhamento de porta",
    ["custom"] = "Personalizados",
    ["custom_datetime"] = "Hora atual",
    ["custom_datetime_descr"] = "Define manualmente a data e a hora do sistema.",
    ["custom_policy"] = "Política Personalizada",
    ["data_reset"] = "Redefinição de dados",
    ["data_reset_msg"] = "Você realmente deseja redefinir todos os dados do dispositivo? Os dados incluem timeseries armazenados, fluxos, alertas, caches Redis e contadores de host. A configuração do dispositivo e a configuração do sistema não serão afetadas pela redefinição.<br>Isso causará %{product} para reiniciar e pode fazer com que esta GUI da Web pare de responder por alguns segundos.",
    ["date_time"] = "Data e hora",
    ["default_categories"] = "Políticas de categoria padrão",
    ["default_categories_with_a_defined_policy"] = "Políticas de Categoria Personalizadas Padrão",
    ["default_categories_with_a_defined_quota"] = "Políticas de categoria de cota padrão",
    ["default_categories_with_policy_x"] = "Padrão %{x} Políticas de Categoria",
    ["default_gateway"] = "Gateway padrão",
    ["default_policy"] = "Política Padrão",
    ["default_protocols"] = "Políticas de aplicativo padrão",
    ["default_protocols_with_a_defined_policy"] = "Políticas de aplicativos personalizados padrão",
    ["default_protocols_with_a_defined_quota"] = "Políticas de aplicativo de cota padrão",
    ["default_protocols_with_policy_x"] = "Padrão %{x} Políticas de Aplicação",
    ["default_shaper"] = "Passar",
    ["default_shaper_descr"] = "A porcentagem de largura de banda padrão da velocidade da interface.",
    ["delete_gateway"] = "Excluir gateway",
    ["delete_policy"] = "Excluir política",
    ["delete_port_forwarding_rule"] = "Excluir regra de encaminhamento de porta",
    ["delete_static_lease"] = "Deletar entrada estáticas",
    ["delete_static_route"] = "Excluir rota estática",
    ["device_protocol_policy_has_higher_priority"] = "Políticas de dispositivo têm prioridade mais alta que as políticas de aplicativo.",
    ["device_protocols_blocked_warning"] = "O tráfego será <b>not</b> ser bloqueado porque %{device_protocols_policies} estão desativados",
    ["device_protocols_policies"] = "Políticas de dispositivos",
    ["dhcp_disabled_warning"] = "Se nenhum outro servidor DHCP estiver disponível em sua rede, seus clientes não poderão se conectar automaticamente.",
    ["dhcp_first_ip"] = "Primeiro endereço IP",
    ["dhcp_first_ip_descr"] = "O primeiro endereço IP do pool de endereços DHCP",
    ["dhcp_last_ip"] = "Último endereço IP",
    ["dhcp_last_ip_descr"] = "O último endereço IP do pool de endereços DHCP",
    ["dhcp_server"] = "Servidor DHCP",
    ["dhcp_server_description"] = "Ativar o servidor DHCP.",
    ["dhcp_server_not_enabled"] = "O servidor DHCP não está ativado. Você pode ativá-lo <a href=\"%{url}\">here</a>.",
    ["dns_configuration"] = "Configuração de DNS",
    ["dns_server_preset"] = "Predefinição do servidor DNS",
    ["dns_server_preset_descr"] = "Você pode selecionar um servidor DNS em destaque na lista ou especificar seus servidores DNS personalizados.",
    ["download_description"] = "A velocidade máxima de download da interface.",
    ["download_speed"] = "Velocidade de download",
    ["edit_gateway"] = "Editar gateway",
    ["edit_quotas"] = "Editar Quotas",
    ["edit_routing_policy"] = "Editar política de roteamento",
    ["edit_static_route"] = "Editar rota estática",
    ["edit_user"] = "Editar usuário",
    ["edit_users"] = "Editar usuários",
    ["enable_device_protocols_policies"] = "Políticas de aplicativos de dispositivo",
    ["enable_interface"] = "Ativar interface",
    ["enable_interface_descr"] = "Ativar ou desativar a interface de rede.",
    ["enable_nat"] = "Ativar NAT",
    ["enable_nat_descr"] = "Se ativado, os endereços IP dos clientes serão maquerados com o endereço IP da interface WAN.",
    ["enforce_global_dns"] = "Reforçar o DNS global",
    ["enforce_global_dns_description"] = "Ative o forjamento de DNS para forçar os dispositivos a usar o DNS global especificado.",
    ["enternal_port_overlap"] = "Portas externas sobrepostas com porta %{port} atribuído a %{ip}",
    ["external_port"] = "Porta externa (WAN)",
    ["external_port_or_range"] = "Porta externa ou faixa de portas",
    ["factory_reset"] = "Restauração de fábrica",
    ["factory_reset_msg"] = "Você realmente deseja redefinir o dispositivo para sua configuração de fábrica? Qualquer configuração e dados serão perdidos.",
    ["filter_policies"] = "Políticas de filtro",
    ["gateway"] = "Gateway",
    ["gateway_exists"] = "Gateway %{gw} já existe.",
    ["gateway_interface_descr"] = "Especifique a interface de rede a ser usada para determinar o endereço IP do gateway",
    ["gateway_name"] = "Nome do Gateway",
    ["gateway_type"] = "Modo",
    ["gateway_type_address_descr"] = "Especifique o endereço IP do gateway.",
    ["gateway_x"] = "Gateway %{gw}",
    ["gateways"] = "Gateways",
    ["gateways_status"] = "Status de gateways",
    ["global_dns"] = "DNS Global",
    ["global_shapers_rates"] = "Controle Global de Largura de Banda",
    ["high_priority"] = "Prioridade máxima",
    ["higher_priority"] = "Maior prioridade",
    ["hostname"] = "Nome do anfitrião",
    ["hostname_lease_exists"] = "Uma entrada estática com nome de host \"%{hostname}\" já existe.",
    ["interfaces_configuration"] = "Configuração de Interfaces",
    ["internal_ip"] = "IP interno (LAN)",
    ["internal_port"] = "Porta Interna (LAN)",
    ["internal_port_number"] = "Número da porta interna",
    ["internal_port_overlap"] = "A porta interna sobrepõe-se a %{internal_port} já mapeado para porta externa %{external_port}",
    ["invalid_dhcp_range"] = "Intervalo DHCP inválido. Certifique-se de que os endereços IP do DHCP estejam dentro do alcance da rede LAN, caso contrário, seus dispositivos não poderão navegar na Web.",
    ["invalid_port_range"] = "Intervalo de portas inválido",
    ["ip_address_takes_preced"] = "Um endereço IP tem precedência sobre um endereço de rede",
    ["ip_lease_exists"] = "Uma entrada estática com ip \"%{ip}\" já existe.",
    ["lan"] = "LAN",
    ["lan_ip_addr"] = "Endereço IP da LAN",
    ["lan_ip_addr_descr"] = "Especifique o endereço IP da interface da LAN.",
    ["lan_recovery_ip"] = "IP de recuperação de LAN",
    ["lan_recovery_ip_descr"] = "Um endereço IP adicional para alcançar o %{product} dispositivo na interface LAN.",
    ["lan_recovery_warning"] = "Por favor, certifique-se de que isso não colide com qualquer outra rede definida.",
    ["link_not_ready"] = "Link não pronto",
    ["linkdown"] = "Marque abaixo",
    ["low_priority"] = "Baixa prioridade",
    ["lower_priority"] = "Prioridade Inferior",
    ["mac_address_takes_preced"] = "Um endereço mac tem precedência sobre um endereço IP",
    ["mac_lease_exists"] = "Uma entrada estática para mac \"%{mac}\" já existe.",
    ["max_bps_per_host"] = "Max %{bps} por host",
    ["max_perc"] = "Max %{perc}%%",
    ["max_rrt"] = "Max RTT",
    ["max_rrt_description"] = "O tempo máximo de ida e volta em direção ao endereço do monitor. Se o RTT medido exceder esse valor, o gateway será considerado.",
    ["maximum_enforced"] = "Reforço maximum",
    ["maximum_enforced_descr"] = "Se definido como máximo imposto, a alocação máxima de largura de banda será imposta, independentemente da largura de banda disponível.",
    ["member_address"] = "Endereço do membro",
    ["member_exists"] = "Member %{member} não adicionado, como já está atribuído ao usuário %{existing_user}",
    ["members"] = "Membros",
    ["members_for_user_x"] = "Membros do usuário %{user}",
    ["min_perc"] = "Min %{perc}%%",
    ["minimum_guaranteed"] = "Mínimo Garantido",
    ["minimum_guaranteed_descr"] = "Se configurado para o mínimo garantido, apenas a alocação mínima de largura de banda será garantida.",
    ["mode"] = "Modo",
    ["nedge"] = "nEdge",
    ["network_conf_dhcp"] = "DHCP",
    ["network_conf_iface_descr"] = "Especifique o modo de endereço IP da interface.",
    ["network_conf_iface_gw"] = "Endereço IP do gateway padrão da interface (e.g. 192.168.1.1).",
    ["network_conf_iface_ip"] = "Endereço IP da interface (e.g. 192.168.1.10).",
    ["network_conf_iface_nmask"] = "Máscara de rede da interface (e.g. 255.255.255.0).",
    ["network_conf_iface_title"] = "%{ifrole} Interface %{ifname}",
    ["network_conf_static"] = "Estática",
    ["network_conf_vlan_trunk"] = "Tronco VLAN",
    ["no_gateways_defined"] = "Nenhum gateways definido.",
    ["no_interfaces_available"] = "Nenhuma interface disponível.",
    ["no_routing_policies_defined"] = "Nenhuma política de roteamento definida",
    ["no_rules"] = "Sem regras",
    ["no_static_leases"] = "Nenhuma entrada estática",
    ["no_static_routes_defined"] = "Nenhuma rota estática definida.",
    ["ntp_sync"] = "Sincronização NTP",
    ["ntp_sync_descr"] = "Alternar a sincronização com um servidor NTP.",
    ["per_ip_rates"] = "Por controle de largura de banda do host",
    ["ping_address"] = "Endereço do Monitor",
    ["ping_address_description"] = "O endereço a monitorar para verificar o status do gateway.",
    ["please_fill_out_this_field"] = "Por favor, preencha este campo.",
    ["policy_due_to_source"] = "%{policy} devido a %{source}",
    ["policy_name"] = "Nome da política",
    ["port_forwarding"] = "Encaminhamento de porta",
    ["power_off"] = "Desligar",
    ["power_off_confirm"] = "Você quer desligar o aparelho?",
    ["priority_x"] = "Prioridade %{x}",
    ["protocol_policy_has_higher_priority"] = "As Políticas de Aplicativo têm maior prioridade que as Políticas de Categoria.",
    ["protocols_policies"] = "Políticas de Aplicação",
    ["reboot"] = "Reinicialização",
    ["reboot_corfirm"] = "Você quer reiniciar o dispositivo?",
    ["remove_all_members"] = "Remover todos os membros",
    ["remove_all_members_confirm"] = "Você realmente quer remover todos os membros do usuário %{user}?",
    ["reset_and_reboot"] = "Redefinir e Reiniciar",
    ["reset_and_restart_self"] = "Repor e Reiniciar",
    ["restrict_weg_gui_access_description"] = "Restringir o acesso a esta GUI da Web de gerenciamento para torná-lo acessível somente a partir da interface da LAN (mais seguro) ou de qualquer interface do sistema (menos seguro).",
    ["restrict_weg_gui_access_title"] = "Acesso à GUI da Web de gerenciamento",
    ["router"] = "Roteador",
    ["router_mode_requires_enterprise"] = "O modo de roteador está disponível apenas na edição Enterprise nedge.",
    ["routing"] = "Roteamento",
    ["routing_policies"] = "Políticas de roteamento",
    ["routing_policy"] = "Políticas de roteamento",
    ["routing_policy_exists"] = "Políticas de roteamento \"%{policy}\" já existe.",
    ["safe_search_description"] = "Use o Child Safe DNS para bloquear conteúdo impróprio.",
    ["search_categories"] = "Categorias de pesquisa",
    ["search_protocols"] = "Aplicativos de pesquisa",
    ["security"] = "Segurança",
    ["set_the_device_mode"] = "Definir o modo de operação do dispositivo.",
    ["setup_apply"] = "Aplique",
    ["setup_config_edited_descr"] = "Aplicar alterações para tornar a nova configuração efetiva ou descartada para continuar usando a atual.",
    ["setup_config_edited_title"] = "Configuração do sistema editada!",
    ["setup_discard"] = "Descartar",
    ["setup_mode"] = "Modo operacional",
    ["setup_network"] = "Rede",
    ["shapers"] = "Controle de Largura de Banda",
    ["single_port_router"] = "Roteador de porta única",
    ["slow_pass_shaper_descr"] = "A porcentagem de largura de banda da passagem lenta da velocidade da interface.",
    ["slower_pass_shaper_descr"] = "A porcentagem de largura de banda da passagem mais lenta da velocidade da interface.",
    ["specify_a_protocol"] = "Especifique um aplicativo",
    ["static_dhcp_leases"] = "Locações estáticas do servidor DHCP",
    ["static_route_address_descr"] = "Especifique o destino da rota estática.",
    ["static_route_exists"] = "Rota estática %{sr} já existe.",
    ["static_route_is_local_descr"] = "Especifique se esta é uma rota estática para uma rede local.",
    ["static_route_is_local_title"] = "Rota estática da rede local",
    ["static_route_name"] = "Nome da rota estática",
    ["static_route_netmask_descr"] = "Especifique a máscara de rede a ser aplicada ao destino da rota estática.",
    ["static_route_via_descr"] = "Especifique o endereço IP a ser usado como próximo salto para a rota estática.",
    ["static_route_x"] = "Rota estática %{sr}",
    ["static_routes"] = "Rotas Estáticas",
    ["static_routes_in_policies"] = "Rotas estáticas são aplicadas a (e ter precedência sobre) qualquer um dos definidos <a href=\"%{url}\">Políticas de roteamento</a>.",
    ["status_activate"] = "Ativar",
    ["status_connected"] = "Conectado",
    ["status_connecting"] = "Conectando",
    ["status_deactivate"] = "Desativar",
    ["status_disabled"] = "Desativado",
    ["status_disconnected"] = "Desconectado",
    ["status_down"] = "Down",
    ["status_failed"] = "Falhou",
    ["status_inactive"] = "Inativo",
    ["status_unreachable"] = "Inacessível",
    ["status_up"] = "Up",
    ["system_setup"] = "Configuração do sistema",
    ["system_users"] = "Usuários do sistema",
    ["test_policies"] = "Políticas de teste",
    ["test_policies_page_description"] = "Esta página pode ser usada para verificar quais serão as políticas aplicadas no %{user} dispositivos baseados na configuração atual.",
    ["the_fallback_policy"] = "A <a href=\"%{url}\">Fallback Policy</a> é aplicado quando o usuário e a política global para um determinado aplicativo e sua categoria correspondente são definidos como \"Default\".",
    ["the_not_assigned_user_contains"] = "O \"Not Assigned\" usuário pode ser usado para definir políticas para dispositivos que não são atribuídos a nenhum usuário.",
    ["the_primary_dns_server"] = "O servidor DNS primário",
    ["the_secondary_dns_server"] = "O servidor DNS secundário",
    ["timezone"] = "Fuso horário",
    ["timezone_descr"] = "Define o fuso horário do sistema.",
    ["upload_description"] = "A velocidade máxima de upload para a interface.",
    ["upload_speed"] = "Velocidade de upload",
    ["user"] = "usuário",
    ["user_categories"] = "Políticas de categoria para usuário %{user}",
    ["user_categories_with_a_defined_policy"] = "Políticas de categorias personalizadas para o usuário %{user}",
    ["user_categories_with_a_defined_quota"] = "Políticas de Categoria de Cota para o Usuário %{user}",
    ["user_categories_with_policy_x"] = "%{x} Políticas de categoria para usuário %{user}",
    ["user_category_policies"] = "Políticas de categoria de usuário",
    ["user_device_protocols"] = "Políticas de aplicação para %{user} Devices",
    ["user_protocols"] = "Políticas de aplicativo para usuário %{user}",
    ["user_protocols_with_a_defined_policy"] = "Políticas de aplicativos personalizados para o usuário %{user}",
    ["user_protocols_with_a_defined_quota"] = "Políticas de aplicativo de cota para o usuário %{user}",
    ["user_protocols_with_policy_x"] = "%{x} Políticas de aplicativo para usuário %{user}",
    ["users_list"] = "Lista de usuários",
    ["view_quotas"] = "Visualizar Quota",
    ["wan"] = "WAN",
    ["wan_interface"] = "Interface WAN",
    ["with_quota"] = "Com Quota",
    ["x_shaper_per_host_descr"] = "A %{shaper} alocação máxima de largura de banda por host. 0 para ilimitado.",
    ["you_can_assign_routing_policy"] = "Você pode atribuir políticas de roteamento para <a href=\"%{url}\">Users</a>.",
    ["you_can_assign_shapers_to_users_protocols"] = "Você pode atribuir políticas de largura de banda <a href=\"%{url}\">Users</a> aplicações específicas ou defini-las globalmente como <a href=\"%{url2}\">Política de reserva</a>.",
    ["you_can_set_static_dhcp_lease_here"] = "Você pode configurar entrada DHCP estáticas <a href=\"%{url}\">here</a>.",
    ["you_can_use_gateways_in_policies"] = "Você pode especificar as prioridades dos gateways <a href=\"%{url}\">Políticas de roteamento</a>.",
    ["policy_source_labels"] = {
      ["policy_source_category"] = "Política de Categoria",
      ["policy_source_default"] = "Desconhecido",
      ["policy_source_device_protocol"] = "Política de Aplicativo do Dispositivo",
      ["policy_source_pool"] = "Política Padrão",
      ["policy_source_protocol"] = "Política de Aplicação",
    },
  },
  ["network_alert_config"] = {
    ["trigger_alerts_for_network"] = "Acionar alertas para a rede %{network}",
    ["trigger_network_alerts"] = "Alertas de rede de disparo",
  },
  ["network_details"] = {
    ["network"] = "Rede",
    ["network_parameter_missing_message"] = "Parâmetro de rede está ausente (erro interno?)",
    ["no_available_stats_for_network"] = "Não há estatísticas disponíveis para rede %{network}",
  },
  ["network_stats"] = {
    ["network_list"] = "Lista de rede",
    ["network_name"] = "Nome da rede",
    ["networks"] = "Redes",
    ["networks_traffic_with_ipver"] = "%{networks} com IPv%{ipver} tráfego",
    ["note_broader_network"] = "A rede mais ampla não incluirá hosts definidos em redes menores.",
    ["note_overlapping_networks"] = "NOTA: Caso você tenha definido redes sobrepostas:",
    ["note_see_both_network_entries"] = "Você verá as duas entradas de rede na tabela acima.",
  },
  ["os_stats"] = {
    ["hosts_by_operating_system"] = "Hosts por sistema operacional",
  },
  ["packets_page"] = {
    ["arp_distribution"] = "Distribuição ARP",
    ["ip_version_distribution"] = "Distribuição de Versão IP",
    ["lost"] = "Perdido",
    ["out_of_order"] = "Fora de serviço",
    ["received_distribution"] = "Distribuição Recebida",
    ["retransmissions"] = "Retransmissões",
    ["sent_distribution"] = "Distribuição Enviada",
    ["sent_vs_rcvd_distribution"] = "Distribuição Enviada / Recebida",
    ["size_distribution"] = "Distribuição de Tamanho",
    ["tcp_flags_distribution"] = "Distribuição de bandeiras TCP",
    ["tcp_flags_vs_arp_distribution"] = "Distribuição de bandeiras TCP / ARP",
    ["tcp_packets_analysis"] = "Análise de pacotes TCP",
    ["version_vs_flags_distribution"] = "Distribuição de IP version / TCP Flags",
  },
  ["peers_page"] = {
    ["host"] = "Host",
    ["no_active_flows_message"] = "Nenhum fluxo ativo foi observado para o host especificado",
    ["top_peer_protocol"] = "Principais aplicativos de pares",
    ["top_peers_for_host"] = "Topo %{hostkey} Pares",
    ["traffic_volume"] = "Volume de trafego",
  },
  ["please_wait_page"] = {
    ["command"] = "Comando",
    ["database"] = "Base de dados",
    ["host"] = "Host",
    ["id"] = "Id",
    ["info"] = "Info",
    ["operations_on_database_msg"] = "As operações atualmente realizadas no banco de dados são as seguintes: ",
    ["state"] = "Estado",
    ["time"] = "Tempo",
    ["user"] = "Usuário",
    ["waiting_for_db_msg"] = "Migração do esquema do banco de dados em andamento, aguardando pelo banco de dados <b>%{dbname}</b> tornar-se operacional. Você será redirecionado assim que o banco de dados estiver pronto. Dependendo do tamanho do banco de dados existente, essa operação pode levar muito tempo.As migrações são realizadas apenas uma vez e somente durante as principais atualizações de versão. Em caso de dúvida, entre em contato com os desenvolvedores em <a href='mailto:info@ntop.org'>info@ntop.org</a>.",
  },
  ["policy_presets"] = {
    ["business"] = "O negócio",
    ["business_description"] = "Uma predefinição para funcionários de empresas de negócios",
    ["child"] = "Criança",
    ["child_description"] = "Uma predefinição para crianças. Bloqueia redes sociais e limita o tempo de jogo",
    ["default"] = "Padrão",
    ["guests"] = "Convidados",
    ["guests_description"] = "Uma predefinição para os convidados. Apenas navegação básica permitida",
    ["no_obfuscation"] = "Sem ofuscação",
    ["no_obfuscation_description"] = "Uma predefinição para evitar ofuscação de tráfego",
    ["walled_garden"] = "Área de exceção",
    ["walled_garden_description"] = "Blocos VPN e Redes Sociais",
  },
  ["pool_details"] = {
    ["host_pool"] = "Pool de host",
    ["host_pool_timeseries_enable_message"] = "As séries de horas do Pool de hosts podem ser ativadas <A HREF=\"%{url}\">%{icon_flask} Preferences</A>. São necessários alguns minutos para ver os primeiros pontos de dados.",
    ["no_available_data_for_host_pool_message"] = "Não há dados disponíveis para o Pool de Hosts '%{pool_name}'.",
    ["pool_parameter_missing_message"] = "Parâmetro está faltando (erro interno ?)",
  },
  ["pool_stats"] = {
    ["host_pool_list"] = "Lista do Pool de Hosts",
  },
  ["port_details"] = {
    ["active_flows_for_host_and_port"] = "Fluxos Ativos para %{host}:%{port}",
    ["active_flows_on_port"] = "Fluxos Ativos no Porto %{port}",
    ["active_flows_on_port_symbolic"] = "Fluxos Ativos no Porto %{port} [%{symbolic_port}]",
    ["l4_port"] = "Porta L4",
  },
  ["ports_page"] = {
    ["client_ports"] = "Portas do Cliente",
    ["server_ports"] = "Portas do servidor",
  },
  ["prefs"] = {
    ["active_local_host_cache_interval_description"] = "Intervalo entre despejos de cache de hosts locais ativos consecutivos. Padrão: 1 hora.",
    ["active_local_host_cache_interval_title"] = "Intervalo de cache do host local ativo",
    ["admin_group_description"] = "Nome do grupo ao qual o usuário deve pertencer para se autenticar como administrador.",
    ["admin_group_title"] = "Grupo Administrativo LDAP",
    ["alert_entity"] = "Entidade de Alerta",
    ["alerts_notifications"] = "Pontos de Alerta",
    ["alerts_retention"] = "Retenção de Alertas",
    ["alerts_settings"] = "Configurações de alertas",
    ["all"] = "Todas",
    ["auth_methods_order"] = "A ordem de verificação dos métodos de autenticação é igual à ordem de listagem acima, por exemplo. se o LDAP e a autenticação local estiverem ativados, o LDAP será verificado primeiro e, se a autenticação falhar, a autenticação local será verificada em seguida..",
    ["authentication"] = "Autenticação",
    ["authentication_duration"] = "Duração de Autenticação",
    ["authentication_duration_descr"] = "Quantidade de tempo antes que a sessão de um usuário autenticado seja encerrada e a nova autenticação seja necessária. As alterações afetarão apenas as sessões recém-criadas.",
    ["authentication_duration_title"] = "Duração da sessão autenticada",
    ["authentication_midnight_expiration_descr"] = "Alterna o término das sessões à meia-noite, forçando todos os usuários autenticados a se autenticar novamente após a meia-noite.",
    ["authentication_midnight_expiration_title"] = "Rescisão de sessão autenticada à meia-noite",
    ["bind_dn_description"] = "Vincular nome distinto do servidor LDAP. Exemplo:",
    ["bind_dn_title"] = "DN de ligação LDAP",
    ["bind_pwd_description"] = "Senha de ligação usada para autenticar com o servidor LDAP.",
    ["bind_pwd_title"] = "Senha de Autenticação de Ligação LDAP",
    ["both"] = "Ambas",
    ["cache_settings"] = "Configurações de Cache",
    ["captive_portal_disabled_message"] = "Este botão é <b>disabled</b> como a GUI da web ntopng NÃO foi iniciada na porta 80 que é exigida pelo portal cativo (-w command line parameter, e.g. -w 80,3000).",
    ["captive_portal_url_description"] = "A URL para a qual seus clientes serão redirecionados após uma autenticação bem-sucedida do portal cativo.",
    ["captive_portal_url_title"] = "URL de redirecionamento",
    ["client_x509_auth"] = "Autenticação de Cliente HTTPS",
    ["client_x509_auth_descr"] = "Alternar a autenticação de clientes com base em seu certificado X.509. Quando o nome comum do cliente X.509 (CN) é igual a um dos usuários ntopng, então o cliente é autenticado como o usuário ntopng. Alterações nesta configuração requerem uma reinicialização ntopng.",
    ["client_x509_auth_title"] = "Autenticação de certificado do cliente X.509",
    ["could_not_contact_influxdb"] = "Não foi possível contatar o banco de dados do InfluxDB: %{msg}",
    ["databases"] = "Bancos de dados",
    ["default_snmp_community_description"] = "A comunidade SNMP padrão é usada ao tentar executar o SNMP MIB de um host local selecionado que não foi configurado por meio da página de dispositivos SNMP.",
    ["default_snmp_community_title"] = "Comunidade SNMP padrão",
    ["default_snmp_proto_version_description"] = "A versão do protocolo SNMP padrão.",
    ["default_snmp_proto_version_title"] = "Versão SNMP padrão",
    ["device_identifier"] = "Identificador de Dispositivo",
    ["device_identifier_descr"] = "Geralmente os dispositivos são identificados pelo endereço MAC. No entanto, se os dispositivos estiverem atrás de um roteador, a identificação de IP é preferível.",
    ["disable_alerts_generation_description"] = "Alterne a geração geral de alertas.",
    ["disable_alerts_generation_title"] = "Ativar alertas",
    ["dns"] = "DNS",
    ["dns_service"] = "Serviço",
    ["dump_settings"] = "Banco de dados de fluxo",
    ["dynamic_interfaces_creation_description"] = "O ntopng pode usar um critério para desagregar o tráfego de entrada. Quando um critério de desagregação é selecionado, o ntopng usará o valor de critério para desviar o tráfego de entrada para interfaces criadas dinamicamente. Por exemplo, quando o critério 'VLAN Id' é selecionado, uma interface dinâmica será criada para cada ID de VLAN observada, e o tráfego de entrada será desviado para uma interface dinâmica, dependendo do valor de ID da VLAN. ",
    ["dynamic_interfaces_creation_note_0"] = "A desagregação de 'VLAN Id' é suportada tanto para interfaces físicas quanto para fluxos recebidos pelo ZMQ. Os outros critérios de desagregação são suportados apenas para fluxos do ZMQ e serão ineficazes para interfaces físicas.",
    ["dynamic_interfaces_creation_note_1"] = "Alterações de critérios não afetarão as interfaces existentes. <b>Um reinício de ntopng é necessário para que a mudança tenha efeito</b>.",
    ["dynamic_interfaces_creation_note_2"] = "Ao usar o critério 'Ingress Interface' em dispositivos que não são sflow, %%INPUT_SNMP deve aparecer no modelo nprobe.",
    ["dynamic_interfaces_creation_note_3"] = "Critério de desagregação 'Interface' adiciona qualquer fluxo a duas interfaces dinâmicas. O valor de %%INPUT_SNMP é usado para selecionar a primeira interface dinâmica, enquanto o valor de %%OUTPUT_SNMP é usado para selecionar o segundo.",
    ["dynamic_interfaces_creation_title"] = "Critério de desagregação",
    ["dynamic_network_interfaces"] = "Interfaces dinâmicas de rede",
    ["elephant_flow_local_to_remote_bytes_description"] = "A quantidade de dados que um fluxo pode carregar antes de ser considerado um fluxo de elefantes.",
    ["elephant_flow_local_to_remote_bytes_title"] = "Elephant Flows Threshold (Local para remoto)",
    ["elephant_flow_remote_to_local_bytes_description"] = "A quantidade de dados que um fluxo pode baixar antes de ser considerado um fluxo de elefantes.",
    ["elephant_flow_remote_to_local_bytes_title"] = "Elephant Flows Threshold (Remoto para Local)",
    ["email_notification"] = "Notificação de Email",
    ["email_notification_recipient_description"] = "O endereço de email do destinatário.",
    ["email_notification_recipient_title"] = "Recebedor",
    ["email_notification_sender_description"] = "O endereço de email do remetente.",
    ["email_notification_sender_title"] = "Remetente",
    ["email_notification_server_description"] = "O servidor SMTP para entregar o email.",
    ["email_notification_server_title"] = "Servidor SMTP",
    ["email_send_error"] = "E-mail enviar erro. Por favor verifique <a href='%{url}'>a documentação online</a> para mais detalhes.",
    ["email_sent_successfully"] = "E-mail enviado com sucesso",
    ["errors"] = "Erros",
    ["errors_and_warnings"] = "Erros e Avisos",
    ["ewma_alpha_percent_description"] = "Média móvel ponderada exponencialmente (EWMA) coeficiente alfa, expresso em porcentagem. Usado para estimar o tempo de ida e volta dos Sistemas Autônomos.",
    ["ewma_alpha_percent_title"] = "Coeficiente alfas EWMA (por cento)",
    ["expert_view"] = "Visão de especialista",
    ["featured_dns_description"] = "A seguir, uma lista de servidores DNS seguros. Você pode usá-los como servidores DNS globais ou como provedor Child Safe.",
    ["featured_dns_title"] = "Servidores DNS em destaque",
    ["flow_interface"] = "Interface",
    ["flow_max_idle_description"] = "Tempo de inatividade após o qual um fluxo é considerado ocioso. Padrão: 1 min.",
    ["flow_max_idle_title"] = "Tempo limite de ociosidade do fluxo",
    ["flows_dump_limited_days"] = "O despejo de fluxo é limitado a %{days} dias nesta versão ntopng. Atualize para a versão corporativa para remover esse limite.",
    ["global_dns_description"] = "Um servidor DNS para redirecionar as solicitações de DNS dos clientes para pools de host não seguros para filho. Se vazio, o redirecionamento é desativado e o DNS padrão é usado.",
    ["global_dns_title"] = "DNS principal global",
    ["google_apis_browser_key_description"] = "Geomaps de hosts gráficos são baseados nas APIs do Google Maps. O Google recentemente alterou as políticas de acesso à API do Google Maps e agora exige que uma chave da API do navegador seja enviada para todas as solicitações. Informações detalhadas sobre como obter uma chave de API podem ser encontradas <a href=\"%{url}\">here</a>. Uma vez obtida, a chave da API pode ser colocada nesse campo.",
    ["google_apis_browser_key_title"] = "Chave do navegador das APIs do Google",
    ["host_mask"] = "Endereços IP do host da máscara",
    ["http_auth"] = "Autenticação HTTP",
    ["http_auth_server_description"] = "A URL do servidor HTTP a ser usada para autenticar usuários.",
    ["http_auth_server_title"] = "Servidor HTTP",
    ["idle_timeout_settings"] = "Configurações de tempo limite ocioso",
    ["ignored_interfaces_description"] = "Quando 'Ingress Interface' é selecionado como critério de desagregação, não adicione a uma interface dinâmica nenhum fluxo %%INPUT_SNMP nesta lista. Quando a desagregação 'Interface' é selecionada, não adicione ao primeiro (second) interface dinâmica qualquer fluxo tendo o seu %%INPUT_SNMP (%%OUTPUT_SNMP) nesta lista. Especifique um ou mais IDs de interface SNMP separados por vírgulas. Mudanças requerem %{product} reiniciar.",
    ["ignored_interfaces_title"] = "Interfaces ignoradas",
    ["incompatible_influxdb_version_found"] = "Versão Incompatible do InfluxDB: obrigatório \"%{required}\", found \"%{found}\". Por favor, instale uma versão atualizada do <a href='%{url}'>official site</a>.",
    ["influxdb_auth_description"] = "Ativar autenticação do InfluxDB.",
    ["influxdb_auth_title"] = "Autenticação do InfluxDB",
    ["influxdb_create_error"] = "Não foi possível criar \"%{db}\" database: %{msg}",
    ["influxdb_dbname_description"] = "O banco de dados a ser usado para armazenamento de série temporal. Os dados existentes não serão migrados.",
    ["influxdb_dbname_title"] = "Banco de dados do InfluxDB",
    ["influxdb_password_description"] = "A senha para autenticar com o banco de dados do InfluxDB.",
    ["influxdb_retention_error"] = "Não foi possível definir a política de retenção no banco de dados \"%{db}\": %{msg}",
    ["influxdb_storage_description"] = "Dias de retenção de dados da série temporal do InfluxDB (use 0 para ilimitado). Padrão: 365 dias.",
    ["influxdb_storage_title"] = "Armazenamento do InfluxDB",
    ["influxdb_url_description"] = "O URL apontando para uma instância do InfluxDB em execução.",
    ["influxdb_url_title"] = "InfluxDB URL",
    ["influxdb_username_description"] = "O nome de usuário para autenticar com o banco de dados do InfluxDB.",
    ["ingress_flow_interface"] = "Interface de entrada",
    ["ingress_vrf_id"] = "ID do VRF de ingresso",
    ["interfaces_timeseries"] = "Interfaces Timeseries",
    ["internal_log"] = "Log Interno",
    ["is_influxdb_running"] = "O InfluxDB está em execução?",
    ["l2_devices_timeseries"] = "Dispositivos de séries temporais",
    ["ldap_authentication"] = "Autenticação LDAP",
    ["ldap_server_address_description"] = "Endereço IP e porta do servidor LDAP (e.g. ldaps://localhost:636). Padrão: \"ldap://localhost:389\".",
    ["ldap_server_address_title"] = "Endereço do servidor LDAP",
    ["license"] = "Licença",
    ["local_auth"] = "Autenticação Local",
    ["local_host_cache_duration_description"] = "Tempo após o qual um host local armazenado em cache é excluído do cache. Padrão: 1 hora.",
    ["local_host_cache_duration_title"] = "Duração do Cache dos Hosts Locais",
    ["local_host_mask"] = "Hosts locais de máscara",
    ["local_host_max_idle_description"] = "Tempo de inatividade após o qual um host local é considerado inativo (sec). Os hosts locais inativos são despejados em um cache para que seus contadores possam ser restaurados caso eles se tornem ativos novamente. Os contadores incluem, mas não estão limitados a, pacotes e bytes total e por aplicativo de camada 7. Padrão: 5 min.",
    ["local_host_max_idle_title"] = "Tempo limite ocioso do host local",
    ["local_hosts_cache_settings"] = "Configurações de cache de hosts locais",
    ["local_hosts_timeseries"] = "Hosts locais de séries temporais",
    ["logging"] = "Fazendo login",
    ["longlived_flow_duration_description"] = "A duração mínima para um fluxo ser considerado um Fluxo de Vida Longa.",
    ["longlived_flow_duration_title"] = "Duração dos Fluxos de Vida Longa",
    ["max_num_alerts_per_entity_description"] = "O número máximo de alertas por entidade alarmante. Entidades alarmantes são hosts, redes, interfaces. Os alertas são verificados periodicamente e, caso o número real de alertas exceda o número máximo de uma determinada entidade, os alertas mais antigos serão excluídos para preservar um número de alertas igual a 80 %% do número máximo configurado. Padrão: 1024.",
    ["max_num_alerts_per_entity_title"] = "Número máximo de alertas por entidade",
    ["max_num_bytes_per_tiny_flow_description"] = "O número máximo de bytes que um fluxo deve ter para ser considerado um fluxo pequeno. Padrão: 64.",
    ["max_num_bytes_per_tiny_flow_title"] = "Número máximo de bytes por fluxo minúsculo",
    ["max_num_flow_alerts_description"] = "O número máximo de alertas de fluxo. Os alertas são verificados periodicamente e, caso o número real de alertas de fluxo exceda o número máximo configurado, os alertas mais antigos serão excluídos para preservar um número de alertas igual a 80 %% do número máximo configurado. Padrão: 16384.",
    ["max_num_flow_alerts_title"] = "Número Máximo de Alertas de Fluxo",
    ["max_num_packets_per_tiny_flow_description"] = "O número máximo de pacotes que um fluxo deve ter para ser considerado um fluxo minúsculo. Padrão: 3.",
    ["max_num_packets_per_tiny_flow_title"] = "Número máximo de pacotes por fluxo minúsculo",
    ["max_ui_strlen_description"] = "Encurte as cadeias mais longas do que o número máximo de caracteres especificado.",
    ["max_ui_strlen_title"] = "Comprimento máximo da string exibida",
    ["mgmt_acl_description"] = "Uma lista separada por vírgulas de redes IPv4. Cada rede deve ser explicitamente permitida ou não permitida por um líder \"+\" or \"-\" assinar, respectivamente. O princípio de correspondência mais longa é usado com redes sobrepostas. Exemplos: \"+127.0.0.0/8\" torna a interface acessível apenas a partir do localhost, \"+0.0.0.0/0,-192.168.0.0/16\", torna a interface acessível para todos, exceto 192.168.0.0/16. Deve reiniciar %{product} para que as mudanças tenham efeito.",
    ["mgmt_acl_title"] = "Lista de Controle de Acesso",
    ["minute_top_talkers_retention_description"] = "Número de dias para manter as estatísticas de alto nível de resolução de um minuto. Padrão: 365 dias.",
    ["minute_top_talkers_retention_title"] = "Armazenamento dos principais locutores",
    ["misc"] = "diversos",
    ["multiple_ldap_account_type_description"] = "Escolha o seu tipo de conta",
    ["multiple_ldap_account_type_title"] = "Tipo de Contas LDAP",
    ["multiple_timeseries_database_description"] = "O driver usado para armazenar e recuperar dados de série temporal.",
    ["multiple_timeseries_database_title"] = "Driver de série temporal",
    ["mysql"] = "MySQL",
    ["mysql_retention_description"] = "Duração em dias de retenção de dados para o banco de dados MySQL. Padrão: 7 dias.<br>MySQL é usado para armazenar dados de fluxos exportados.<br>Flows dump só é possível se a instância ntopng tiver sido lançada com opção ",
    ["mysql_retention_title"] = "Armazenamento MySQL",
    ["n2disk_license_description"] = "A gravação contínua de tráfego requer uma licença n2disk, compre uma em <a href=\"%{purchase_url}\">e-shop</a>. Se você é sem fins lucrativos, pesquisa ou instituição de ensino, por favor leia <a href=\"%{universities_url}\">this</a>.",
    ["n2disk_license_systemid"] = "SystemID: %{systemid}",
    ["n2disk_license_title"] = "Chave de licença do n2disk",
    ["n2disk_license_version"] = "Versão n2disk: %{version}",
    ["n2n_supernode_description"] = "O endereço do <a class='ntopng-external-link' href=\"%{url}\">n2n <i class=\"fas fa-external-link-alt\"></i></a> supernode. Configure seu próprio supernode para ter um acesso remoto totalmente privado.<br>OBSERVAÇÃO: essa alteração afetará somente após a reinicialização da Assistência Remota.",
    ["n2n_supernode_title"] = "Supernode",
    ["network_discovery"] = "Descoberta de rede",
    ["network_discovery_interval_description"] = "Intervalo entre descobertas consecutivas de redes. Padrão: 15 min.",
    ["network_discovery_interval_title"] = "Intervalo de descoberta de rede ativa",
    ["network_interfaces"] = "Interfaces de Rede",
    ["nindex_retention_description"] = "Número de dias para manter fluxos indexados para exploração histórica.",
    ["nindex_retention_title"] = "Armazenamento de índice de fluxo",
    ["no_host_mask"] = "Não mascare hosts",
    ["non_local_host_max_idle_description"] = "Tempo de inatividade após o qual um host remoto é considerado ocioso. Padrão: 1 min.",
    ["non_local_host_max_idle_title"] = "Tempo limite ocioso do host remoto",
    ["none"] = "Nenhum",
    ["note_timeseries_resolution_disabled"] = "NOTA: isso está desativado porque \"%{pref}\" não está definido para o valor padrão.",
    ["other_timeseries"] = "Outras séries temporais",
    ["per_category"] = "Por categoria",
    ["per_protocol"] = "Por aplicação",
    ["policy_target_type"] = "Tipo de segmentação de política",
    ["policy_target_type_description"] = "Especifique o tipo de segmentação por política que você deseja aplicar.",
    ["posix"] = "Posix",
    ["preferences"] = "Preferências",
    ["primary_dns"] = "DNS primário",
    ["probe_ip_address"] = "Probe IP",
    ["protocols"] = "Aplicações",
    ["radius_admin_group_description"] = "O usuário é autenticado como admin quando o valor para o par Filter-Id Attribute-Value retornado pelo RADIUS corresponde ao especificado neste campo. Quando não há correspondência, o usuário é autenticado como não privilegiado.",
    ["radius_admin_group_title"] = "RADIUS Admin Filter-Id",
    ["radius_auth"] = "Autenticação RADIUS",
    ["radius_secret_descroption"] = "O segredo compartilhado para autenticar com o servidor RADIUS.",
    ["radius_secret_title"] = "Sigilo RADIUS",
    ["radius_server_description"] = "Host e porta do servidor RADIUS (e.g. %{example}).",
    ["radius_server_title"] = "Endereço do servidor RADIUS",
    ["recording"] = "Gravação de Tráfego",
    ["remote_host_mask"] = "Hosts remotos de máscara",
    ["report"] = "Relatório",
    ["rrd_files_retention_description"] = "O número máximo de dias que os RRDs não atualizados são preservados antes de serem excluídos.<br><b>NOTE</b>: o tempo de retenção de um único RRD é sempre de 365 dias, independentemente desta configuração.",
    ["rrd_files_retention_title"] = "Retenção antiga de RRDs",
    ["runtime_prefs"] = "Preferências de Tempo de Execução",
    ["safe_search_dns_description"] = "O servidor DNS a ser usado para executar <a href='%{url}'>Child Safe</a> queries.<br>Child A segurança pode ser ativada para pools de host individuais na página de configuração de pools de host. Padrão: 208.67.222.123.",
    ["safe_search_dns_title"] = "DNS seguro para crianças",
    ["samaccount"] = "sAMAccount",
    ["search_path_description"] = "Caminho raiz usado para pesquisar os usuários.",
    ["search_path_title"] = "Caminho de pesquisa LDAP",
    ["search_preferences"] = "Preferências de pesquisa",
    ["secondary_dns"] = "DNS secundário",
    ["secondary_dns_description"] = "Um servidor DNS de fallback para usar quando o servidor DNS primário global não está disponível.",
    ["secondary_dns_title"] = "DNS secundário global",
    ["security_alerts"] = "Alertas de segurança",
    ["send_test_mail"] = "Enviar email de teste",
    ["send_test_slack"] = "Enviar mensagem de teste",
    ["send_test_webhook"] = "Enviar mensagem de teste",
    ["sender_username_description"] = "Definir o nome de usuário do remetente de notificações de folga",
    ["sender_username_title"] = "Nome de Usuário do Remetente da Notificação",
    ["simple_view"] = "Visão simples",
    ["slack_channel"] = "Canal de folga",
    ["slack_channel_names"] = "Nomes de Canais",
    ["slack_channel_names_descr"] = "Configure os canais do Slack nos quais cada alerta será enviado. Os canais devem existir para exibir corretamente o alerta.",
    ["slack_integration"] = "Integração Slack",
    ["slack_notification_severity_preference_description"] = "Erros (somente erros), Erros e Avisos (erros e avisos, sem informação), Tudo (todos os tipos de alertas serão notificados).",
    ["slack_notification_severity_preference_title"] = "Gravidade de Notificação",
    ["slack_send_error"] = "Enviar mensagem de erro negligente.",
    ["slack_sent_successfully"] = "Uma mensagem de folga foi enviada para o #%{channel} canal.",
    ["slack_webhook_description"] = "Envie sua notificação para este URL de folga",
    ["slack_webhook_title"] = "Notificação Webhook",
    ["snmp"] = "SNMP",
    ["stats_reset"] = "Reposição de Estatísticas",
    ["status_alerts"] = "Alertas de status",
    ["successfully_connected_influxdb"] = "Banco de dados inicializado com sucesso \"%{db}\" no InfluxDB(%{version})",
    ["syslog_alert_format_description"] = "Escolheu o formato de saída de alertas do syslog.",
    ["syslog_alert_format_json"] = "JSON",
    ["syslog_alert_format_plaintext"] = "Texto simples",
    ["syslog_alert_format_title"] = "Formato de alertas do syslog",
    ["syslog_notification"] = "Notificação Syslog",
    ["timeseries"] = "Timeseries",
    ["timeseries_database"] = "Banco de dados de séries temporais",
    ["timeseries_resolution_resolution_description"] = "O intervalo entre os pontos de dados em timeseries de alta resolução, em particular os hosts locais e os aplicativos da interface L7.",
    ["timeseries_resolution_resolution_title"] = "Resolução de Aplicações L7",
    ["toggle_access_log_description"] = "Alternar a criação do log de acesso HTTP no diretório de despejo de dados. Configurações terão efeito na próxima %{product} comece.",
    ["toggle_access_log_title"] = "Ativar o log de acesso HTTP",
    ["toggle_active_local_host_cache_enabled_description"] = "Alterne a criação de entradas de cache para hosts locais ativos. O armazenamento em cache de hosts locais ativos periodicamente pode ser útil para proteger os hosts contra falhas (e.g., power losses). Isso é particularmente importante para hosts locais que raramente ficam ociosos, pois garante que seus contadores sejam armazenados em cache após o intervalo de tempo especificado..",
    ["toggle_active_local_host_cache_enabled_title"] = "Cache de Hosts Ativos Locais",
    ["toggle_alert_probing_description"] = "Alternar alertas gerados quando as tentativas de sondagem são detectadas.",
    ["toggle_alert_probing_title"] = "Alertas de pesquisa",
    ["toggle_alert_syslog_description"] = "Alternar alertas registrados no syslog do sistema.",
    ["toggle_alert_syslog_title"] = "Alternar notificação de syslog",
    ["toggle_alerts_notifications_description"] = "Alternar o relatório de alerta para endpoints de terceiros.",
    ["toggle_alerts_notifications_title"] = "Alertas para endpoints de terceiros",
    ["toggle_asn_rrds_description"] = "Alternar a criação de bytes e timeseries de aplicativos para sistemas autônomos.",
    ["toggle_asn_rrds_title"] = "Sistemas autônomos",
    ["toggle_autologout_description"] = "Alternar o logout automático de usuários da interface da web com sessões expiradas.",
    ["toggle_autologout_title"] = "logout automático",
    ["toggle_captive_portal_description"] = "Ativar o portal cativo da web para autenticar usuários da rede.",
    ["toggle_captive_portal_title"] = "Portal cativo",
    ["toggle_country_rrds_description"] = "Alternar a criação de timeseries de bytes para países.",
    ["toggle_country_rrds_title"] = "Países",
    ["toggle_device_activation_alert_description"] = "Alternar alertas gerados quando os dispositivos se conectam ou desconectam da rede.",
    ["toggle_device_activation_alert_title"] = "Conexão de Dispositivos/Alertas de Desconexão",
    ["toggle_device_first_seen_alert_description"] = "Alternar alertas gerados quando novos dispositivos não vistos aparecerem na rede.",
    ["toggle_device_first_seen_alert_title"] = "Conexão de novos dispositivos",
    ["toggle_device_protocols_description"] = "Alternar alertas gerados quando um aplicativo anômalo é detectado de acordo com a configuração <a href=\"%{url}\">políticas de aplicativos de dispositivo</a>.",
    ["toggle_device_protocols_description_nedge"] = "Alternar alertas gerados quando um protocolo anômalo <i>Not Assigned</i> dispositivos é detectado de acordo com o <a href=\"%{url}\">políticas de protocolos de dispositivo</a>.",
    ["toggle_device_protocols_title"] = "Alertas de aplicativos de dispositivo",
    ["toggle_dns_alerts_description"] = "Alternar alertas gerados quando a consulta DNS é inválida",
    ["toggle_dns_alerts_title"] = "Alertas de DNS",
    ["toggle_dropped_flows_alerts_description"] = "Ativar alertas informativos gerados no bloco de fluxos devido às políticas configuradas",
    ["toggle_dropped_flows_alerts_title"] = "Ativar alertas de fluxos bloqueados",
    ["toggle_dst_with_post_nat_dst_description"] = "Substituir endereços de destino IPv4 (%%IPV4_DST_ADDR) e portas (%%L4_DST_PORT) com seus valores pós-nat (%%POST_NAT_DST_IPV4_ADDR and %%POST_NAPT_DST_TRANSPORT_PORT).",
    ["toggle_dst_with_post_nat_dst_title"] = "Use endereços IPv4 de destino pós-nat e portas",
    ["toggle_elephant_flows_alerts_description"] = "Alternar alertas gerados quando um fluxo de elefantes foi detectado. Isso é útil para detectar comportamentos indesejados (por exemplo. exfiltração de dados).",
    ["toggle_elephant_flows_alerts_title"] = "Elephant Flows Alerts",
    ["toggle_email_notification_description"] = "Alternar notificações de alertas por email.",
    ["toggle_email_notification_title"] = "Alternar notificação por email",
    ["toggle_flow_alerts_iface_description"] = "Ative a geração de alertas de fluxo quando a interface de rede é alertada.",
    ["toggle_flow_alerts_iface_title"] = "Ativar alertas de fluxo",
    ["toggle_flow_rrds_description"] = "Alterne a criação de timeseries de bytes para cada porta do dispositivo remoto recebida pelo ZMQ (e.g. sFlow/NetFlow/SNMP).<br>Para dispositivos não sFlow, %%INPUT_SNMP and %%OUTPUT_SNMP deve aparecer no modelo nprobe.",
    ["toggle_flow_rrds_title"] = "Dispositivos de fluxo",
    ["toggle_host_mask_description"] = "Por motivos de privacidade, pode ser necessário mascarar os endereços IP dos hosts. Por exemplo, se você é um ISP, você não deveria saber quais endereços locais estão acessando hosts remotos..",
    ["toggle_host_mask_title"] = "Endereços IP do host da máscara",
    ["toggle_host_pools_log_description"] = "Alterne a criação de logs relacionados a pools de host. Logs incluem associações e desassociações de hosts para seus pools de host.",
    ["toggle_host_pools_log_title"] = "Ativar log de eventos do pool de hosts",
    ["toggle_host_tskey_description"] = "A chave a ser usada para serializar os hosts no domínio de transmissão local. Em um ambiente dinâmico (DHCP) geralmente é desejável escolher 'Endereço Mac'.",
    ["toggle_host_tskey_title"] = "Identificador de hosts de domínio de transmissão local",
    ["toggle_http_auth"] = "Alternar Autenticação HTTP",
    ["toggle_http_auth_descr"] = "Alternar autenticação de gui através de um autenticador HTTP.",
    ["toggle_informative_captive_portal_description"] = "Não autentique usuários. Mostrar apenas uma página informativa antes de permitir que os usuários acessem a Internet.",
    ["toggle_informative_captive_portal_title"] = "Informativo",
    ["toggle_ip_reassignment_description"] = "Alternar alertas gerados quando um endereço IP, visto anteriormente com um endereço MAC, é visto agora com outro endereço MAC. Esse alerta pode indicar uma tentativa de falsificação ARP.",
    ["toggle_ip_reassignment_title"] = "Alertas de reatribuição de IP",
    ["toggle_ldap_anonymous_bind_description"] = "Ativar ligação anônima.",
    ["toggle_ldap_anonymous_bind_title"] = "Ligação Anônima LDAP",
    ["toggle_ldap_auth"] = "Alternar autenticação LDAP",
    ["toggle_ldap_auth_descr"] = "Alternar autenticação de gui via LDAP.",
    ["toggle_ldap_referrals_description"] = "Especifica se o cliente deve seguir automaticamente as referências retornadas pelos servidores LDAP.",
    ["toggle_ldap_referrals_title"] = "Siga as referências",
    ["toggle_local_auth"] = "Alternar Autenticação Local",
    ["toggle_local_auth_descr"] = "Alternar autenticação de gui de acordo com %{product} usuários definidos.",
    ["toggle_local_host_cache_enabled_description"] = "Alterne a criação de entradas de cache para hosts locais ociosos. Os contadores de hosts locais armazenados em cache são restaurados automaticamente para seus valores anteriores após a detecção de tráfego de host adicional.",
    ["toggle_local_host_cache_enabled_title"] = "Cache de hosts locais ociosos",
    ["toggle_log_to_file_description"] = "Alterne a criação de ntopng.log no diretório de despejo de dados em vez de usar o syslog. Configurações terão efeito na próxima %{product} comece.",
    ["toggle_log_to_file_title"] = "Ativar Log de Rastreamento",
    ["toggle_logging_level_description"] = "Escolha o nível de log de tempo de execução.",
    ["toggle_logging_level_title"] = "Nível de log",
    ["toggle_longlived_flows_alerts_description"] = "Alternar alertas gerados quando um fluxo de longa duração foi detectado. Isso é útil para detectar comportamentos indesejados (por exemplo. exfiltração de dados).",
    ["toggle_longlived_flows_alerts_title"] = "Alertas de Fluxos de Vida Longa",
    ["toggle_malware_probing_description"] = "Alternar alertas gerados pelo tráfego enviado / recebido por hosts marcados com malware. As listas negras de malware podem ser configuradas a partir do <a href=\"%{url}\">Category Lists page</a>.",
    ["toggle_malware_probing_title"] = "Alertas de Malware",
    ["toggle_midnight_stats_reset_description"] = "Alternar as estatísticas automáticas redefinidas à meia-noite. Isso inclui estatísticas de endereços de hosts e Mac.",
    ["toggle_midnight_stats_reset_title"] = "Reset da meia-noite",
    ["toggle_mining_alerts_description"] = "Alternar alertas gerados quando o tráfego de / para hosts conhecidos por executar a mineração de criptografia é detectado",
    ["toggle_mining_alerts_title"] = "Alertas de Mineração",
    ["toggle_mysql_check_open_files_limit_description"] = "Habilitar gerações de alertas do MySQL devido a verificações periódicas do MySQL open_files_limit.<br>A verificação open_files_limit é útil para detectar quando o número de arquivos MySQL abertos é alto, o que poderia levar a erros de inserção de banco de dados.",
    ["toggle_mysql_check_open_files_limit_title"] = "Ativar alertas do MySQL",
    ["toggle_ndpi_timeseries_creation_description"] = "Alterne a criação de séries temporais de aplicativos da camada 7. Criar uma série temporal por aplicativo requer mais espaço em disco e E / S extra e, em geral, não é necessário.",
    ["toggle_ndpi_timeseries_creation_title"] = "Aplicativos de camada 7",
    ["toggle_network_discovery_description"] = "Alterne a descoberta periódica de dispositivos de rede usando várias técnicas que incluem varredura ARP, MDNS e SSDP.<p><b>NOTE:</b> descoberta pode ser <u>only</u> ativado em interfaces físicas  (ou seja, sem ZMQ) onde podemos enviar / receber tráfego para a rede (isto é, interfaces somente de leitura, como aquelas conectadas a espelhos de portas, não funcionarão). ",
    ["toggle_network_discovery_title"] = "Descoberta de Rede Ativa",
    ["toggle_pool_activation_alert_description"] = "Alternar alertas gerados quando o primeiro host se conecta ou o último host desconecta de algum pool.",
    ["toggle_pool_activation_alert_title"] = "Alertas de conexão / desconexão de pools de host",
    ["toggle_pools_rrds_description"] = "Alterne a criação de timeseries de bytes e aplicativos para pools de host definidos.",
    ["toggle_pools_rrds_title"] = "Host Pools",
    ["toggle_quota_exceed_alert_description"] = "Habilite a geração de alertas sempre que um pool de hosts excede uma cota configurada.",
    ["toggle_quota_exceed_alert_title"] = "Ativar alertas de cota excedida",
    ["toggle_radius_auth"] = "Alternar a autenticação RADIUS",
    ["toggle_radius_auth_descr"] = "Alternar autenticação de gui através de um servidor RADIUS.",
    ["toggle_remote_to_remote_alerts_description"] = "Alternar alertas gerados quando o cliente e o servidor de um fluxo são remotos.",
    ["toggle_remote_to_remote_alerts_title"] = "Alertas remotos para remotos",
    ["toggle_shaping_directions_description"] = "Ative esta opção para poder definir diferentes políticas de formatação para o tráfego de entrada e saída.",
    ["toggle_shaping_directions_title"] = "Dividir formatação instrucionais",
    ["toggle_slack_notification_description"] = "Alternar notificações de alertas via folga. Veja as instruções de integração <a href='%{url}'>here</a>.",
    ["toggle_slack_notification_title"] = "Alternancia <a href=\"%{url}\">Slack</a> Notificação",
    ["toggle_snmp_alerts_port_errors_description"] = "Alternar alertas gerados quando os descartes ou contadores de erros aumentam em uma interface",
    ["toggle_snmp_alerts_port_errors_title"] = "Alertas de descartes / erros de interface",
    ["toggle_snmp_alerts_port_status_change_description"] = "Alternar alertas gerados quando o status da porta em uma interface é alterado",
    ["toggle_snmp_alerts_port_status_change_title"] = "Alertas de alteração de status da interface",
    ["toggle_snmp_rrds_description"] = "Alterne a criação de séries temporais de bytes para cada porta dos dispositivos SNMP. Para cada porta de dispositivo será criada uma série temporal com bytes de entrada / saída.",
    ["toggle_snmp_rrds_title"] = "Timeseries de dispositivos SNMP",
    ["toggle_src_with_post_nat_src_description"] = "Substituir endereços de origem IPv4 (%%IPV4_SRC_ADDR) e portas (%%L4_SRC_PORT) com seus valores pós-nat (%%POST_NAT_SRC_IPV4_ADDR and %%POST_NAPT_SRC_TRANSPORT_PORT).",
    ["toggle_src_with_post_nat_src_title"] = "Use Endereços e Portas IPv4 de Origem Pós-Nat",
    ["toggle_tcp_flags_rrds_description"] = "Alterna a criação de flags de TCP SYN, SYN + ACK, FIN + ACK e timeseries de RST para interfaces de rede.",
    ["toggle_tcp_flags_rrds_title"] = "Sinalizadores TCP",
    ["toggle_tcp_retr_ooo_lost_rrds_description"] = "Alterne a criação de timeseries para segmentos TCP fora de ordem, perdidos e retransmitidos. Séries temporais serão criadas para interfaces de rede, sistemas autônomos, redes locais e vlans.",
    ["toggle_tcp_retr_ooo_lost_rrds_title"] = "Truques TCP fora de ordem, perdidos e retransmitidos",
    ["toggle_thpt_content_description"] = "Selecione a unidade de taxa de transferência a ser exibida nos relatórios de tráfego.",
    ["toggle_thpt_content_title"] = "Unidade de rendimento",
    ["toggle_tiny_flows_dump_description"] = "Alterna a exportação de fluxos pequenos, que são fluxos com poucos pacotes ou bytes. Reduz a cardinalidade de fluxo em bancos de dados, acelera inserções e pesquisas. Ajustar fluxos minúsculos pode ajudar a limitar a cardinalidade do fluxo sem reduzir a visibilidade nas informações descartadas.",
    ["toggle_tiny_flows_dump_title"] = "Exportação de fluxos minúsculos",
    ["toggle_tls_alerts_description"] = "Alternar alertas gerados quando o certificado TLS fornecido por um servidor não corresponde ao nome comum do certificado.",
    ["toggle_tls_alerts_title"] = "Alertas TLS",
    ["toggle_top_sites_description"] = "Alterne a criação dos principais sites visitados para hosts locais. Os principais sites são criados usando um <a href=\"%{url}\">heuristic</a> que não mantêm mais de 20 sites por host local. A heurística opera totalmente na memória e não requer nenhuma interação com o disco. Os principais sites são apagados a cada 5 minutos. É possível criar um arquivo histórico dos principais sites visitados, para cada host local, consultando periodicamente o JSON <i class=\"fas fa-download fa-sm\"></i> link de download acessível a partir da página de detalhes do host.",
    ["toggle_top_sites_title"] = "Principais sites HTTP",
    ["toggle_traffic_rrd_creation_description"] = "Alternar a criação de bytes e séries de tempo de pacotes.",
    ["toggle_traffic_rrd_creation_title"] = "Tráfego",
    ["toggle_users_rrds_description"] = "Alternar a criação de timeseries de bytes e aplicativos para usuários definidos.",
    ["toggle_users_rrds_title"] = "Usuários",
    ["toggle_vlan_rrds_description"] = "Alternar a criação de timeseries de bytes e aplicativos para VLANs.",
    ["toggle_vlan_rrds_title"] = "VLANs",
    ["toggle_webhook_notification_description"] = "Alternar notificações de alertas via webhook (HTTP).",
    ["toggle_webhook_notification_title"] = "Alternar notificação do Webhook",
    ["topk_heuristic_precision_description"] = "Use uma heurística ao agregar os principais hosts, países, etc. históricos para criar relatórios de tráfego. Útil ao criar relatórios por longos períodos.",
    ["topk_heuristic_precision_title"] = "Heurístico Top-K",
    ["traffic_bridging"] = "Ponte de tráfego",
    ["traffic_shaping"] = "Formação de tráfico",
    ["user_authentication"] = "Autenticação de usuário",
    ["user_group_description"] = "Nome do grupo ao qual o usuário deve pertencer para autenticar como usuário não privilegiado.",
    ["user_group_title"] = "Grupo de Usuários LDAP",
    ["vlan"] = "VLAN Id",
    ["web_user_interface"] = "Interface do usuário da web",
    ["webhook_notification"] = "Notificação de Webhook",
    ["webhook_notification_severity_preference_description"] = "Erros (errors only), Erros e Avisos (erros e avisos, sem informação), Tudo (todos os tipos de alertas serão notificados).",
    ["webhook_notification_severity_preference_title"] = "Gravidade de Notificação",
    ["webhook_password_description"] = "A senha a ser usada no caso de autenticação HTTP (opcional).",
    ["webhook_send_error"] = "Erro ao enviar mensagem para o webhook.",
    ["webhook_sent_successfully"] = "Uma mensagem foi enviada para o webhook",
    ["webhook_sharedsecret_description"] = "Definir um (user-defined) segredo a ser validado pelo receptor (optional).",
    ["webhook_sharedsecret_title"] = "Segredo partilhado",
    ["webhook_url_description"] = "Enviar notificação para este URL no formato JSON.",
    ["webhook_url_title"] = "URL de notificação",
    ["webhook_username_description"] = "O nome de usuário a ser usado no caso de autenticação HTTP (optional).",
    ["zmq_interfaces"] = "Interfaces ZMQ",
  },
  ["processes_stats"] = {
    ["active_processes_title"] = "Processos Ativos: Visualização em Tempo Real",
    ["active_since"] = "Ativo Desde",
    ["flows_count"] = "Contagem de Fluxos",
    ["legend"] = "Lenda",
    ["lines"] = "Linhas",
    ["missing_pid_name_message"] = "Nome do pid ausente",
    ["no_traffic_detected"] = "Nenhum tráfego detectado para este processo, processo de fluxo expirado ou processo finalizado.",
    ["processes_timeline_title"] = "Linha do tempo dos processos",
    ["stack"] = "Pilha",
    ["timeline"] = "Timeline",
    ["top_hosts"] = "Principais hosts",
    ["top_hosts_traffic"] = "Principais host de tráfego",
    ["traffic_rcvd"] = "Tráfego Rcvd",
    ["traffic_sent"] = "Tráfego enviado",
    ["type"] = "Tipo",
  },
  ["report"] = {
    ["application_breakdown"] = "Repartição do aplicativo",
    ["applications"] = "Aplicações",
    ["begin_date_time"] = "Data de início / hora",
    ["date"] = "%{month}-%{day}-%{year}",
    ["end_date_time"] = "Data / hora final",
    ["filter_report"] = "Relatório de filtro",
    ["generate"] = "Gerar",
    ["invalid_begin"] = "Início inválido",
    ["invalid_begin_date"] = "Data de início inválida",
    ["invalid_begin_end"] = "Início / Fim Inválido",
    ["invalid_to"] = "Inválido para",
    ["local_networks"] = "Redes locais",
    ["local_remote"] = "Local / Remoto",
    ["network_interface"] = "Interface de rede",
    ["period"] = "Intervalo",
    ["please_check_format"] = "Por favor verifique o seu formato",
    ["please_choose_valid"] = "Por favor escolha uma data / hora de início / fim válida",
    ["please_choose_valid_date_and_time"] = "Por favor escolha uma data e hora válidas",
    ["receivers"] = "Receptores",
    ["remote_local"] = "remoto / local",
    ["report_for_subject"] = "Relatório - %{num_min} - para %{subject} iniciando %{dt}",
    ["reports_professional_only"] = "Os relatórios estão disponíveis apenas na versão Professional",
    ["senders"] = "Remetentes",
    ["starting"] = "Iniciando",
    ["submit_filter"] = "Enviar filtro",
    ["toggle_all"] = "Alternar tudo",
    ["top_asn"] = "ASN superior",
    ["top_countries"] = "Países Principais",
    ["top_local_hosts"] = "Principais hosts locais",
    ["top_local_os"] = "Top Local OS",
    ["top_networks"] = "Principais redes",
    ["top_non_local_os"] = "Top Non-Local OS",
    ["top_remote_hosts"] = "Principais hosts remotos",
    ["top_talkers"] = "Top Talkers",
    ["total_traffic"] = "Tráfego total",
    ["traffic_report"] = "Relatório de Trânsito",
    ["use_server_timezone"] = "Use o fuso horário do servidor",
  },
  ["sflows_stats"] = {
    ["active_flows"] = "Fluxos Ativos",
    ["client_peer"] = "Client Peer",
    ["client_process"] = "Processo do Cliente",
    ["server_peer"] = "Peer do servidor",
    ["server_process"] = "Processo do servidor",
    ["total_bytes"] = "Total de Bytes",
  },
  ["shaping"] = {
    ["applied_to"] = "Aplicado a",
    ["bandwidth_manager"] = "Gerenciador de largura de banda",
    ["confirm_delete_all_policies"] = "Você realmente quer apagar todo o \"%{pool_name}\" políticas de pool",
    ["confirm_delete_policy"] = "Você realmente deseja excluir",
    ["confirm_delete_shaper"] = "Você realmente quer excluir shaper ",
    ["daily_time"] = "Hora Diária (Current / Quota)",
    ["daily_time_quota"] = "Cota de tempo diário",
    ["daily_traffic"] = "Tráfego Diário (Current / Quota)",
    ["daily_traffic_quota"] = "Quota de tráfego diário",
    ["delete_all_policies"] = "Excluir todas as políticas",
    ["delete_policy"] = "Excluir política",
    ["delete_shaper"] = "Excluir Shaper",
    ["for_dropping_all_traffic"] = "para eliminar todo o tráfego",
    ["for_no_shaping"] = "por não moldar",
    ["initial_clone_protocols"] = "As regras iniciais de aplicativos serão clonadas",
    ["initial_empty_protocols"] = "As regras iniciais de aplicativos estarão vazias",
    ["manage_policies"] = "Gerenciar políticas",
    ["no_quota_applied"] = "Sem cota",
    ["no_quota_data"] = "Nenhuma cota definida",
    ["no_quota_traffic"] = "Nenhum tráfego relacionado a cotas até o momento",
    ["no_shapers_available"] = "Não há shapers disponíveis",
    ["note_default_pool_config"] = "Políticas e cotas se aplicam apenas a pools de host definidos pelo usuário. Selecione um pool diferente ou crie um novo <a href='%{url}'>here</a>.",
    ["note_drop_core"] = "Eliminar alguns protocolos principais pode ter efeitos colaterais em outros protocolos. Por exemplo, se você bloquear o DNS,<br>nomes de host simbólicos não são mais resolvidos e, portanto, somente a comunicação com IPs numéricos funciona.",
    ["note_quota_unlimited"] = "Definir tráfego e cota de tempo para 0 para tráfego ilimitado.",
    ["note_target_type"] = "Você pode modificar o que exibir na coluna Destino por meio do campo Tipo de Destino da Política no <a href=\"%{url}\">Preferências de ponte de tráfego</a> visão de especialista.",
    ["note_traffic_categories"] = "Você pode configurar as Categorias a partir do <a href=\"%{url}\">applications page</a>.",
    ["notes"] = "NOTAS",
    ["policy_from_pool"] = "política do pool",
    ["protocol_families"] = "Famílias de Aplicativos",
    ["protocol_policy"] = "Política de trânsito",
    ["protocols"] = "Aplicações",
    ["protocols_policies"] = "Políticas de Aplicações",
    ["see_quotas_here"] = "Visite o host pool <a href='%{url}'>quotas page</a> para obter uma visão geral completa das cotas do pool de host ativo.",
    ["select_to_clone"] = "Selecione uma rede existente para clonar as regras do aplicativo",
    ["set_max_rate_to"] = "Definir taxa máxima para",
    ["shaper0_message"] = "O shaper 0 é o shaper padrão usado para hosts locais que não têm shaper definido",
    ["shaper_id"] = "Shaper Id",
    ["shapers_in_use_message"] = "Shapers só podem ser excluídos se não forem aplicados a qualquer rede",
    ["traffic_from"] = "Tráfego de",
    ["traffic_to"] = "Tráfego para",
  },
  ["show_alerts"] = {
    ["1_day"] = "1 dia",
    ["1_hour"] = "1 hora",
    ["1_month"] = "1 mês",
    ["1_week"] = "1 semana",
    ["1_year"] = "1 ano",
    ["30_min"] = "30 minutos",
    ["5_min"] = "5 minutos",
    ["6_months"] = "6 meses",
    ["alert_actions"] = "Ações",
    ["alert_counts"] = "Contagens",
    ["alert_datetime"] = "Data hora",
    ["alert_description"] = "Descrição",
    ["alert_duration"] = "Duração",
    ["alert_severity"] = "Gravidade",
    ["alert_type"] = "Tipo de alerta",
    ["alerts"] = "Alertas",
    ["alerts_are_disabled_message"] = "Alertas estão desativados. Por favor, verifique a página de preferências para habilitá-los.",
    ["alerts_to_purge"] = "Alertas para purgar",
    ["confirm_delete_alert"] = "Você realmente deseja excluir o alerta especificado",
    ["daily"] = "Diariamente",
    ["delete_alert"] = "Excluir alerta",
    ["delete_alerts_configuration"] = "Excluir configuração de alertas",
    ["delete_all"] = "Excluir tudo",
    ["delete_config_btn"] = "Excluir %{conf}s Configuração comum",
    ["delete_config_message"] = "Você realmente quer apagar o comum %{granularity} alerta configuração de %{conf}s",
    ["detected_alerts"] = "Alertas Detectados",
    ["engaged"] = "Acionado",
    ["engaged_alerts"] = "Alertas Envolvidos",
    ["explorer"] = "Explorar",
    ["five_minutes"] = "Cinco minutos",
    ["flow_alerts"] = "Alertas de Fluxo",
    ["flush_data"] = "Flush Data",
    ["host_delete_config_btn"] = "Excluir host %{host} Alertas configurados",
    ["host_delete_config_confirm"] = "Você realmente deseja excluir o %{granularity} alertas de configuração para o host",
    ["hourly"] = "De hora em hora",
    ["iface_delete_config_btn"] = "Excluir interface %{iface} Configuração",
    ["iface_delete_config_confirm"] = "Você realmente deseja excluir o %{granularity} alertas de configuração para interface",
    ["in_the_selected_time_frame"] = "no período de tempo selecionado",
    ["interface_drops_threshold"] = "Pacotes de Interface Drops",
    ["interface_drops_threshold_descr"] = "A porcentagem máxima de pacotes descartados em relação ao número total de pacotes observados da interface",
    ["last_day"] = "Último dia",
    ["last_hour"] = "Última hora",
    ["last_minute"] = "Último minuto",
    ["minute"] = "Minuto",
    ["network_delete_config_btn"] = "Excluir rede %{network} Alertas configurados",
    ["network_delete_config_confirm"] = "Você realmente deseja excluir o %{granularity} alerta configuração para rede",
    ["no_recorded_alerts_message"] = "Nenhum alerta gravado para interface %{ifname}",
    ["older_1_day_ago"] = " mais de 1 dia atrás",
    ["older_1_hour_ago"] = "mais de 1 hora atrás",
    ["older_1_month_ago"] = "mais de 1 mês atrás",
    ["older_1_week_ago"] = "mais de 1 semana atrás",
    ["older_1_year_ago"] = "mais de 1 ano atrás",
    ["older_30_minutes_ago"] = "mais de 30 minutos atrás",
    ["older_5_minutes_ago"] = "mais de 5 minutos atrás",
    ["older_6_months_ago"] = "mais de 6 meses atrás",
    ["older_than"] = "mais velho que",
    ["past"] = "Passado",
    ["past_alerts"] = "Alertas Passados",
    ["past_flow"] = "Fluxo Passado",
    ["purge_num_alerts"] = "Purga [%{num_alerts} alerts]",
    ["purge_subj_alerts"] = "Purga %{subj} alertas",
    ["purge_subj_alerts_confirm"] = "Você realmente quer purgar todo o %{subj} alertas?",
    ["reset_alert_database"] = "Limpar dados de alertas",
    ["reset_alert_database_message"] = "Esta ação removerá todos os dados relacionados a alertas, incluindo<ul><li>Status de alertas de tempo de execução</li><li>Configuração de alertas</li><li>Alertas persistentes de armazenamento SQLite</li></ul><br>Você realmente quer prosseguir?",
    ["startup"] = "Comece",
  },
  ["sites_page"] = {
    ["contacts"] = "Contatos",
    ["current_sites"] = "Sites atuais",
    ["last_5_minutes_sites"] = "Últimos 5 minutos de sites",
    ["sites"] = "Sites",
    ["top_sites_not_enabled_message"] = "Para acompanhar os sites visitados, habilite a criação dos principais sites visitados para hosts locais a partir do <a href=\"%{url}\"><i class=\"fas fa-flask\"></i> Preferences</a>.",
    ["top_sites_not_seen"] = "O anfitrião local atual não visitou nenhum website ainda.",
    ["top_visited_sites"] = "Principais sites visitados",
  },
  ["snmp"] = {
    ["AlertDescription"] = "Alerta Descrição",
    ["ConsoleDisplayBufferText"] = "Exibir texto",
    ["GeneralSerialNumber"] = "Número de série",
    ["InputCurrentLevel"] = "Nível atual",
    ["InputDimUnit"] = "Unidade Dim",
    ["InputMaxCapacity"] = "Capacidade máxima",
    ["InputMediaDimFeedDirDeclared"] = "InputMediaDimFeedDirDeclared",
    ["InputMediaDimXFeedDirDeclared"] = "InputMediaDimXFeedDirDeclared",
    ["InputName"] = "InputName",
    ["MarkerColorantValue"] = "Corante marcador",
    ["MarkerLifeCount"] = "Contagem de Vida do Marcador",
    ["MarkerSuppliesDescription"] = "Descrição dos suprimentos de marcadores",
    ["MarkerSuppliesLevel"] = "Nível de suprimentos de marcador",
    ["MarkerSuppliesMaxCapacity"] = "Capacidade máxima de suprimentos de marcador",
    ["PrinterCurrentStatus"] = "Status atual",
    ["PrinterOperationalStatus"] = "Estado operacional",
    ["add_device"] = "Adicionar novo dispositivo",
    ["add_snmp_devices"] = "Adicionar dispositivos SNMP",
    ["all_snmp_interface_types"] = "Todos os tipos",
    ["all_snmp_statuses"] = "Todos os status",
    ["and_one_more_interface"] = "e <a href='%{url}'>1 mais interface</a>",
    ["bound_interface_description"] = "Ligar uma interface de rede a uma interface SNMP é útil para comparar o tráfego de rede monitorado por ntopng com o relatado pelo SNMP",
    ["caching_in_progress"] = "Andamento SNMP do dispositivo em andamento. Isso pode levar até 5 minutos. A página será atualizada periodicamente.",
    ["contact"] = "Contato",
    ["delete_all_devices"] = "Excluir todos os dispositivos",
    ["device_example"] = "Examplo: %{example}",
    ["device_ip"] = "IP do dispositivo",
    ["device_model"] = "Modelo do dispositivo",
    ["device_polling"] = "Polling de dispositivos",
    ["device_polling_desc"] = "Realizar passeios SNMP periódicos para coletar dados do dispositivo, incluindo o tráfego e o status das interfaces de dispositivo.",
    ["device_status"] = "Status do dispositivo",
    ["disable_port_monitor"] = "Desativar o Port Monitor",
    ["discover_devices"] = "Descubra dispositivos",
    ["enable_port_monitor"] = "Ativar monitor de porta",
    ["ifName"] = "Nome da interface",
    ["ifindex"] = "Índice",
    ["in_bytes"] = "Em bytes",
    ["in_discards"] = "Em devoluções",
    ["in_errors"] = "Em erros",
    ["interface_device"] = "Interface %{interface} [ %{device} ]",
    ["last_change"] = "Última mudança",
    ["low_port_speed"] = "Baixa velocidade da porta",
    ["multiple_macs_non_trunk"] = "Múltiplos MACs na porta sem tronco",
    ["no_answer"] = "Nenhuma resposta do host %{host}: verifique se o SNMP está ativo e se a comunidade está configurada com o valor correto",
    ["no_host_discovered"] = "Nenhum host descoberto em %{host}/%{cidr}",
    ["note"] = "NOTA",
    ["object_id"] = "ObjectID",
    ["out_bytes"] = "Bytes fora",
    ["port_macs"] = "Endereços Mac",
    ["port_macs_short"] = "MACs",
    ["remove_all_snmp_devices"] = "Remover todos os dispositivos SNMP",
    ["remove_all_snmp_devices_confirm"] = "Você realmente deseja excluir todos os dispositivos SNMP?",
    ["remove_snmp_device"] = "Remover dispositivo SNMP",
    ["remove_snmp_device_confirm"] = "Você realmente deseja excluir o dispositivo SNMP %{device}?",
    ["snmp_all_interfaces"] = "Todas as interfaces",
    ["snmp_also_seen_on"] = "Também visto em",
    ["snmp_and_n_more_interfaces"] = "e <a href='%{url}'>%{count} mais interfaces</a>",
    ["snmp_community"] = "Comunidade SNMP",
    ["snmp_device"] = "Dispositivo SNMP",
    ["snmp_device_does_not_respond"] = "O dispositivo SNMP não responde.",
    ["snmp_device_last_poll"] = "Tempo desde a última pesquisa",
    ["snmp_device_polling_disabled"] = "A consulta periódica de dispositivos está desativada. As informações mostradas podem estar ausentes ou desatualizadas. A pesquisa pode ser ativada a partir do <a href=\"%{url}\"><i class=\"fas fa-flask\"></i> Preferences</a>.",
    ["snmp_device_x"] = "%{device}",
    ["snmp_devices"] = "Dispositivo SNMP",
    ["snmp_interface"] = "Interface SNMP",
    ["snmp_interface_type"] = "Tipo de interface",
    ["snmp_interface_x"] = "Interface: %{interface}",
    ["snmp_interfaces"] = "Interfaces",
    ["snmp_monitor_disable_confirm"] = "Você realmente quer desabilitar o monitoramento do status da porta no dispositivo SNMP? %{device}?",
    ["snmp_monitor_enable_confirm"] = "Você realmente deseja ativar o monitoramento do status da porta no dispositivo SNMP? %{device}? Alertas serão gerados sempre que uma porta mudar de estado.",
    ["snmp_note_bridge_mib"] = "Passeios SNMP periódicos no Bridge MIB são executados para preencher a tabela.",
    ["snmp_note_bridge_mib_status"] = "O status mostrado é o dot1qTpFdbStatus Status da Bridge MIB associado ao endereço MAC.",
    ["snmp_note_periodic_interfaces_polling"] = "Passeios SNMP periódicos são executados para atualizar interfaces em intervalos regulares de 5 minutos.",
    ["snmp_note_thpt_calc"] = "O throughput é responsável pelo tráfego total (in + out) ao longo dos dois mais recentes passeios SNMP consecutivos.",
    ["snmp_note_thpt_span"] = "Os dois mais recentes passeios SNMP consecutivos foram realizados em %{last} e %{prev}.",
    ["snmp_port_monitor"] = "Monitor de porta SNMP",
    ["snmp_printer"] = "Impressora",
    ["snmp_timeseries_descr"] = "Os timeseries de dispositivos SNMP podem ser ativados <a href=\"%{url}\"><i class=\"fas fa-flask\"></i> Preferences</a>. São necessários alguns minutos para ver os primeiros pontos de dados",
    ["snmp_version"] = "Versão SNMP",
    ["status_down"] = "Down",
    ["status_up"] = "Up",
    ["testing"] = "Testando",
    ["tp_fbd_status_invalid"] = "inválido",
    ["tp_fbd_status_learned"] = "aprendido",
    ["tp_fbd_status_mgmt"] = "mgmt",
    ["tp_fbd_status_other"] = "de outros",
    ["tp_fbd_status_self"] = "auto",
    ["trunk"] = "tronco",
    ["unable_to_delete_snmp_device"] = "Não é possível excluir o dispositivo SNMP %{device}",
    ["unresponsive_device"] = "A caminhada do SNMP é muito lenta. Os dados exibidos podem estar desatualizados ou ausentes. Verifique a conectividade de rede e a capacidade de resposta do dispositivo. Uma nova tentativa de rastreamento será realizada em 15 minutos.",
    ["view_device"] = "Ver dispositivo",
  },
  ["snmp_page"] = {
    ["guide_snmp_page_message"] = "Visite a página <a href='%{url}'> SNMP</a> adicionar este host à lista de dispositivos SNMP configurados.",
    ["not_configured_as_snmp_device_message"] = "Host %{host_ip} não foi configurado como um dispositivo SNMP.",
    ["showing_snmp_mib_info_default_community_message"] = "Mostrando informações de SNMP MIB recuperadas usando a comunidade padrão '%{community}'",
    ["trying_to_retrive_message"] = "Tentando recuperar o host SNMP MIB usando a comunidade padrão '%{community}'",
    ["unable_to_retrive_snmp_default_community_message"] = "Não é possível recuperar o host SNMP MIB usando a comunidade padrão '%{community}'.",
  },
  ["sprobe_page"] = {
    ["active_memory"] = "Memória ativa",
    ["latency"] = "Latência",
    ["processes"] = "Processos",
    ["processes_traffic_tree"] = "Árvore de Tráfego de Processos",
    ["show_more_info"] = "Passe o mouse para mostrar as informações do processo ou clique duas vezes para mostrar mais informações.",
    ["system_interactions"] = "Interações do Sistema",
    ["top_processes"] = "Principais processos",
    ["top_users"] = "Principais usuários",
    ["tree"] = "Árvore",
    ["users"] = "Usuários",
  },
  ["top_hosts"] = {
    ["top_hosts_local"] = "Principais hosts (Local)",
  },
  ["topk_heuristic"] = {
    ["precision"] = {
      ["aggressive"] = "Agressivo",
      ["disabled"] = "Desativado",
      ["less_accurate"] = "Menos preciso",
      ["more_accurate"] = "Mais preciso",
    },
  },
  ["traffic_page"] = {
    ["l4_proto_overview"] = "Visão geral do protocolo",
    ["no_traffic_observed_message"] = "Nenhum tráfego foi observado para o host especificado",
    ["rcvd"] = "Rcvd",
  },
  ["traffic_profiles"] = {
    ["advanced_filter_examples"] = "Exemplos de Filtros Avançados",
    ["confirm_delete_profile"] = "Você realmente quer excluir o perfil",
    ["delete_profile"] = "Excluir perfil",
    ["destination_network"] = "Rede de destino",
    ["duplicate_profile"] = "Nome do perfil duplicado",
    ["edit_traffic_profiles"] = "Perfis de tráfego",
    ["enter_profile_filter"] = "Digite o filtro do perfil",
    ["enter_profile_name"] = "Digite um nome de perfil",
    ["facebook_traffic"] = "Facebook",
    ["host_http_https"] = "Host HTTP/HTTPS",
    ["host_traffic"] = "Host",
    ["http_traffic"] = "HTTP",
    ["invalid_bpf"] = "Filtro BPF inválido",
    ["max_profiles_num"] = "Com esta versão do ntopng você só pode criar %{maxnum} perfis. Atualize para a versão Enterprise para remover esse limite",
    ["no_profiles"] = "Nenhum conjunto de perfis",
    ["note"] = "Nota",
    ["note_0"] = "Nomes de perfis de tráfego permitem caracteres alfanuméricos, espaços e sublinhados",
    ["note_1"] = "Perfis de tráfego são aplicados aos fluxos. Cada fluxo pode ter até um perfil, portanto, no caso de várias correspondências de perfil, apenas o primeiro é selecionado",
    ["profile_name"] = "Nome do perfil",
    ["see_ndpi_protos"] = "(use %{option} to print all nDPI supported protocols)",
    ["simple_filter_examples"] = "Exemplos de filtros simples",
    ["source_ethernet"] = "Endereço MAC de origem",
    ["traffic_between"] = "Tráfego entre hosts",
    ["traffic_filter_bpf"] = "Filtro de tráfego (nBPF Format)",
    ["traffic_from_to"] = "Tráfego de um host para outro",
    ["traffic_profiles"] = "Perfis de tráfego",
  },
  ["traffic_recording"] = {
    ["about_to_extract"] = "Prestes a extrair tráfego de <b>%{date_begin}</b> to <b>%{date_end}</b>",
    ["active_since"] = "Ativo Desde",
    ["archive"] = "Arquivo",
    ["completed"] = "Concluído",
    ["continuous_recording"] = "Gravação Contínua de Tráfego",
    ["continuous_recording_and_flows"] = "Gravação Contínua de Tráfego e Visibilidade de Fluxo",
    ["delete_all_jobs"] = "Excluir todos os trabalhos",
    ["delete_all_jobs_confirm"] = "Você realmente deseja excluir todos os trabalhos de extração? Trabalhos ativos serão interrompidos.",
    ["delete_job"] = "Excluir trabalho",
    ["delete_job_confirm"] = "Você realmente quer excluir Job %{job_id} e os arquivos Pcap relacionados?",
    ["disabled"] = "Desativado",
    ["disk_space"] = "Espaço Máximo em Disco",
    ["disk_space_note"] = "Espaço máximo em disco usado para tráfego gravado no disco.",
    ["disk_space_note_in_use"] = "%{in_use} GB já estão em uso por esta instância.",
    ["download"] = "Baixar",
    ["download_nth_pcap"] = "Download Pcap #{0}",
    ["dump_window"] = "Janela de despejo",
    ["edit_filter"] = "Editar filtro",
    ["err_alloc"] = "erro de alocação de memória",
    ["err_filter"] = "filtro não suportado",
    ["err_open"] = "incapaz de abrir o despejo",
    ["err_stuck"] = "preso ou interrompido",
    ["err_unknown"] = "erro inesperado",
    ["ext_interface"] = "Interface externa",
    ["extract_action"] = "Extrair",
    ["extract_now"] = "Extraia agora",
    ["extracted_bytes"] = "Bytes extraídos",
    ["extracted_packets"] = "Pacotes extraídos",
    ["extraction_scheduled"] = "Um novo trabalho de extração foi agendado, por favor, verifique o %{page} página para baixar o pcap assim que o arquivo estiver pronto. O ID do trabalho para esta extração é ",
    ["failed"] = "Falhou",
    ["failure"] = "Falha",
    ["failure_note"] = "Por favor, verifique o log de rastreamento e tente reiniciar o serviço.",
    ["filter_bpf"] = "Filtro (Formato nBPF)",
    ["filter_examples"] = "Exemplos de filtro",
    ["global_settings_note"] = "Configurações globais (por exemplo. a chave de licença) pode ser configurado a partir do <a href=\"%{url}\">Preferências de Gravação de Tráfego</a>.",
    ["invalid_bpf"] = "Filtro inválido",
    ["job_date_time"] = "Data / hora de criação do trabalho",
    ["job_id"] = "ID de trabalho",
    ["jobs"] = "Trabalhos",
    ["logs"] = "Registros de Gravação de Tráfego",
    ["max_extracted_pcap_bytes_description"] = "Tamanho máximo para arquivos pcap extraídos de dados gravados. No caso de extrações que excedam esse tamanho, a saída será dividida em vários arquivos.",
    ["max_extracted_pcap_bytes_title"] = "Tamanho máximo do arquivo extraído",
    ["missing_data_msg"] = "A gravação de tráfego foi interrompida ou reiniciada. Alguns dados podem estar faltando.",
    ["missing_parameters"] = "Parâmetros obrigatórios estão ausentes",
    ["msg_err_missing_timeline"] = "Não é possível determinar a linha do tempo do n2disk atualmente em execução. As extrações só podem ser executadas quando o n2disk está atualizado e executado com a opção --timeline-dir.",
    ["msg_err_timeline_path_not_existing"] = "Caminho da linha do tempo não encontrado no sistema.",
    ["msg_err_unable_to_access_timeline"] = "Não é possível ler os dados gravados. Permissões insuficientes. Certifique-se de que o usuário que está executando o ntopng esteja no mesmo grupo do usuário que está executando o n2disk.",
    ["msg_err_unknown"] = "Status desconhecido.",
    ["msg_external_providers_detected"] = "Provedores de gravação de tráfego externo detectados. O ntopng pode vincular automaticamente essa interface a um provedor externo. Você pode deixar ntopng cuidar da gravação usando esta página, ou você pode <a href=\"%{url}\"><i class=\"fas fa-cog\"></i> configure</a> um provedor de gravação de tráfego externo.",
    ["msg_ok"] = "Pronto para extrair",
    ["multiple_extracted_files"] = "Extração de tráfego gerou vários arquivos pcap de %{mb} MB, É possível alterar esse limite em Preferências. Clique nos links abaixo para baixar os arquivos pcap.",
    ["no_data_in_interval"] = "Não há (or partial) dados pcap em disco para o intervalo de tempo selecionado. Por favor, note que os dados de pcap são despejados a cada minuto (último minuto não está disponível) e dados antigos são apagados (por favor, verifique a janela de <A HREF=\"%{page}\">status page</A>). Por favor, tente selecionar um intervalo de tempo diferente.",
    ["no_file"] = "Ainda não há arquivos despejados",
    ["no_recorded_data"] = "Não há dados gravados no período de tempo especificado. O gravador de tráfego precisa de algum tempo para gravar dados recentes.",
    ["not_found"] = "Arquivo não encontrado",
    ["not_granted"] = "Pedido não concedido",
    ["note_dump"] = "Em redes ethernet, cada pacote tem um <A HREF=\"https://en.wikipedia.org/wiki/Ethernet_frame\">overhead of 24 bytes</A> [preamble, start of frame, CRC, IFG]. Essa sobrecarga é responsável pelo tráfego da interface, mas não é adicionada ao tráfego que está sendo despejado no disco. Por esse motivo, o número de bytes nesta página pode diferir daqueles relatados no gráfico de interface.",
    ["packet_dumps"] = "Despejos de pacotes",
    ["pcap_download"] = "Extrair pcap",
    ["pcap_download_message"] = "Inicie a extração e verifique o %{page} página para baixar o pcap assim que o arquivo estiver pronto.",
    ["processing"] = "Em processamento",
    ["queue_as_job"] = "Fila como um trabalho",
    ["recording"] = "Gravação",
    ["restart"] = "Reiniciar",
    ["restart_service"] = "Reinicie o serviço",
    ["settings"] = "Definições",
    ["start_extraction"] = "Iniciar extração",
    ["stop_job"] = "trabalho parado",
    ["stop_job_confirm"] = "Você realmente quer parar o trabalho %{job_id}?",
    ["stopped"] = "Parado",
    ["storage"] = "Armazenamento",
    ["storage_dir"] = "Diretório de Armazenamento",
    ["storage_directory_config"] = "O caminho do diretório de armazenamento pode ser alterado especificando <i>%{option}</i> opção no %{product} arquivo de configuração.",
    ["storage_utilization"] = "Utilização de armazenamento",
    ["traffic_extraction_jobs"] = "Trabalhos de Extração de Tráfego",
    ["traffic_extractions"] = "Extrações",
    ["traffic_on_disk"] = "Tráfego no disco",
    ["traffic_recording"] = "Gravação de Tráfego",
    ["traffic_recording_provider"] = "Provedor de Gravação de Tráfego",
    ["traffic_recording_settings"] = "Configurações de gravação de tráfego",
    ["traffic_recording_status"] = "Status de gravação de tráfego",
    ["unsupported_fields"] = "Observe que o gráfico selecionado fornece uma visão do tráfego não totalmente suportado pela ferramenta de extração. O tráfego extraído conterá mais tráfego do que o esperado.",
    ["waiting"] = "Esperando",
    ["waiting_nospace"] = "Esperando (Nenhum espaço no disco)",
  },
  ["traffic_report"] = {
    ["current_day"] = "Dia atual",
    ["current_month"] = "Mês atual",
    ["current_week"] = "Semana atual",
    ["daily"] = "Diariamente",
    ["header_daily"] = "Relatório diário",
    ["header_monthly"] = "Relatório mensal",
    ["header_weekly"] = "Relatório semanal",
    ["monthly"] = "Por mês",
    ["previous_day"] = "Dia anterior",
    ["previous_month"] = "Mês anterior",
    ["previous_week"] = "Semana anterior",
    ["weekly"] = "Semanal",
  },
  ["tree_map"] = {
    ["hosts_treemap"] = "Mapa da árvore de hosts",
  },
  ["unknown_devices"] = {
    ["active_only"] = "Apenas ativo",
    ["all_devices"] = "Todos os dispositivos",
    ["assign_device_pool"] = "Atribuir dispositivo a um pool",
    ["assign_pool"] = "Atribuir ao pool",
    ["device_name"] = "Nome do dispositivo",
    ["filter_devices"] = "Dispositivos de filtro",
    ["first_seen"] = "Visto pela primeira vez",
    ["inactive_only"] = "Apenas inativo",
    ["last_seen"] = "Visto pela última vez",
    ["no_pools"] = "Um host pool deve ser criado para atribuir dispositivos desconhecidos ao.",
    ["select_pool"] = "Selecione um host pool no menu suspenso abaixo para atribuir '%{mac}' para:",
    ["unassigned_devices"] = "Dispositivos não atribuídos",
  },
  ["user_activity"] = {
    ["alerts_deleted"] = "Usuário '%{user}' purgado '%{status}' alertas.",
    ["changed_preference"] = "Usuário '%{user}' configurações alteradas para %{pref}.",
    ["deleted_all_interfaces_data"] = "Usuário '%{user}' dados excluídos para todas as interfaces.",
    ["deleted_host_data"] = "Usuário '%{user}' dados excluídos para o host %{host} na interface %{ifname}.",
    ["deleted_inactive_interfaces_data"] = "Usuário '%{user}' dados excluídos para todas as interfaces inativas.",
    ["deleted_interface_data"] = "Usuário '%{user}' dados excluídos para interface %{ifname}.",
    ["deleted_network_data"] = "Usuário '%{user}' dados excluídos para rede %{network} na interface %{ifname}.",
    ["disabled_preference"] = "Usuário '%{user}' preferência desativada %{pref}.",
    ["enabled_preference"] = "Usuário '%{user}' preferência ativada %{pref}.",
    ["exported_data"] = "Usuário '%{user}' dados JSON exportados para '%{mode}' hosts.",
    ["exported_data_host"] = "Usuário '%{user}' dados JSON exportados para '%{mode}' host %{host}.",
    ["file_downloaded"] = "Usuário '%{user}' arquivo baixado '%{file}'.",
    ["flows_downloaded"] = "Usuário '%{user}' dados de fluxos baixados de %{from} para %{to}.",
    ["host_json_downloaded"] = "Usuário '%{user}' dados JSON baixados para o host %{host}.",
    ["live_capture"] = "Usuário '%{user}' tráfego ao vivo capturado na interface %{ifname}.",
    ["live_capture_host"] = "Usuário '%{user}' tráfego ao vivo capturado para o host %{host} na interface %{ifname}.",
    ["live_capture_host_with_filter"] = "Usuário '%{user}' tráfego ao vivo capturado para o host %{host} filtro de correspondência '%{filter}' na interface %{ifname}.",
    ["live_capture_with_filter"] = "Usuário '%{user}' filtro de correspondência de tráfego ao vivo capturado '%{filter}' na interface %{ifname}.",
    ["live_extraction"] = "Usuário '%{user}' tráfego baixado da interface %{ifname} de %{from} para %{to}.",
    ["live_extraction_with_filter"] = "Usuário '%{user}' tráfego baixado da interface %{ifname} de %{from} para %{to} filtro de correspondência '%{filter}'.",
    ["login_not_authorized"] = "Login negado para o usuário '%{user}'.",
    ["login_successful"] = "Usuário '%{user}' logado.",
    ["password_changed"] = "Password for user '%{pwd_user}' Alterado por '%{user}'.",
    ["recording_disabled"] = "Usuário '%{user}' desativado Gravação de tráfego na interface %{ifname}.",
    ["recording_enabled"] = "Usuário '%{user}' Gravação de Tráfego habilitada na interface %{ifname}.",
    ["snmp_device_added"] = "Usuário '%{user}' dispositivo SNMP adicionado %{ip}.",
    ["snmp_device_deleted"] = "Usuário '%{user}' dispositivo SNMP excluído %{ip}.",
    ["unknown_activity"] = "Usuário '%{user}' fez alguma atividade desconhecida (%{scope}), por favor comunique isto.",
    ["unknown_activity_function"] = "Usuário '%{user}' fez alguma atividade desconhecida (%{name}), por favor comunique isto.",
    ["user_added"] = "Usuário '%{add_user}' adicionado por '%{user}'.",
    ["user_deleted"] = "Usuário '%{del_user}' excluído por '%{user}'.",
  },
  ["user_info"] = {
    ["missing_user_name_message"] = "Nome de usuário ausente",
    ["processes"] = "Processos",
    ["processes_overview"] = "Visão geral dos processos",
    ["top_l4_protocols"] = "Protocolos principais",
    ["top_l7_protocols"] = "Principais aplicativos",
  },
  ["users"] = {
    ["add_new_user"] = "Adicionar novo usuário",
    ["add_user"] = "Adicionar usuário",
    ["assigned_devices"] = "Dispositivos Atribuídos",
    ["cat_protocols"] = "%{cat} Aplicações",
    ["categories"] = "Categorias",
    ["client_policy"] = "Dispositivo como cliente",
    ["confirm_delete_user"] = "Você realmente quer excluir o usuário \"%{user}\"?",
    ["delete_user"] = "Deletar usuário",
    ["devices"] = "Devices",
    ["edit"] = "Editar",
    ["edit_global_policies"] = "Editar políticas padrão",
    ["fallback_policy"] = "Política de reserva",
    ["full_name"] = "Nome completo",
    ["global"] = "Global",
    ["global_policies"] = "Políticas Padrão",
    ["no_users"] = "Nenhum usuário",
    ["num_protocols"] = "Aplicações Num",
    ["policy"] = "Política",
    ["protocols"] = "Aplicações",
    ["reset_to_defaults"] = "Redefinir para padrões",
    ["reset_to_defaults_confirm"] = "Você realmente quer redefinir o tipo de dispositivo \"%{devtype}\" políticas para os padrões?",
    ["server_policy"] = "Dispositivo como servidor",
    ["settings"] = "Definições",
    ["total_daily_time_quota"] = "Cota Total de Tempo Diário",
    ["total_daily_traffic_quota"] = "Cota total de tráfego diário",
    ["unchanged"] = "Inalterado",
    ["user_exists"] = "Usuário \"%{user}\" já existe",
    ["user_x"] = "Usuário: %{user}",
    ["shapers"] = {
      ["default"] = "Padrão",
      ["drop"] = "Drop",
      ["pass"] = "Passar",
      ["slow"] = "Passagem lenta",
      ["slower"] = "Passagem mais lenta",
    },
  },
  ["vlan_details"] = {
    ["no_available_stats_for_vlan_message"] = "Não há estatísticas disponíveis para VLAN %{vlan_id}. Por favor, aguarde alguns minutos para permitir %{product} colher novas estatísticas.",
    ["vlan_id_parameter_missing_or_invalid_message"] = "O parâmetro Vlan_Id está ausente ou não é válido",
  },
  ["vlan_stats"] = {
    ["vlan_id"] = "VLAN ID",
    ["vlans"] = "VLANs",
  },
}

return lang
